.woocommerce {
	input[type=text],
	input[type=tel],
	input[type=email],
	input[type=password],
	input[type=email],
	input[type=search],
	input[type=date],
	input[type=range],
	input[type=number],
	input[name="apply_coupon"],
	textarea,
	select {
		padding: 14px;
		margin-bottom: 0 !important;
		font-size: 14px;
		box-shadow: none;
		text-shadow: none;
		font-weight: normal;
		border-radius: 0px;
	}

	input[type=submit],
	input[type=button] {
		border: 0;
	}

	input[name="apply_coupon"] {
		margin-top: 10px;
	}

	a.remove,
	ul.product_list_widget li a.remove{
		font-size: 18px  !important;
		height: 20px;
		width: 20px;
		padding: 0px;
		font-weight: 100;
		line-height: 1em !important;

		&:hover {
			background: @accent-color-1 !important;
		}
	}

	.ul.socialcount {
		margin: 0.4em 0px 0.4em 0 !important;
	}

	.lost_reset_password .button {
		.button-gen-common();
		.button-gen(@accent-color-1);
		.button-gen-hover(@accent-color-2);

		padding: 0.8em 1.6em;
		border-radius: 0;
	}

	.checkout-breadcrumb {
		.icon.shortcode {
			line-height: 1.15;
			font-size: 20px;
			padding: 0 20px;
			vertical-align: middle !important;
			color: @accent-color-7;
		}

		.title-part-inactive {
			color: @accent-color-7;
		}
	}

	#payment {
		background: none;

		#place_order {
			float: left;
			padding: 1em 1.8em;
			.submit-button-style
			&:hover {
				background: @accent-color-2;
				color: @accent-color-8 !important;
			}
		}

		ul.payment_methods {
			border-bottom: 0;
		}

		ul.payment_methods li input {
			vertical-align: middle;
			border: 0;
		}

		.payment_box {
			background: @accent-color-7;

			p {
				margin: 0;
			}
		}
	}

	h1.page-title,
	div.product .product_title {
		display: none;
	}

	.star-rating {
		float: none;
		color: @accent-color-1;
		font-style: normal;

		&:before {
			color: @accent-color-1;
			font-style: normal;
		}
	}

	.woocommerce-result-count {
		margin-top: 20px;
		line-height: 15px;
	}

	.woocommerce-ordering {
		margin-bottom: 30px;

		select {
			padding: 10px;
			box-shadow: 0 1px 2px rgba(0, 0, 0, 0.16)!important;
			font-size: 12px;
			line-height: 22px;
		}
	}

	form.login {
			border-radius: 1px;
			border: 3px solid @accent-color-1;
	}

	form.checkout_coupon {
		border-radius: 1px;
		border: 3px solid @accent-color-1;
	}

	.woocommerce-message,
	.woocommerce-error,
	.woocommerce-info {
		margin-bottom: 2em;
		border-top: 0;
		background: transparent;
		box-shadow: none;
		padding: 10px !important;
		text-shadow: none;
		border-radius: 1px;


		&:before {
			display: none;
		}
	}

	.button.wc-forward,
	.button.wc-backward {
		&, a {
			&:after,
			&:before {
				display: none;
			}
		}
	}

	.woocommerce-info,
	.woocommerce-message {
		background-color: transparent;
		border: solid 1px @accent-color-7;
		border-radius: 0px;
	}

	.woocommerce-error {
		background-color: fade(@accent-color-1, 10%);
		color: fade(@accent-color-1, 80%);
		text-shadow: none;
	}

	span.onsale,
	.products.vamtam-wc .product span.onsale {
		top: 0;
		right: 0;
		left: auto;
		z-index: 5;
		margin: 0;
		border-radius: 1px;
		background: transparent;
		box-shadow: none;
		color: #D55000;
		text-transform: uppercase;
		text-shadow: none;
		font-weight: bold;
		font-style: normal;
		font-size: .75em;
		line-height: 1;
		min-width: 0;
		min-height: 0;
		font-family: @h6-face, sans-serif;
		background: #FCEA00;
		padding: 10px;
	}

	.products.vamtam-wc .product,
	div.product .summary {
		.stock {
			font-size: 12px;
			margin: 0;
			overflow: hidden;

			small {
				position: relative;
				color: @primary-font-color;
				line-height: 1;
				padding-right: 5px;

				&:after {
					content: "";
					position: absolute;
					left: 100%;
					bottom: 3px;
					width: 800px;
					height: 1px;
					background: @accent-color-7;
				}
			}
		}
	}

	.products.vamtam-wc {
		position: relative;

		.product-category {
			mark.count {
				display: none;
			}
		}

		.product {
			padding: 0;

			span.amount {
				font-weight: normal;
				font-size: 0.6em;
				background: @accent-color-1;
				color: @accent-color-8;
				padding: 10px 15px;
			}

			.add_to_cart_button,
			.vamtam-button.product_type_simple {
				margin-top: 10px;
			}

			&.first {
				clear: both;
			}

			&.last {
				margin-right: 0;
			}

			.wc-new-badge {
				margin: 0;
				position: absolute;
				top: 0;
				left: 0;
				border-radius: 0;
				padding: 5px 10px;
				background: @accent-color-1;
			}

			.categories {
				margin: 0;

				a {
					color: @primary-font-color;
					font-size: 12px;
				}
			}

			.price {
				display: block;
				.wpv-font(h3-);
				color: @accent-color-3;
				margin-top: -36px;
				position: relative;
				margin-bottom: 15px;

				del {
					margin: 0px;
					font-size: inherit;
					display: inline-block;
					opacity: 1;

					span {
						background: #000;
						color: #fff;
					}
				}

				ins {
					span{
						color: #D55000;
						background: #FCEA00;
					}
				}
			}

			h5 {
				margin-bottom: 0px;
			}

			.woocommerce-loop-product__title {
				.wpv-font(h4-);
				font-size: 18px;
				font-weight: normal;
				color: @accent-color-1;
				padding-bottom: .1em;
			}

			a {
				.product-thumbnail {
					position: relative;
					display: block;
					max-height: none !important;
					border: 1px solid @accent-color-7;
					margin-bottom: 0px;
					overflow: hidden;
					-webkit-transform: translateZ(0);
					-ms-transform: translateZ(0);
					transform: translateZ(0);
				}

				img {
					display: block;
					border: 0;
					box-shadow: none;
					margin: 0;
					.transition(all .3s);
				}

				html.no-touch &:hover {
					img {
						box-shadow: none !important;
						.transform(scale(1.1));
					}
				}

				&:hover .woocommerce-loop-product__title {
					color: @css_link_hover_color;
					box-shadow: none;
					-webkit-box-shadow: none;
				}
			}

			.aggregateRating {
				margin: 10px 0 20px 0;
				min-height: 1.4em;

				.star-rating {
					position: relative;
					top: 2px;
					float: left;
					margin-right: 10px;
					margin-bottom: 0;
					width: 7em;
					color: @accent-color-1;
					letter-spacing: 5px;
					font-size: 14px;

					span {
						display: inline-block;

						strong,
						span.visualhidden {
							display: none;
						}

						&:before {
							font-size: 14px !important;
						}
					}
				}

				a.count {
					position: relative;
					top: -3px;
					margin: 0 0 0 5px;
					color: @accent-color-6;

					span.number {
						color: @accent-color-2;
					}
				}

				+ .vamtam-button {
					margin-top: 0;
				}
			}

			span.price span.from {
				.wpv-font(em-);
				.wpv-color(em-);
			}

			.add_to_cart_button .btext {
				padding-left: 1.5em;
				padding-right: 1.5em;
			}
		}

		div[itemprop="description"] {
			margin: 0 0 5px 0;

			> p:first-child {
				margin-top: 0;
			}
		}
	}

	.related,
	.upsells {
		&.products {
			clear: both;
			margin-top: 100px;

			h2 {
				.wpv-font(h2-);
				position: relative;
				margin: 0;
				margin-bottom: 30px;
				padding: 0 5px 15px 0;
				padding-bottom: 20px;
				border-bottom: 1px solid @default-line-color;
				color: @h3-color;
				text-align: center;
				text-transform: uppercase;
			}

			ul,
			.products.vamtam-wc {
				.product {
					margin-bottom: 60px;
					width: 22.15%;
				}
			}
		}
	}

	.upsells {
		&.products {
			ul,
			.products.vamtam-wc {
				.product {
					margin-bottom: 0;
				}
			}
		}
	}

	.quantity,
	#quantity {
		input.qty {
			border: 1px solid @default-line-color;
			border-radius: 1px;
			font-weight: normal;
			padding: 0;
			font-size: 14px;
			height: 45px;
		}
	}

	div.product {
		span.onsale {
			right: 52%;
		}

		p.price {
			margin-bottom: 30px;

			span.from {
				.wpv-font(em-);
				.wpv-color(em-);
			}
		}

		.woocommerce-tabs {
			position: relative;

			> ul.tabs {
				overflow: visible;
				margin: 0;
				margin-top: 10px;
				padding: 0;
				border: 0;
				background: @accent-color-8;
				list-style: none;

				li {
					position: relative;
					z-index: 2;
					display: block;
					float: left;
					margin: 0;
					padding: 0;
					border: 0;
					box-shadow: none;
					white-space: nowrap;
					border-radius: 0;
					background: none;
					color:  @accent-color-6;

					&:before,
					&:after {
						display: none !important;
					}

					a {
						position: relative;
						display: block;
						padding: 25px 16px;
						outline: none;
						color: @accent-color-6;
						text-shadow: none;
						font-weight: normal;
						font-size: 18px;
						line-height: 1;
						cursor: pointer;
						border-bottom: solid 3px transparent;
						transition: all 0.3s;

						.icon {
							color: @accent-color-8;
							font-style: normal;
						}

						&:hover {
							border: 0;
							border-radius: 1px;
							box-shadow: none;
							color: @accent-color-6;
							text-decoration: none;
							border-bottom: solid 3px @accent-color-1;
							background: none;

							.icon {
								color: @accent-color-8 !important;
							}
						}
					}
				}

				li.active {
					padding: 0 !important;
					border: 0;
					box-shadow: none;
					color: @accent-color-8;
					text-decoration: none;
					white-space: nowrap;
					border-radius: 0px;
					background: none;

					a {
						border-bottom: solid 3px @accent-color-1;
						background: none;
						color: @accent-color-6;
					}
				}
			}

			.panel {
				clear: both;
				margin-bottom: 0 !important;
				padding: 10px 12px 0 12px;
			}

			&,
			&:after,
			> ul:after {
				display: block;
				clear: both;
				content: "";
			}

			#tab-description > h2,
			#tab-reviews h2 {
				display: none;
			}

			#tab-reviews #comments > div .star-rating {
				display: none;
			}
		}

		form.cart {
			margin: 20px 0px;

			.group_table td {
				padding-bottom: 1em;
			}

			> .single_add_to_cart_button {
				padding: .7em 2em;

				border: 2px solid @accent-color-1;
				border-radius: 1px;
				background: transparent;
				box-shadow: none;
				color: @accent-color-1;
				text-transform: uppercase;
				text-shadow: none;
				font-style: normal;
				font-size: 15px;
				&:hover {
					&, span {
						border-color: @accent-color-1;
						background: @accent-color-1;
						color: lighten(@accent-color-1, 90%) ;
						transition: color 0.3s;
					}
				}
			}

			+ .share-btns {
				text-align: left;
				padding: 20px 0;

				> ul {
					margin-left: 0;
				}

				.sep,
				.sep-2,
				.sep-3 {
					&:first-child {
						display: none;
					}
				}
			}
		}

		.product_meta {
			.posted_in,
			.tagged_as {
				display: block;
			}
		}

		div.images {
			position: relative;
			margin-bottom: @vertical-padding-large*2;

			.bx-wrapper {
				margin-bottom: 0;
			}

			ul.thumbnails {
				padding-top: 0;
				list-style-type: none;
				margin: 0;

				li {
					display: inline-block;
					margin-top: 4%;
					margin-right: 4%;
					width: 22%;

					&:nth-child(4n) {
						margin-right: 0;
					}
				}
			}
		}
	}

	&.woocommerce-cart .cart_totals table {
		float: left;
		text-align: left;
	}

	&.woocommerce-checkout {

		.product-subtotal,
		.cart-subtotal,
		.order-total {
			.amount {
				.wpv-font(h5-);
				color: inherit;
				font-weight: bold;
				font-size: 1.3em;
			}
		}

		.customer_details {
			dt, dd {
				display: inline;
			}

			dt:before {
				display: block;
				content: "";
			}
		}

		.addresses {
			margin-top: @element-padding;
		}


		table.shop_table,
		table.shop_table th,
		table.shop_table td {
			border: 0;
			font-weight: normal;
			padding: 3px;
		}

		#order_review_heading,
		#payment {

		}


		h3 {
			margin-bottom: .8em;
			.wpv-font(h4-);
		}

		#payment {
			div.payment_box {
				background: @accent-color-7;
				box-shadow: none;
				text-shadow: none;

				&:after {
					border-bottom-color: @accent-color-7;
				}
			}
		}

		#shiptobilling {
			line-height: 2.7em;
		}

		.amount {
			color: @accent-color-3;
		}

		#place_order {
			.button-gen-common();
			.button-gen(@accent-color-1);
			.button-gen-hover(@accent-color-2);
		}
	}

	#reviews {
		h3 {
			margin: 0 0 20px;
			font-size: 16px;
		}

		#comments {
			.comments;

			ol.commentlist {
				li {
					margin-bottom: 0;
					padding: 15px 0;
					border-top: 1px dotted @default-line-color;

					img.avatar {
						position: relative;
						float: none;
						width: 60px;
					}

					.comment-meta {
						.wpv-color(primary-font-);

						div.star-rating {
							width: 7em !important;
							letter-spacing: 5px;
							font-size: 14px !important;

							span {
								color: @accent-color-1 !important;
								font-size: 14px !important;

								&:before {
									font-size: 14px !important;
								}
							}
						}
					}
				}
			}

			.add_review {
				margin-top: @element-padding;
			}
		}
	}

	#commentform .form-submit {
		position: static;

		input {
			.submit-button-style;
		}
	}

	html.placeholder & {
		label[for] {
			display: inline;
		}

		form .form-row label[for] {
			display: block;
			padding-bottom: 5px;

			&.checkbox {
				display: inline;
			}
		}
	}

	article img {
		display: inline-block;
	}

	div.product {
		.summary {
			form.cart {
				padding-left: 20px;
			}

			> div {
				padding-left: 20px;
			}

			.star-rating {
				margin: 13px 8px 15px 0;
				width: 7em;
				color: @accent-color-1;
				letter-spacing: 5px;
				font-size: 14px;

				span {
					&:before {
						font-size: 14px !important;
					}
				}
			}

			a.count {
				display: inline-block;
				margin: 10px 5px 15px 0;
				color: @accent-color-6;
				font-size: 10px;

				span.number {
					color: @accent-color-2;
				}
			}

			form.variations_form {
				table.variations {
					td {
						display: block;
						padding-bottom: 5px;
						select {
							margin: 0 0 5px 0;
						}
					}
				}

				.single_add_to_cart_button {
					.wpv-font(primary-font-);
					border-radius: 1px;
					background: @accent-color-1;
					color:@accent-color-8;
					text-transform: uppercase;
					font-weight: normal;

					&:hover,
					&:before,
					&:after {
						color: @accent-color-3 !important;
						text-decoration: none;
					}

					&:after {
						top: 2.2em;
						border-top: 1px solid @accent-color-3;
					}
				}
			}

			.share-btns {
				margin: 0 0 0 20px;
				padding: 0 0 20px 0;
			}

			.product_meta {
				margin: 0 0 0 20px;
				padding-left: 0;
			}

			.price {
				&, ins, del {
					.amount {
						.wpv-font(h2-);
					}
				}

				del {
					opacity: 1;
					display: inline-block;
					margin-right: .5em;

					&, .amount {
						color: @accent-color-7;
					}
				}
			}

			.stock {
				margin-left: 20px;

				&.out-of-stock {
					border-top: 1px solid @accent-color-7;
					padding: 25px 0 0 0;

					small {
						font-size: 2em !important;

						&:after {
							display: none;
						}
					}
				}
			}
		}
	}

	.price {
		&, ins {
			.amount {
				.wpv-font(h3-);
				font-style: normal;
				color: @accent-color-6;
				text-decoration: none !important;
			}
		}

		del {
			.amount {
				.wpv-font(h5-);
				color: @accent-color-6;
				text-decoration: line-through;
			}
		}
	}

	.images a img {
		box-shadow: none !important;
	}

	.product_meta {
		padding: 15px 0 0 0;
		border-top: 1px solid @default-line-color;

		span {
			line-height: 25px;
		}

		a {
			color: @css_link_color;

			&:hover {
				color: @css_link_hover_color;
			}

			&:visited {
				color: @css_link_visited_color;
			}
		}
	}

	table.shop_table {
		th,
		tfoot th td {
			font-weight: normal;
		}
	}

	&.woocommerce-cart {

		.button {
			padding: 0.6em 1em !important;
			text-shadow: none !important;
		}

		.cart-collaterals {
			.button {
				margin: 10px 10px 0 0;
				.button-gen-common();
				.button-gen(@accent-color-7);
				.button-gen-hover(@accent-color-2);
			}

			.checkout-button {
				.button-gen-common();
				.button-gen(@accent-color-1);
				.button-gen-hover(@accent-color-2);
				padding: 0.5em 1.4em;

				&:hover {
					color: @accent-color-8;
				}
			}
		}

		.coupon {
			margin-top: 30px;
			text-transform: uppercase;
			font-size: 16;
		}

		table.shop_table,
		table.shop_table th,
		table.shop_table td {
			border: 0;
		}

		table.shop_table {
			.product-thumbnail {
				img {
					width: 50px;
				}
			}

			td {
				border-top: 1px solid @default-line-color;
				border-bottom: 0;

				&.product-name a {
					font-size: 15px;
				}
			}

			a.remove:hover {
				background: none;
				color: red;
			}
		}

		.product-subtotal,
		.cart-subtotal,
		.order-total {
			.amount {
				.wpv-font(h5-);
				color: @h5-color;
				font-weight: bold;
				font-size: 1.3em;
			}
		}

		.cart_totals {
			th,
			th strong {
				font-weight: normal;
				padding: 0;
				text-transform: none !important;
			}

			table.shop_table {
				th,
				td {
					border-top: 1px solid @default-line-color;
					width: 50%;
				}
			}
		}



		.cart_totals,
		.shipping_calculator {
			width: auto;
			float: none;
		}

		.shipping-calculator-form {
			.button {
				.button-gen-common();
				.button-gen(@accent-color-7);
				.button-gen-hover(@accent-color-2);

				margin: 0;
			}

			.form-row {
				padding: 0;

				input {
					margin: 0 !important;
				}

				.calc_shipping_country_field {
					margin-bottom: 10px;
				}
			}
		}

		.cart_totals > h2,
		.shipping_calculator > h2  {
			.wpv-font(h4-);
			text-align: left;
		}

		.cart_totals > h2 {
			margin-top: 0;
		}

		.shipping-calculator-button {
			&:hover {
				text-decoration: none;
			}

			&:after {
				display: none;
			}
		}
	}

	.pp_content_container #respond #commentform .form-submit {

		input[type="submit"] {
			.submit-button-style;
			border: none !important;
			box-shadow: none !important;
			text-shadow: none;
		}
	}

	.add_review {
		a.button {
			.button-gen-common();
			.button-gen(@accent-color-1);
			.button-gen-hover(@accent-color-2);
			padding-right: .8em;
			padding-left: .8em;
			box-shadow: none;
			text-shadow: none;
		}
	}

	ul.cart_list a {
		.wpv-font(h5-);
		padding: 5px 0 10px 0;
		font-size: 14px;

	}

	ul.product-categories {
		li.current-cat {
			a {
				color: @css_link_hover_color;
			}
		}
	}

	.myaccount_user {
		padding-bottom: 70px;
	}

	.myaccount_address {
		padding-bottom: 30px;
	}

	#customer_login .lost_password {
		margin-left: 20px;
	}
}

body.woocommerce-checkout {
	form.login {
		margin-bottom: 5em;
	}

	.col-2 {
		border: 3px solid @accent-color-1;
		padding: 20px;
		.border-box();
	}
}

.cart-collaterals {
	width: auto !important;
	padding: 20px;
	border: solid 3px @accent-color-1;

	.cart_totals table tr:first-child th {
		width: 69%;
	}

	.cart_totals tr td {
		border: 0;
		padding: 3px !important;
	}
}

.woocommerce .page-wrapper,
.woocommerce .products {
	#review_form #respond .form-submit input,
	#submit,
	a.button,
	input.button,
	input[type=button],
	button.button {
		.button-gen-common();
		.button-gen(@accent-color-1);
		.button-gen-hover(@accent-color-2);
		.wpv-font(primary-font-);
		box-shadow: none;
		text-shadow: none;
		padding: 0.8em 1.6em;
		border: none;
		border-radius: 0;

	}

	.quantity {
		margin: 0 10px 0 0 !important;
		padding-top: 0;
	}
}

.woocommerce-page #review_form #respond p {
	margin: 0 0 10px;
}

.vamtam-cart-dropdown-link {
	position: relative;
	display: block;
	margin-top: -1px;
	margin-left: 2px;
	padding: 4px 0 4px 8px;
	width: 40px;
	height: 43px;
	background: transparent;
	color: @accent-color-6;
	text-align: center;
	font-size: 35px;
	line-height: 40px;
	cursor: pointer;
	transition: color .4s;

	body.sticky-header-type-over.sticky-header.wpv-not-scrolled &,
	body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled .layout-standard &,
	body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled .layout-logo-text-menu & {
		color: @main-menu-sticky-color;
	}

	.products {
		.border-box();
		position: absolute;
		top: 5px;
		right: 0px;
		z-index: 1;
		display: block;
		padding: 5px;
		width: 20px;
		height: 20px;
		border-radius: 100px;
		background: @accent-color-1;
		color: @accent-color-8;
		text-align: center;
		font-style: normal;
		font-size: 10px;
		font-family: @primary-font-face;
		line-height: 8px;
		font-weight: 900;


		&.cart-empty {
			background: @accent-color-7;
			.readable-color( @accent-color-7 );
		}
	}

	.icon {
		position: relative;
		top: 5px;
		float: left;
		font-size: 21px;
		color: @accent-color-4;
	}

	&:hover {
		text-decoration: none;
		color: @accent-color-1;
	}
}

.fixed-header-box {
	.cart-dropdown {
		display: table-cell;
		min-width: 50px;
		vertical-align: middle;

		&.hidden {
			display: none;
		}

		&:hover {
			.vamtam-cart-dropdown-link {
				z-index: 9999;
			}
		}

		&:not(:last-child) {
			.cart-dropdown-inner {
				width: 62px;
			}

			.vamtam-cart-dropdown-link {
				padding-right: 5px;
				padding-left: 15px;

				.products {
					right: 5px;
				}
			}

			.widget {
				width: 262px;
			}
		}

		.cart-dropdown-inner {
			width: 50px;
			height: 50px;
		}

		.widget {
			position: absolute;
			display: none;
			margin-left: -230px;
			padding: 15px;
			width: 250px;
			background-color: @accent-color-8;
			box-shadow: 0 2px 4px 2px rgba(0, 0, 0, 0.09);

			img {
				box-shadow: none;
			}
		}
	}
}
