#bbpress-forums {
	p.bbp-topic-meta,
	ul.bbp-reply-revision-log,
	ul.bbp-topic-revision-log,
	div.bbp-template-notice,
	.widget_display_topics,
	.widget_display_replies,
	p.bbp-topic-meta {
		img.avatar {
			display: inline-block;
			margin-bottom: 0 !important;

			&.avatar-14 {
				display: none !important;
			}
		}
	}

	.bbp-topic-started-by img {
		display: none !important;
	}

	#bbp_search {
		width: 200px;
		margin-right: 10px;
	}

	#bbp-search-form {
		margin-bottom: 10px;
	}

	.bbp-forum-title {
		.wpv-font(h3-);
	}

	.bbp-forum-info .bbp-forum-content,
	p.bbp-topic-meta {
		.wpv-font(primary-font-);
	}

	.bbp-breadcrumb {
		p {
			margin: 0;
		}
	}

	#subscription-toggle {
		float: right;
	}
}