.show-hidpi-inline,
.show-hidpi-block {
	display: none;
}

@media only screen and (-webkit-min-device-pixel-ratio: 1.5),
       only screen and (min-resolution: 144dpi) {
	.hide-hidpi {
		display: none;
	}

	.show-hidpi-inline {
		display: inline;
	}

	.show-hidpi-block {
		display: block;
	}
}