@site-min-width: 290px;
@menubar-height: 40px;
@default-bg-color: @main-background-color;
@default-line-color: @accent-color-7;
@dark-bg-color: #444;
@dark-line-color: @dark-bg-color + #222;

@header-background-attachment:scroll;
@title-background-attachment:scroll;
@subfooter-background-attachment:scroll;
@body-background-position:center top;
@main-background-opacity: 1;
@pail-bg-color: @accent-color-8;

@small-padding: 20px;

@content-padding: 30px;
@element-padding: 30px;

@content-padding-large: 60px;
@element-padding-large: 60px;

@horizontal-padding: @content-padding;
@vertical-padding: @element-padding;

@horizontal-padding-large: @content-padding-large;
@vertical-padding-large: @element-padding-large;


@aside-padding: 20px;