.form-input {
	position: relative;
	margin: 0;
	background: @accent-color-7;

}

input[type=text],
input[type=tel],
input[type=email],
input[type=password],
input[type=email],
input[type=search],
input[type=date],
input[type=range],
input[type=number],
input[type=button],
input[type=tel],
textarea,
select {
	.border-box();
	padding: 17px;
	width: 100%;
	position: relative;
	border: none;
	outline: none;
	border: solid 1px fade(@accent-color-6, 10%);
	margin: 0;
	box-shadow: none !important;
	font-size: 18px;
	border-radius: 0px;
	margin-bottom: 15px;
	background: @accent-color-8;
	color: @accent-color-6;

	div.wpcf7 & {
		width: 100%;
		position: relative;
		outline: none;
		border-bottom: 1px solid transparent;
		margin: 0 0 20px 0;
		box-shadow: none !important;
		font-size: 14px;
		border-radius: 0px;
		background: @accent-color-8;
		color: @accent-color-6;
		padding: 10px;
		font-weight: 200;
		transition: all .2s ease;
		border: solid 1px fade(@accent-color-6, 10%);
		margin-top: 5px;

		&:hover {
			-moz-box-shadow:  0px 2px 4px 0px rgba(0,0,0,0.05) !important;
			box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05) !important;
			border: solid 1px rgba(0, 0, 0, 0.2);
		}
	}

	&:focus {
		border: 1px solid @accent-color-1 !important;
	}

	&.invalid {
		border-color: #D94729;
	}
	&:-moz-ui-invalid {
		border-color: #D94729;
	}

	.wpv-main & {
		.formElementColors(@main-background-color);
	}
	footer.main-footer & {
		.formElementColors(@footer-background-color);
	}
	.fixed-header-box & {
		.formElementColors(@header-background-color);
	}
}

.form-input .required {
	display: none;
}

textarea {
	min-height: 6em;
	width: 100%;
	position: relative;
	resize: none;
	font-size: 18px;
}

html.placeholder .dgx-donate-form-section label[for],
html.placeholder form.wpcf7-form label[for] {
	display: inline-block;
}

.select2-container {
	.select2-choice {
		background: @accent-color-8;
		font-size: 14px;
		height: 20px;
		border-radius: 0px;
		color: @accent-color-6;
		border: solid 1px fade(@accent-color-6, 10%);
		box-shadow: none;
		font: inherit;
		padding: 10px;
		transition: all .2s ease;
	}
}

.select2-drop-active {
	border-color: fade(@accent-color-6, 10%);
	border-radius: 0;
}

.select2-results {
	background-color: @accent-color-8;
}