/*! SocialCount - v0.2.0 - 2015-11-23
* https://github.com/filamentgroup/SocialCount
* Copyright (c) 2015 zachleat; Licensed  */

/* Base CSS */

.socialcount {
	list-style: none;
	padding-left: 0;
	margin: 0 0 .6em 0;
	overflow: hidden;
}
.socialcount-large {
	line-height: normal;
}
.socialcount :link,
.socialcount :visited {
	color: inherit;
}
.socialcount > li {
	display: inline-block;
	*display: inline;
	zoom: 1;
	position: relative;
	vertical-align: top;
	min-width: 80px;
	min-height: 30px;
	text-align: center;
	white-space: nowrap;
	*margin-right: 4px;
}
.socialcount-small > li {
	min-width: 0;
}
.socialcount-large > li {
	float: left;
	margin: 0 .6em .6em 0;
	min-width: 105px;
}

.socialcount > li > a {
	display: block;
	padding: 0 5px;
	text-decoration: none;
	color: inherit;
}
.socialcount-small > li > a {
	padding-left: 8px;
	padding-right: 8px;
}
.socialcount-large > li > a {
	padding: 12px 5px 8px;
}

.socialcount .count {
	color: inherit;
	position: relative;
	display: inline-block;
	*display: inline;
	zoom: 1;
	text-align: center;
	margin-left: 6px;
}
.socialcount-large .count {
	display: block;
	width: 100%;
	margin-left: 0;
	padding-top: 10px;
}
.socialcount-small .count {
	margin-left: 0;
}

.socialcount .socialcount-button {
	display: none;
	width: 100%;
	position: absolute;
	left: 0;
	top: 5px;
	text-align: center;
	pointer-events: none;
	line-height: 100%;
}
.socialcount .socialcount-button iframe {
	pointer-events: auto;
}
.socialcount-large .socialcount-button {
	top: auto;
	bottom: 2px;
}

.socialcount.grade-a.activate-on-hover > li.hover.loaded .count,
.socialcount.grade-a.activate-on-click > li.hover.loaded .count {
	text-indent: -999px;
}

.socialcount.grade-a.activate-on-hover > li.hover.loaded .socialcount-button,
.socialcount.grade-a.activate-on-click > li.hover.loaded .socialcount-button {
	display: block;
}
.socialcount.grade-a.activate-on-hover > li.hover.loaded > a,
.socialcount.grade-a.activate-on-click > li.hover.loaded > a {
	cursor: default;
}
.socialcount-small.grade-a.activate-on-hover > li.hover.loaded > a,
.socialcount-small.grade-a.activate-on-click > li.hover.loaded > a,
.socialcount.grade-a.activate-on-hover > li.hover.loaded .socialcount-button iframe,
.socialcount.grade-a.activate-on-click > li.hover.loaded .socialcount-button iframe {
	cursor: pointer;
}

.socialcount.like.de_DE > .facebook {
	min-width: 90px; /* like */
}
.socialcount.recommend .facebook {
	min-width: 120px;
}
.socialcount-small.recommend .facebook {
	min-width: 0;
}

.socialcount-large.recommend .facebook {
	min-width: 105px;
}

.socialcount .facebook iframe {
	height: 21px;
	width: 90px; /* recommend */
}
.socialcount.de_DE .facebook iframe {
	width: 83px; /* recommend */
}
.socialcount.fr_FR .facebook iframe {
	width: 98px; /* recommend */
}
.socialcount.like .facebook iframe {
	width: 48px; /* like */
}
.socialcount.like.de_DE .facebook iframe {
	width: 83px; /* like */
}
.socialcount.like.fr_FR .facebook iframe {
	width: 57px; /* like */
}
.socialcount .pinterest {
	display: none;
}
.socialcount.js .pinterest {
	display: inline-block;
	*display: inline;
	zoom: 1;
}
.socialcount .pinterest .socialcount-button {
	bottom: 0;
	pointer-events: auto;
}
.socialcount-large .pinterest .socialcount-button {
	bottom: 10px;
}
.socialcount > .pinterest:hover {
	cursor: pointer;
}
.socialcount-small .pinterest .count {
	text-indent: -999px;
}


.socialcount .loading {
	position: absolute;
	left: 0;
	top: 0;
	width: 100%;
	height: 100%;
	z-index: 3;
	background-color: #aaa;
	background-color: rgba(170, 170, 170, 0.7);
	color: #000;
	text-transform: uppercase;
	font-size: .75em;
	text-align: center;
	border-radius: 5px;
}
.socialcount-large .loading {
	padding-top: 30%;
}
.socialcount .loading .dot {
	display: inline-block;
	/* no ie7 compat needed here, just shows the text links */
	width: 6px;
	height: 6px;
	margin: 0 3px;
	background: #fff;
	opacity: 0;
	border-radius: 50%;

	-webkit-animation: socialCountLoadingFade .6s infinite;
	-moz-animation: socialCountLoadingFade .6s infinite;
	animation: socialCountLoadingFade .6s infinite;
}

.socialcount .loading .dot:nth-child(1) {
	-webkit-animation-delay: 0s;
	-moz-animation-delay: 0s;
	animation-delay: 0s;
}

.socialcount .loading .dot:nth-child(2) {
	-webkit-animation-delay: .05s;
	-moz-animation-delay: .05s;
	animation-delay: .05s;
}

.socialcount .loading .dot:nth-child(3) {
	-webkit-animation-delay: .1s;
	-moz-animation-delay: .1s;
	animation-delay: .1s;
}

@-webkit-keyframes socialCountLoadingFade {
	0% { opacity: 0; }
	50% { opacity: 0.8; }
	100% { opacity: 0; }
}

@-moz-keyframes socialCountLoadingFade {
	0% { opacity: 0;  }
	50% { opacity: 0.8; }
	100% { opacity: 0; }
}

@keyframes socialCountLoadingFade {
	0% { opacity: 0; }
	50% { opacity: 0.8; }
	100% { opacity: 0; }
}



/* Skin CSS */

.socialcount {
	margin-top: 30px;
	color: @accent-color-6;

	> li {
		background-color: @accent-color-7;
		min-height: 0;

		> a {
			line-height: 2.2em;
			transition: color .3s ease-out;

			&:hover {
				color: @css_link_hover_color;
			}
		}
	}

	> li,
	> li > a:focus,
	.sc-loading {
		border-radius: 1px;
	}

	/* Special class added to count when it's >= the minimum */
	.count.minimum {}
}