@font-face {
	/* long urls because we want to keep the icon fonts in vamtam/ */
	font-family: 'icomoon';
	src: url(../vamtam/assets/fonts/icons/icons.eot);
	src: url(../vamtam/assets/fonts/icons/icons.eot?#iefix) format('embedded-opentype'),
		url(../vamtam/assets/fonts/icons/icons.ttf) format('truetype');
	font-weight: normal;
	font-style: normal;
}

@font-face {
	font-family: 'theme';
	src: url(../wpv_theme/assets/fonts/icons/theme-icons.eot);
	src: url(../wpv_theme/assets/fonts/icons/theme-icons.eot?#iefix) format('embedded-opentype'),
		url(../wpv_theme/assets/fonts/icons/theme-icons.ttf) format('truetype');
	font-weight: normal;
	font-style: normal;
}

.icon {
	&, &-a:after, &-b:before {
		font-family: 'icomoon' !important;
		font-weight: normal !important;
		font-style: normal !important;
		display: inline-block;
		min-width: 1em;
		-webkit-font-smoothing: antialiased;
		-moz-osx-font-smoothing: grayscale;

		.theme& {
			font-family: 'theme' !important;
		}

		.custom& {
			font-family: 'vamtam-custom-icons' !important;
		}
	}
}

.icon-b:before, .icon-a:after { content: " " attr(data-icon) " "}
.icon-b.size-small:before, .icon-a.size-small:after, .icon.size-small { font-size: 16px }
.icon-b.size-medium:before, .icon-a.size-medium:after, .icon.size-medium { font-size: 24px }
.icon-b.size-large:before, .icon-a.size-large:after, .icon.size-large { font-size: 32px }
.icon-b.icon-a:before { content: " " attr(data-iconb) " "}
.icon-b.icon-a:after { content: " " attr(data-icona) " "}
.icon-b:before { padding-right: .5em }
.icon-a:before { padding-left: .5em }

/**
 * html5doctor.com Reset Stylesheet (Eric Meyer's Reset Reloaded + HTML5 baseline)
 * v1.6.1 2010-09-17 | Authors: Eric Meyer & Richard Clark
 * html5doctor.com/html-5-reset-stylesheet/
 */

html, body, div, span, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
abbr, address, cite, code, del, dfn, em, img, ins, kbd, q, samp,
small, strong, sub, sup, var, b, i, dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, canvas, details, figcaption, figure,
footer, header, hgroup, menu, nav, section, summary,
time, mark, audio, video {
	margin: 0;
	padding: 0;
	border: 0;
	font-size: 100%;
	font: inherit;
	vertical-align: baseline;
}

html, body {
	overflow-x: hidden;
	-webkit-tap-highlight-color: rgba(0, 0, 0, 0);
	-webkit-text-size-adjust: 100%;
	-webkit-overflow-scrolling: touch;
}
body {
	overflow: hidden;
}

article, aside, details, figcaption, figure,
footer, header, hgroup, menu, nav, section {
	display: block;
}

blockquote, q { quotes: none; }

blockquote:after,
q:before, q:after { content: ""; content: none; }

ins { color: @accent-color-2; text-decoration: none; }

mark { background-color: #ff9; color: #000; font-style: italic; font-weight: bold; }

del { text-decoration: line-through; }

abbr[title], dfn[title] { border-bottom: 1px dotted; cursor: help; }

table { border-collapse: collapse; border-spacing: 0; }

hr { display: block; height: 1px; border: 0; border-top: 1px solid #ccc; margin: 1em 0; padding: 0; }

input, select { vertical-align: middle; }


/**
 * Font normalization inspired by YUI Library's fonts.css: developer.yahoo.com/yui/
 */

body { font:13px/1.231 sans-serif; *font-size:small; } /* Hack retained to preserve specificity */
select, input, textarea, button { font:99% sans-serif; }

/* Normalize monospace sizing:
   en.wikipedia.org/wiki/MediaWiki_talk:Common.css/Archive_11#Teletype_style_fix_for_Chrome */
pre, code, kbd, samp { font-family: monospace, sans-serif; }

:disabled { cursor: not-allowed; }
/**
 * Minimal base styles.
 */

/* Accessible focus treatment: people.opera.com/patrickl/experiments/keyboard/test */
a:hover, a:active { outline: none; }

/* Remove margins for navigation lists */
nav ul, nav li { margin: 0; list-style:none; list-style-image: none; }

small { font-size: 85%; }
b, strong, th { font-weight: bold; }

td { vertical-align: top; }

/* Set sub, sup without affecting line-height: gist.github.com/413930 */
sub, sup { font-size: 75%; line-height: 0; position: relative; }
sup { top: -0.5em; }
sub { bottom: -0.25em; }

pre {
	/* www.pathf.com/blogs/2008/05/formatting-quoted-code-in-blog-posts-css21-white-space-pre-wrap/ */
	white-space: pre; white-space: pre-wrap; word-wrap: break-word;
	padding: 15px;
}

textarea { overflow: auto; } /* www.sitepoint.com/blogs/2010/08/20/ie-remove-textarea-scrollbars/ */

/* Align checkboxes, radios, text inputs with their label by: Thierry Koblentz tjkdesign.com/ez-css/css/base.css  */
input[type="radio"] { vertical-align: text-bottom; }
input[type="checkbox"] { vertical-align: middle; }

/* Hand cursor on clickable input elements */
label, input[type="button"], input[type="submit"], input[type="image"], button { cursor: pointer; }

button, input, select, textarea {
	/* Webkit browsers add a 2px margin outside the chrome of form elements */
	margin: 0;

	box-shadow: none;
	border-radius: 0;
}

button {
	padding: 0;
}

button, input[type="button"], input[type="submit"] {
	-webkit-appearance: none;
	background-image: none;
}

/* Make buttons play nice in IE:
   www.viget.com/inspire/styling-the-button-element-in-internet-explorer/ */
button {  width: auto; overflow: visible; }

select, input, textarea { color: #444; }

/* For image replacement */
.ir { display: block; text-indent: -999em; overflow: hidden; background-repeat: no-repeat; text-align: left; direction: ltr; }

/* Hide for both screenreaders and browsers:
   css-discuss.incutio.com/wiki/Screenreader_Visibility */
.hidden { display: none; visibility: hidden; }

/* Hide only visually, but have it available for screenreaders: by Jon Neal.
  www.webaim.org/techniques/css/invisiblecontent/  &  j.mp/visuallyhidden */
.screen-reader-text, .visuallyhidden { border: 0; clip: rect(0 0 0 0); height: 1px; margin: -1px; overflow: hidden; padding: 0; position: absolute; width: 1px; }
/* Extends the .visuallyhidden class to allow the element to be focusable when navigated to via the keyboard: drupal.org/node/897638 */
.visuallyhidden.focusable:active,
.visuallyhidden.focusable:focus { clip: auto; height: auto; margin: 0; overflow: visible; position: static; width: auto; }

/* Hide visually and from screenreaders, but maintain layout */
.invisible { visibility: hidden; }

html.no-js .nojs-hide { display: none }

.disable-hover { pointer-events: none }