.page-404 {
	position: relative;
	padding : 0 @content-padding 0.035px;
	text-align: center;

	.searchform {
		position: relative;
		display: block;
		margin: 0 auto 100px auto;
		max-width: 812px;
	}

	input[name=s] {
		.border-box();
		z-index: 1;
		padding: 5px 122px 5px 10px;
		width: 100%;
		height: 45px;
		font-style: italic;
		font-size: 15px;

		&:focus {
			font-style: normal;
		}
	}

	input[type=submit] {
		position: absolute;
		top: 3px;
		right: 3px;
		bottom: 3px;
		z-index: 3;
		padding: 0 1em;
		height: 40px;
		font-size: 16px;
	}
}

#header-404 {
	display: block;
	margin: 0 auto;
	padding-top: 100px;
	padding: 30px;
	height: 324px;
	width: auto;
	max-width: 812px;
	background: url("@{theme-images-dir}404_bg.png") no-repeat bottom right;
	color: @accent-color-4;
	text-align: left;

	.line-1 {
		font: e(@h2-weight) 70px/1 @h2-face;
		color: @accent-color-1;
	}

	.line-2 {
		font: e(@h2-weight) 50px/1.1 @h2-face;
		color: @accent-color-6;
		line-height: 0.8em;
		padding-bottom: 20px;
	}

	.line-3 {
		font: e(@h2-weight) 20px/1 @h2-face;
		color: @accent-color-6;
	}

	.line-4 {
		margin-top: 80px;
		color: @accent-color-6;
	}
}