.vamtam-icon {
	font-family: 'vamtam-icomoon';

	&.theme-icon {
		font-family: 'vamtam-theme';
	}

	&.custom-icon {
		font-family: 'vamtam-custom-icons';
	}
}

.va-icon, [class^="va-icon-"]:before, [class*=" va-icon-"]:before {
	font-family: 'vamtam-admin' !important;
	font-style: normal;
	speak: none;
	font-weight: normal;
	line-height: 1;
	-webkit-font-smoothing: antialiased;
}

.va-icon-undo-char { content: "\e000"; }
.va-icon-undo:before { .va-icon-remove-char }

.va-icon-info-char { content: "\e001"; }
.va-icon-info:before { .va-icon-info-char }

.va-icon-pencil-char { content: "\e002"; }
.va-icon-pencil:before { .va-icon-pencil-char }

.va-icon-lines-char { content: "\e003"; }
.va-icon-lines:before { .va-icon-lines-char }

.va-icon-remove-char { content: "\e004"; }
.va-icon-remove:before { .va-icon-remove-char }

.va-icon-vamtam-char { content: "\e005"; }
.va-icon-vamtam:before { .va-icon-vamtam-char }