.widget_post_formats {
	.post-format-pad { 
		position: relative;
		left: auto;
		float: left;
		margin: @small-padding/4;
		padding: 0px !important;
		width: 30px;
		height: 30px;
		border: none;
		
		* {
			margin-top: 0px !important;
			margin-left: 1px !important;
		}
		
		a {
			width: 28px;
			height: 28px;
			display: block;
			font-size: 18px;
			line-height: 28px;
			text-align: center;
			padding: 0 !important;
			
			&:hover {
				text-decoration: none !important;
			}
		}

		.icon {
			color: @accent-color-6;
			
			&:hover {
				color: @css_link_hover_color;	
			}
			
			&:visited {
				color: @css_link_visited_color;	
			}
			
			&.standard {
				padding-top: 2px !important;
							
				span.icon {
					vertical-align: inherit;
				}
			}
		}
	}
}