@font-face {
	font-family: 'vamtam-admin';
	src:url('../fonts/vamtam-admin.eot');
	src:url('../fonts/vamtam-admin.eot?#iefix') format('embedded-opentype'),
		url('../fonts/vamtam-admin.svg#vamtam-admin') format('svg'),
		url('../fonts/vamtam-admin.woff') format('woff'),
		url('../fonts/vamtam-admin.ttf') format('truetype');
	font-weight: normal;
	font-style: normal;
}

@font-face {
	font-family: 'vamtam-icomoon';
	src: url(../../../assets/fonts/icons/icons.eot);
	src: url(../../../assets/fonts/icons/icons.eot?#iefix) format('embedded-opentype'),
		url(../../../assets/fonts/icons/icons.ttf) format('truetype');
	font-weight: normal;
	font-style: normal;
}

@font-face {
	font-family: 'vamtam-theme';
	src: url(../../../../wpv_theme/assets/fonts/icons/theme-icons.eot);
	src: url(../../../../wpv_theme/assets/fonts/icons/theme-icons.eot?#iefix) format('embedded-opentype'),
		url(../../../../wpv_theme/assets/fonts/icons/theme-icons.ttf) format('truetype');
	font-weight: normal;
	font-style: normal;
}

@font-face {
	font-family: 'vamtam-custom-icons';
	src: url(../../../../../../vamtam/custom-icon-font/custom-icons.eot);
	src: url(../../../../../../vamtam/custom-icon-font/custom-icons.eot?#iefix) format('embedded-opentype'),
		url(../../../../../../vamtam/custom-icon-font/custom-icons.ttf) format('truetype');
	font-weight: normal;
	font-style: normal;
}

@import "va-icon-chardef.less";

#toplevel_page_wpv_general .wp-menu-image,
.mce-ico.mce-i-wpv_shortcodes {
	text-align: center;

	&:before {
		display: inline-block;
		.va-icon;
		.va-icon-vamtam-char;
	}

	img {
		display: none !important;
	}
}

#toplevel_page_wpv_general .wp-menu-image {
	&:before {
		font-size: 20px;
		padding: 8px 0;
	}
}

.mce-ico.mce-i-wpv_shortcodes {
	&:before {
		font-size: 20px;
		padding: 2px 0;
	}

	.content {
		border: 0; clip: rect(0 0 0 0); height: 1px; margin: -1px; overflow: hidden; padding: 0; position: absolute; width: 1px;
	}
}