.team-member-row {
	position: relative;
	z-index: 60;

	> div { // columns
		position: static;
	}
}

/* Force floats adjustment */
@media all and (-webkit-min-device-pixel-ratio: 0) {
	.team-member-row {
		display: inline-table;
		width: 100%;
		table-layout: fixed;
	}
}

.team-member {
	text-align: left;
	border: solid 1px fade(@accent-color-6, 10%);
	padding-top: 0 !important;
	padding-bottom: 0 !important;
	margin: 10px 0;

	.thumbnail {
		overflow: hidden;
		background: @accent-color-6;
		position: relative;
	}

	img {
		-webkit-backface-visibility: hidden;
		-webkit-transition: opacity 0.35s, -webkit-transform 0.35s;
		transition: opacity 0.35s, transform 0.35s;
		.transform( ~"translate3d(0,0,300px)" );
		width: 100%;
	}

	html.no-touch &:hover {
		box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);

		img {
			opacity: 0.6;
			.transform( scale(1.15) );
		}
	}

	html.touch &,
	&:hover {
		.share-icons {
			.transform( ~"translate3d(0,0,0)" );
			opacity: 1;
			bottom: 40%;
			white-space: normal;

			.icon {
				margin: 10px 5px 0px 5px;
			}
		}
	}

	.sep-text {
		margin: 0 0 20px 0;
	}

	.team-member-info {
		background: @accent-color-8;
		margin-top: 0px;
		padding: 15px 20px 25px 20px;

		h3 {
			margin-top: 5px;
			margin-bottom: 0;
			font-style: normal;
			font-size: 20px;

			a {
				font-size: inherit;
				font-style: normal;
				color: @h3-color;
				font-weight: normal;

				&:hover {
					color: @accent-color-1;
				}
			}
		}

		h5 {
			margin-top: 0;
			padding-bottom: 15px;
			color: @accent-color-2 !important;
			font-weight: normal;
			margin-top: 5px;
			border-bottom: none;
			font-weight: inherit;
			margin-bottom: 0px;
		}

		a[href^="mailto:"] {
			word-wrap: break-word;
		}
	}

	.team-member-position {
		text-transform: uppercase;
		font-size: 11px;

	}

    .team-member-phone {
    	padding-bottom: 5px;

    }

	.description {
		padding: 0 20px;
	}

	.share-icons {
		margin-top: 10px;
		white-space: nowrap;
		position: absolute;
		left: 0;
		top: auto;
		height: auto;
		-webkit-transition: -webkit-transform 0.35s;
		transition: transform 0.35s;
		.transform( ~"translate3d( 0, 100%, 0 )" );
		bottom: 30%;
		width: 100%;
		margin: 0px;
		padding: 0px;
		text-align: center;
		opacity: 0;
		background: none;

		a {
			&:hover {
				.icon.shortcode.use-hover {
					background: @accent-color-8;
					color: @accent-color-1 !important;
				}
			}
		}

		html.touch & {
			.transform( ~"translate3d( 0, 0, 0 )" );
		}

		.icon {
			margin: 0px 5px 0px 5px;
			width: 16px;
			height: 16px;
			color: @accent-color-8;
			text-align: center;
			font-size: 16px !important;
			line-height: 1;
			display: inline-block;
			padding: 10px;
			border-radius: 100%;
			border: solid 1px fade(@accent-color-8, 50%);
			background: transparent;

			&:hover {
				.transition(color .5s ease 0s);
				color: @accent-color-1;
			}
		}
	}

	.description {
		display: none;
	}

	.team-member-bio {
		border: none;
		padding: 0px 20px 25px 20px;
		margin-top: 0px;
	}
}
