.load-more,
.wp-pagenavi {
	clear: both;
	margin-top: 50px;

	.products + & {
		margin-top: 0;
	}
}

.wp-pagenavi {
	text-align: center;
	border-top: 1px solid @default-line-color;
	z-index: 100;
	position: relative;
	text-align: right;
	padding: 20px 0 40px;

	&:last-child {
		padding-bottom: 0;
	}

	article > .page-content > section.portfolios > & {
		margin: 0 10px 30px;
	}

	a, span {
		margin: 1px !important;
		border: none !important;
		display: inline-block;
		padding: 2px 8px 3px 8px !important;
		font-size: 12px;
	}

	.current {
		background-color: @accent-color-1;
		color: @accent-color-8;
		font-size: 12px;
		font-weight: normal !important;
		margin: 0px 0px 0px 5px !important;
	}

	a {
		transition: all 0.3s;
		border: solid 1px @accent-color-7 !important;
		margin: 0px 0px 0px 5px !important;
	}

	a:hover,
	.current {
		background-color: @accent-color-1;
		border: solid 1px @accent-color-1 !important;
		color: @accent-color-5;
	}

	.previouspostslink,
	.nextpostslink {
		color: transparent !important;
		background: @accent-color-8;
		width: 23px;
		height: 23px;
		text-align: center;
		line-height: 23px;
		padding: 0 !important;

		&:after {
			color:@css_link_color;
			font-size: 11px;
			font-family: theme;
			left: -2px;
			position: relative;
			font-weight: normal !important;

			&:hover {
				color: @css_link_hover_color;
			}

		}
	}

	.previouspostslink:after {
		content: icon(theme-angle-left);
	}

	.nextpostslink:after {
		content: icon(theme-angle-right);
	}

	span.pages {
		float: left;
		.wpv-font(primary-font-);
		font-size: 12px;
		padding: 0 !important;
	}

	a.page {
		background: @accent-color-8;
		color:@css_link_color;
		font-size: 12px;

		&:hover {
			color:@css_link_hover_color;
		}

		&:visited {
			color:@css_link_visited_color;
		}
	}

	a,
	span,
	span.pages,
	.current {
		font-size: 1.2em;
	}
}

.comment-paging {
	border-top: 0;
	margin-top: -(@content-padding + 10px);
	margin-bottom: @content-padding + 10px;
	padding-top: 0;

	a, span {
		margin: 1px !important;
		border: none !important;
		display: inline-block;
		padding: 2px 8px 3px 8px !important;
		font-size: 12px;
	}

	.current {
		background-color: @accent-color-7;
		color: @accent-color-8;
		font-size: 12px;
		font-weight: normal !important;
	}

	.prev,
	.next {
		color: transparent !important;
		background: @accent-color-8;
		width: 23px;
		height: 23px;
		text-align: center;
		line-height: 22px;
		padding: 0 !important;
		text-indent: -200px;

		&:after {
			color:@css_link_color;
			font-size: 12px;
			font-family: theme;
			position: relative;
			font-weight: normal !important;

			&:hover {
				color: @css_link_hover_color;
			}
		}
	}

	.prev {
		&:after {
			content: icon(theme-angle-left);
			left: 70px;
		}
	}

	.next {
		&:after {
			content: icon(theme-angle-right);
			left: 83px;
		}
	}

	span.pages {
		float: left;
		.wpv-font(primary-font-);
		padding: 0 !important;
	}

	a.page-numbers {
		background: @accent-color-8;
		color:@css_link_color;
		font-size: 12px;

		&:hover {
			color:@css_link_hover_color;
		}

		&:visited {
			color:@css_link_visited_color;
		}
	}
}

.load-more {
	margin: 50px auto 50px auto;
	position: relative;
	text-align: center;

	&.loading {
		background: url(../wpv_theme/assets/images/loader.gif) center center no-repeat;
		background-image: url(../wpv_theme/assets/images/loader.gif),url(../wpv_theme/assets/images/loader_bg.png);
		background-position: center center, center center;
	}

	.button.lm-btn {
		border: 2px solid darken(@accent-color-7, 10%);
		background: none;
		box-shadow: none;
		padding: 0;
		max-width: 380px;
		width: 100%;
		border-radius: 0px;

		span {
			color: darken(@accent-color-7, 10%);
			padding: 0.8em 0 !important;
			position: relative;
			z-index: 555;
			text-transform: uppercase;
			font: 500 1.4em/1 @h4-face;

			&:hover {
				text-decoration: none;
			}
		}

		&:hover {
			border-color: @accent-color-1;

			span {
				color: @accent-color-1 !important;
			}
		}
	}

	+ .share-btns {
		margin-top: 30px;
	}
}
