@media (min-width: 959px) and (max-width: 1280px) {
	.responsive-layout {
		#ss-teaser,
		#style-switcher,
		#feedback-wrapper {
			display: none !important;
			height: 0 !important;
			width: 0 !important;
			right: auto !important;
			left: -10000px !important;
		}

		.loop-wrapper.news,
		.portfolios > ul {
			> .grid-1-4 {
				width: percentage(1/3);

				&:nth-child(3n+1) {
					clear: both;
				}
			}

			> .grid-1-3:nth-child(3n+1),
			> .grid-1-2:nth-child(2n+1) {
				clear: both;
			}
		}

		header.main-header {
			position: relative;
			top: 0;
			right: 0;
			left: 0;
			margin: 0;

			.header-left {
				.border-radius(0);
				display: none;
			}

			#header-text {
				display: none;
			}

			.header-right {
				display: none;
			}

			.second-row {
				.second-row-columns {
					display: block;
				}
			}
		}

		.page-wrapper {
			aside.left,
			aside.right {
				padding-left: @small-padding;
				padding-right: @small-padding;
			}
		}

		#footer-sidebars {
			> .row .widget {
				padding-left: @small-padding;
				padding-right: @small-padding;
			}
		}

		.vamtam-booking-form {
			.wpv-grid .wpv-grid {
				&:first-child {
					width: 100%;
				}

				&:last-child {
					width: 200%;
					margin-left: -100%;
					margin-top: 5px;
				}
			}
		}
	}
}

@media (min-width: 959px) and (max-width: @site-max-width) {
	.responsive-layout {
		.page-content {
			> .limit-wrapper {
				padding-left: 30px;
				padding-right: 30px;
			}
		}
	}
}

@media (max-width: @site-max-width + 120px ) {
	header.main-header .first-row {
		box-sizing: border-box;
	}
}