ul, ol {
	margin: 0.4em 0px 0.4em 1.3em;
}
ul li, ol li {
	padding-bottom: 4px;
	padding-top: 4px;
}

.styled-list {
	padding:0;
	margin-left:0.3em;
	list-style:none;

	li {
		padding-left: 1.5em;
		text-indent: -1.5em;

		&:before {
			text-indent: 0;
		}
	}

	&.icon-accent1 li:before { color: @accent-color-1 }
	&.icon-accent2 li:before { color: @accent-color-2 }
	&.icon-accent3 li:before { color: @accent-color-3 }
	&.icon-accent4 li:before { color: @accent-color-4 }
	&.icon-accent5 li:before { color: @accent-color-5 }
	&.icon-accent6 li:before { color: @accent-color-6 }
	&.icon-accent7 li:before { color: @accent-color-7 }
	&.icon-accent8 li:before { color: @accent-color-8 }
}