#wpv_visual_editor {

	// helpers
	.ui-helper-hidden { display: none; }
	.ui-helper-hidden-accessible { position: absolute !important; clip: rect(1px 1px 1px 1px); clip: rect(1px,1px,1px,1px); }
	.ui-helper-reset { margin: 0; padding: 0; outline: 0; border: 0; list-style: none; text-decoration: none; font-size: 100%; line-height: 1.3; }
	.ui-helper-clearfix:after { display: block; visibility: hidden; clear: both; height: 0; content: "."; }
	.ui-helper-clearfix { display: inline-block; }
	.ui-helper-clearfix { display:block; }
	.ui-helper-zfix { position: absolute; top: 0; left: 0; width: 100%; height: 100%; opacity: 0; filter:Alpha(Opacity=0); }

	// tabs
	.ui-tabs {
		position: relative;
		zoom: 1;

		.ui-tabs-nav {
			margin: 0;
			padding: 0;

			li {
				.transition(all .3s ease);
				display: inline-block;
				float: left;
				overflow: hidden;
				margin: 0 6px -1px 0;
				padding: 0;
				padding: 4px 14px 6px;
				border-width: 1px;

				border-style: solid;
				border-color: #DFDFDF;
				border-radius: 3px 3px 0 0;

				background: #FBFBFB;
				list-style: none;
				text-decoration: none;
				text-shadow: white 0 1px 0;
				white-space: nowrap;

				display: flex;
				align-items: center;

				.tab-icon-selector {
					float: left;
					margin-left: .5em;
					padding: 3px;
					width: 1em;
					height: 1em;
					border-radius: 2px;
					background: #fff;
					color: #666;
					text-align: center;
					font-size: 14px;
					font-family: "vamtam-icomoon";
					line-height: 1;
					cursor: pointer;
					order: -1;

					&.theme {
						font-family: "vamtam-theme";
					}

					&.no-icon {
						text-indent: -9999px;

						&:before {
							display: block;
							content: icon(pencil);
							text-indent: 0;
							font-size: 11px;
							line-height: 14px;
						}
					}
				}

				.tab-title {
					float: left;
					color: #AAA;
					text-decoration: none;
					font-size: 14px;
					font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
					line-height: 16px;
					cursor: pointer;

					input {
						margin: -.3em 0;
					}
				}

				&.ui-tabs-active {
					border-bottom-color: #F9F9F9;
					background: #F9F9F9;
					-webkit-box-shadow: inset 0 1px 0 white;
					box-shadow: inset 0 1px 0 white;

					.tab-title {
						color: #464646;
						cursor: normal;
					}
				}

				&.ui-state-disabled,
				&.ui-state-processing {
					.tab-title {
						cursor: normal;
					}

					.tab-remove,
					.tab-clone {
						display: none;
					}
				}

				.tab-remove,
				.tab-clone {
					float: right;
					margin-left: .5em;
					color: #f66;
					font-size: 10px;
					cursor: pointer;

					&:hover {
						color: #f33;
					}
				}

				.tab-clone {
					color: #666;

					&:hover {
						color: #333;
					}
				}

				.tab-add {
					position: relative;
					top: 1px;
					display: block;
					color: #AAA;
					text-decoration: none;
					text-shadow: white 0px 1px 0px;
					font-size: 14px;
					line-height: 16px;
					cursor: pointer;

					&:hover {
						color: #d54e21;
					}
				}
			}
		}

		.ui-tabs-panel {
			display: block;
			padding: 5px;
			border: 1px solid #dfdfdf;
			background: #f9f9f9;
		}
	}

	.ui-accordion {
		width:100%;

		.ui-accordion-header{
			position:relative;
			margin-top:1px;
			font-weight:inherit;
			font-size:inherit;
			font-family:inherit;
			cursor:pointer;
			zoom:1;

			a {
				display: inline-block;
				padding: .5em 1em;
				color: #aaa;
			}

			.accordion-remove,
			.accordion-clone {
				display: inline-block;
				float: right;
				margin: .5em 1em .5em 0;
				padding: 0;
				color: #f66;
				font-size: 10px;
				cursor: pointer;

				&:hover {
					color: #f33;
				}
			}

			.accordion-clone {
				color: #666;

				&:hover {
					color: #333;
				}
			}

			.accordion-background-selector {
				float: left;
				margin-left: .5em;
				padding: 3px;
				width: 1em;
				height: 1em;
				border-radius: 2px;
				background: #fff;
				color: #666;
				content: icon('image');
				text-align: center;
				font-size: 14px;
				font-family: "vamtam-icomoon";
				line-height: 19px;
				cursor: pointer;
			}
		}

		.ui-accordion-header-active {
			border-bottom:0 !important;

			a {
				color: #464646;
			}
		}
		.ui-accordion-heading {
			display:block;
			padding:.5em .5em .5em .7em;
		}
		.ui-accordion-content {
			.border-box();
			position:relative;
			top:1px;
			display:none;
			overflow:auto;
			margin-top:-2px;
			margin-bottom:2px;
			padding: 5px;
			width: 100%;
			border: 1px dotted #cdcdcd;
			border-top:0;
			zoom:1;
		}

		.ui-accordion-content-active {
			display: block;
			min-height: 2em;
		}

		.accordion-add {
			display: inline-block;
			margin: -7px -10px;
			padding: 7px 0;
			width: 100%;
			color: #444;
			text-align: center;
			font-weight: normal;
			font-size: 14px;
			cursor: pointer;

			&:hover {
				color: #d54e21;
			}
		}
	}
}