.wpv-wysija-newsletter,
#main .wpv-wysija-newsletter {
	text-align: center;
	font-size: 14px;

	.widget_wysija_cont.shortcode_wysija {
		display: inline-block;
		position: relative;

		label {
			display: none;
		}

		input[name="wysija[user][email]"] {
			width: 210px;
			height: 50px;
			border: 0;
			background: @accent-color-8;
			border-radius: 0;
			margin: 0 20px;
		}

		.wysija-submit,
		.wysija-paragraph,
		input[name="wysija[user][email]"] {
			display: inline-block;
			vertical-align: middle;
		}

		.wysija-submit {
			background: none;
			color: @accent-color-1;
			border: 1px solid @accent-color-1;
			margin-top: 0;
			padding: 10px 30px 10px 30px;
			font-size: 19px;
			border-radius: 0;

			&:hover {

			color: @accent-color-8 !important;
		    transition: color .3s ease;
		    background: @accent-color-1;
		    border-color: @accent-color-1

			}
		}

		.formError {
			left: 20px !important;
			width: 210px !important;
			top: auto !important;
			bottom: 100% !important;
			opacity: 1 !important;

			.formErrorContent {
				width: 190px !important;
				border: 0;
				background: @accent-color-8;
				color: @accent-color-6;
			}
		}

		.allmsgs {
			> div {
				margin: 0 0 0 20px;
				display: inline-block;
				vertical-align: middle;

				ul {
					margin-left: 0;
				}
			}
		}
	}
}