.ms-filter-gradient(@color:transparent) when (iscolor(@color)) and (alpha(@color) < 1) {
	@ieAlphaColor: argb(@color);
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr='@{ieAlphaColor}', endColorstr='@{ieAlphaColor}', GradientType=0)";
}

.ms-filter-alpha(@opacity: 0) when (isnumber(@opacity)){
	-ms-filter: "alpha(opacity=@{opacity})";
}