@thumb-size: 40px;
.wpv_authors {
	.authors_list > li {

		padding: 0 0;
		border-bottom: 0 solid @default-line-color;
		position: relative;
		overflow: hidden;
		margin: 0;
		padding: 0 0;
		text-overflow: ellipsis;


		&:first-child {
			padding-top: 0;
		}

		&:last-child {
			padding-bottom: 0;
			border-bottom: 0;
		}
	}

	.gravatar {
		float: left;
	}

	.author_name  h6 {
		margin-bottom: 5px;
		a {
		font-size: 16px !important;
	    }
	}

	.author_info:not(:first-child) {
		padding-left: 10px + @thumb-size;

	}

	.author_desc {

		padding-bottom: 10px;
	}

	.post-count {
		font-size: .8em;
	}
}
