@-webkit-keyframes breathe {
	from {
		opacity: 1;
	}

	to {
		opacity: .4;
	}
}

@keyframes breathe {
	from {
		opacity: 1;
	}

	to {
		opacity: .4;
	}
}

.wpv-splash-screen {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	background: @accent-color-8;
	z-index: 99999;

	.wpv-splash-screen-logo {
		position: absolute;
		top: 0;
		right: 0;
		bottom: 0;
		left: 0;
		.animation( breathe 1s alternate infinite cubic-bezier(.5522847498,0,.44771525,1) );
	}
}