.slogan {
	@btn-height: 18px;
	@btn-pad-y : 8px;

	position     : relative;

	em {
		font-size: 12px;
		line-height: 0.8em;
	}

	.title {
		font-size: 24px;
		margin-bottom: 18px;
	}

	.description {
		font-size: 16px !important;
		line-height: 1.4em !important;
		font-weight: normal;
	}

	h3 {
		line-height: 1;
	}

	.slogan-content,
	.button-wrp {
		vertical-align: middle;
	}

	&.has-button .slogan-content,
	.button-wrp {
		display: table-cell;
	}

	.button-wrp {
		padding-left: @content-padding;
		text-align: center;
		white-space: nowrap;
	}

	.slogan-content {
		width: 100%;
	}

	.button-wrp .button {
		border: none;
		font-size: @btn-height !important;
		line-height: 1 !important;
		padding: 0 !important;
		margin: auto !important;
		vertical-align: middle;
		white-space: nowrap;
	}

	.vamtam-button.button-filled span.icon {
		font-size: 20px;
	}
}

.has-background {
	> .slogan,
	> div > .slogan {
		padding: @vertical-padding @horizontal-padding/2;
	}
}
