.vamtam-icon {
  font-family: 'vamtam-icomoon';
}
.vamtam-icon.theme-icon {
  font-family: 'vamtam-theme';
}
.vamtam-icon.custom-icon {
  font-family: 'vamtam-custom-icons';
}
.va-icon,
[class^="va-icon-"]:before,
[class*=" va-icon-"]:before {
  font-family: 'vamtam-admin' !important;
  font-style: normal;
  speak: none;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
}
.va-icon-undo-char {
  content: "\e000";
}
.va-icon-undo:before {
  content: "\e004";
}
.va-icon-info-char {
  content: "\e001";
}
.va-icon-info:before {
  content: "\e001";
}
.va-icon-pencil-char {
  content: "\e002";
}
.va-icon-pencil:before {
  content: "\e002";
}
.va-icon-lines-char {
  content: "\e003";
}
.va-icon-lines:before {
  content: "\e003";
}
.va-icon-remove-char {
  content: "\e004";
}
.va-icon-remove:before {
  content: "\e004";
}
.va-icon-vamtam-char {
  content: "\e005";
}
.va-icon-vamtam:before {
  content: "\e005";
}
.clearfix:before,
.clearfix:after {
  content: "\0020";
  display: block;
  height: 0;
  visibility: hidden;
}
.clearboth,
.clearfix:after {
  clear: both;
}
.clearfix {
  zoom: 1;
}
.invisible {
  visibility: hidden;
}
.sub_shortcode_wrap {
  display: none;
}
.wpv-config-page .disabled .button,
.wpv-config-page .disabled .button-primary {
  opacity: .3;
}
#wpv-config-tabs ul {
  margin: 0;
  padding: 0;
}
#wpv-config-tabs li {
  display: inline-block;
  margin: 0;
}
#wpv-config-tabs a {
  color: #555;
  border-color: #ccc;
  background: #e4e4e4;
}
#wpv-config-tabs a:hover,
#wpv-config-tabs .ui-tabs-active a {
  color: #000;
  background: none;
  border-color: #ccc;
  border-bottom-color: #f1f1f1;
}
#wpv-config-tabs .ui-tabs-active a {
  border-width: 1px;
  color: #464646;
}
h2.wpv-config-no-tabs {
  padding-left: 1px;
  font-size: 30px;
}
#wpv-config-title {
  display: none;
  width: 827px;
  margin-top: 30px;
  padding-top: 10px;
}
#wpv-first-run,
#wpv-config-title-links {
  background-color: #f0f0f0;
  padding: 5px 10px;
  border-top: 1px solid #fff;
}
#wpv-first-run {
  border-botom: 1px solid #dfdfdf;
  border-width: 1px 0;
  background-color: #ccf;
}
#wpv-config-title-links * {
  -moz-transition: all 0.3s ease-out;
  -o-transition: all 0.3s ease-out;
  -webkit-transition: all 0.3s ease-out;
  -ms-transition: all 0.3s ease-out;
  transition: all 0.3s ease-out;
}
#wpv-config-title-links .button-primary {
  float: right;
  position: relative;
  top: 3px;
  margin-top: -3px;
  padding: 0 6px;
  margin-right: 10px;
}
#wpv-config-title-links a {
  color: #666;
  text-decoration: none;
  margin: 0 5px;
  text-transform: uppercase;
  font-size: 10px;
  font-weight: bold;
  position: relative;
  top: 4px;
  float: left;
}
#wpv-config-title-links a:hover {
  color: #21759b;
}
#wpv-config-title-links a:first-child {
  margin-left: 0;
}
#wpv-config-title-links a:last-child {
  margin-right: 0;
}
#wpv-config-title h2 {
  color: #666;
  padding: 10px;
  font-style: normal;
  border-bottom: 1px solid #dfdfdf;
}
#wpv-config-title p {
  margin: 0;
  padding: 10px 0;
}
#wpv-config-title .message {
  margin: 0;
  -moz-border-radius: 0;
  border-radius: 0;
  border: 0;
  background: #999BB9;
  color: #f0f0f0;
  text-align: center;
}
.wpv-config-group .config-info {
  padding: 15px 60px 15px 0;
}
.wpv-config-group .config-info .info-wrapper {
  padding: 20px 18px;
  position: relative;
  background-color: #fff;
  border-left: 4px solid #0074a2;
  box-shadow: 0px 1px 1px 0px rgba(0,0,0,0.1);
}
.wpv-config-group .config-info .info-wrapper .title {
  color: #B07320;
  font-weight: bold;
}
.wpv-config-group .config-info .info-wrapper .desc {
  display: none;
  padding-top: 15px;
  color: #707070;
}
.wpv-config-group .config-info .info-wrapper .desc.visible {
  display: block;
}
.wpv-config-group .config-info .info-wrapper > a {
  position: absolute;
  right: 18px;
  top: 20px;
}
.wpv-config-group .config-separator {
  font-weight: bold;
  padding: 30px 0 16px 7px;
  line-height: 1;
  border-bottom: 1px solid #ccc;
  font-size: 1.17em;
}
.wpv-config-group.metabox {
  background: none;
  border: 0;
}
.wpv-config-group.metabox,
.wpv-config-group.metabox input,
.wpv-config-group.metabox select,
.wpv-config-group.metabox textarea {
  font-family: sans-serif;
  font-family: 12px;
}
.wpv-config-group.metabox .ui-tabs-nav {
  background: none;
  padding: 0;
  border-bottom: 1px solid #ccc;
}
.wpv-config-group.metabox .wpv-meta-tab {
  display: inline-block;
  border: 0;
  margin-bottom: -2px;
  padding-bottom: 1px;
  background: transparent;
}
.wpv-config-group.metabox .wpv-meta-tab a {
  display: inline-block;
  text-decoration: none;
  padding: 14px 18px 10px 18px;
  line-height: 1;
  font-size: 14px;
  font-family: sans-serif;
  color: #21759b;
}
.wpv-config-group.metabox .wpv-meta-tab a:hover {
  color: #d54e21;
}
.wpv-config-group.metabox .wpv-meta-tab.ui-tabs-active {
  margin-bottom: -2px;
}
.wpv-config-group.metabox .wpv-meta-tab.ui-tabs-active a {
  border: 1px solid #ccc;
  border-bottom-color: #fff;
  background: #fff;
  border-radius: 3px 3px 0 0;
  color: #464646;
}
.wpv-config-group.metabox .wpv-meta-part {
  background: #fff;
}
.wpv-config-group.metabox .wpv-meta-part.ui-tabs-panel {
  border-top-width: 1px;
  padding: 0 6px;
}
#vamtam-portfolio-formats-select .wpv-config-group.metabox .wpv-meta-part {
  background: transparent;
  border: 0;
  padding: 0;
}
#vamtam-portfolio-formats-select .rtitle {
  display: none;
}
#vamtam-portfolio-formats-select .rcontent {
  margin-left: 0;
  padding-top: 0;
}
#vamtam-portfolio-formats-select .rcontent .toggle-radio {
  display: block;
  padding: 4px 0;
}
#vamtam-portfolio-formats-select .wpv-config-row {
  padding-bottom: 0;
  border: 0;
}
.wpv-config-group h4,
#shortcode_preview h4 {
  font-size: 15px;
  font-weight: normal;
  color: #464646;
  margin: 10px 0;
  padding: 7px 0;
  font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
}
.wpv-config-row.autofill.no-box .rcontent > div {
  background: transparent;
  border: 0;
}
.wpv-config-row.autofill .rcontent > div {
  max-width: 648px;
  background: #fff;
  border: 1px solid #eee;
}
.wpv-config-row.autofill .rcontent > div .autofill-description {
  margin: 0;
  text-shadow: 0 1px 0 #fff;
  color: #555;
  background: #fff;
  border-bottom: 1px solid #eee;
  font: 400 14px/19px 'Open Sans', sans-serif;
  padding: 7px 12px;
}
.wpv-config-row.autofill .rcontent > div .autofill-thumbs {
  padding: 8px;
}
.wpv-config-row.autofill .rcontent > div .autofill-thumbs a {
  display: inline-block;
  margin: 11px;
  border: 1px solid #ddd;
  box-shadow: 0 1px 0 #fff;
  position: relative;
  z-index: 1;
}
.wpv-config-row.autofill .rcontent > div .autofill-thumbs a img {
  cursor: pointer;
  vertical-align: bottom;
}
.wpv-config-row.autofill .rcontent > div .autofill-thumbs a.selected,
.wpv-config-row.autofill .rcontent > div .autofill-thumbs a:hover {
  box-shadow: 0 0 0 1px white, 0 0 0 5px #85CA47;
}
.wpv-config-row.autofill .rcontent > div .autofill-thumbs a.selected:before,
.wpv-config-row.autofill .rcontent > div .autofill-thumbs a:hover:before {
  content: "";
  display: block;
  position: absolute;
  background-image: url(../images/mark.png);
  background-repeat: no-repeat;
  height: 30px;
  width: 30px;
  top: -15px;
  right: -15px;
  z-index: 11;
}
.wpv-config-row {
  padding: 6px 20px;
  clear: both;
}
.wpv-config-row {
  padding: 0 0 20px 0;
  border-bottom: 1px solid #e9e9e9;
}
.wpv-config-row.slim {
  border-bottom: 0;
  padding-bottom: 0;
}
.wpv-config-row.short-border {
  border-bottom: 0;
  padding-bottom: 0;
}
.wpv-config-row.short-border .rcontent {
  padding-bottom: 20px;
  border-bottom: 1px solid #e9e9e9;
}
.wpv-config-row.no-border {
  border-bottom: 0;
}
.wpv-config-row select {
  max-width: 100%;
}
.wpv-config-row .rtitle {
  float: left;
  width: 160px;
  padding: 27px 12px 0 12px;
}
.wpv-config-row .rtitle h4 {
  margin: 0;
  padding: 0;
  font-family: sans-serif;
  font-size: 12px;
}
.wpv-config-row .rtitle .row-desc {
  margin: 0;
  padding: 0;
  position: relative;
  float: left;
}
.wpv-config-row .rtitle .row-desc > a {
  text-decoration: none;
  margin-top: 10px;
  display: block;
  font-size: 14px;
  color: #ccc;
}
.wpv-config-row .rtitle .row-desc > a:hover,
.wpv-config-row .rtitle .row-desc > a:focus {
  color: #20759A;
}
.wpv-config-row .rtitle .row-desc > div {
  display: none;
  position: absolute;
  top: 0;
  left: 36px;
  width: 380px;
  border: 1px solid #ccc;
  background: #fff;
  box-shadow: 2px 3px 6px rgba(0,0,0,0.4);
}
.wpv-config-row .rtitle .row-desc > div .content {
  padding: 14px;
}
.wpv-config-row .rtitle .row-desc > div footer {
  padding: 9px 14px;
  border-top: 1px solid #ccc;
  background: #f1f1f1;
}
.wpv-config-row .rtitle .row-desc > div:after,
.wpv-config-row .rtitle .row-desc > div:before {
  top: 25px;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
}
.wpv-config-row .rtitle .row-desc > div:after {
  border-right-color: #fff;
  border-width: 10px;
  left: 0;
  z-index: 100;
  margin-left: -20px;
  margin-top: 1px;
}
.wpv-config-row .rtitle .row-desc > div:before {
  border-right-color: #989898;
  border-width: 11px;
  left: 0;
  z-index: 99;
  margin-left: -22px;
}
.wpv-config-row .rtitle .row-desc:hover,
.wpv-config-row .rtitle .row-desc:focus {
  padding: 20px 0;
  margin: -20px 0;
  float: none;
  z-index: 100;
}
.wpv-config-row .rtitle .row-desc:hover > div,
.wpv-config-row .rtitle .row-desc:focus > div {
  display: block;
}
.wpv-config-row .rtitle .row-desc:hover > a,
.wpv-config-row .rtitle .row-desc:focus > a {
  color: #20759A;
}
.wpv-config-row .rcontent {
  padding-top: 25px;
  margin-left: 184px;
}
.save-wpv-config {
  width: 827px;
  margin: 0;
  padding: 20px 14px 25px 14px;
}
#shortcodes {
  display: none;
}
.wpv-config-group.metabox.shortcode_wrap {
  width: 100%;
  background: #fff;
}
.shortcode_content {
  width: 49%;
  float: left;
}
#shortcode_preview {
  width: 49%;
  height: 100%;
  float: right;
  margin-top: 45px;
}
#shortcode_preview > div > iframe {
  min-height: 300px;
  width: 100%;
}
.shortcode_send {
  margin-left: 20px;
}
.shortcode_buttons {
  clear: both;
  text-align: right;
}
.shortcode_buttons.top {
  margin-bottom: 0;
}
.imageItemWrap .hndle {
  vertical-align: middle;
  width: 10px;
}
.imageItemWrap .hndle div {
  width: 10px;
  height: 10px;
  background: #55f;
  -moz-border-radius: 50px;
  border-radius: 50px;
  -moz-box-shadow: 0 0 10px rgba(0,0,0,0.4);
  -webkit-box-shadow: 0 0 10px rgba(0,0,0,0.4);
  -o-box-shadow: 0 0 10px rgba(0,0,0,0.4);
  box-shadow: 0 0 10px rgba(0,0,0,0.4);
}
#imagesSortable .sortItem-placeholder {
  background: #f0f0f0;
  border: 1px solid #ccc;
}
#credits_tbl {
  border: 1px solid #dfdfdf;
}
#menu_content_content_wpv_shortcodes_menu {
  width: 132px;
  height: 300px;
}
#menu_content_content_wpv_shortcodes_menu tr.mceFirst {
  width: 132px !important;
}
#menu_content_content_wpv_shortcodes_menu tr.mceFirst td {
  width: 132px !important;
}
#menu_content_content_wpv_shortcodes_menu tr {
  width: 132px !important;
  border-left: 1px solid #ccc;
}
#menu_content_content_wpv_shortcodes_menu tr td {
  width: 132px;
}
.vamtam_page_wpv_help #wpv-config,
.wpv-help {
  padding: 10px 20px;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.wpv-config-row.font .wrapper {
  display: inline-block;
}
.wpv-config-row.font .size-lheight-separator {
  position: relative;
  top: -1.3em;
  font-size: 1.2em;
}
.wpv-config-row.font .font-preview {
  margin-bottom: 15px;
}
.wpv-config-row.font .sub-desc {
  padding-left: 5px;
  color: #777;
  font-size: 9px;
}
.wpv-config-row.font .rcontent {
  padding-top: 15px;
}
.wpv-config-row.font .hidden {
  display: none;
}
.wpv-config-row.body-layout .layout-type {
  display: inline-block;
  text-align: center;
  margin: 11px;
  border: 1px solid #ddd;
  box-shadow: 0 1px 0 #fff;
  position: relative;
  z-index: 1;
  cursor: pointer;
}
.wpv-config-row.body-layout .layout-type.default {
  border: 0;
}
.wpv-config-row.body-layout .layout-type.default label {
  display: inline;
}
.wpv-config-row.body-layout .layout-type.default label.selected,
.wpv-config-row.body-layout .layout-type.default label:hover {
  box-shadow: none;
}
.wpv-config-row.body-layout .layout-type.default label:before,
.wpv-config-row.body-layout .layout-type.default label:after {
  display: none;
}
.wpv-config-row.body-layout .layout-type.default input[type="radio"] {
  display: inline-block;
}
.wpv-config-row.body-layout label {
  display: block;
}
.wpv-config-row.body-layout label img {
  cursor: pointer;
  vertical-align: bottom;
}
.wpv-config-row.body-layout label.selected,
.wpv-config-row.body-layout label:hover {
  box-shadow: 0 0 0 1px white, 0 0 0 5px #85CA47;
}
.wpv-config-row.body-layout label.selected:before,
.wpv-config-row.body-layout label:hover:before {
  content: "";
  display: block;
  position: absolute;
  background-image: url(../images/mark.png);
  background-repeat: no-repeat;
  height: 30px;
  width: 30px;
  top: -15px;
  right: -15px;
  z-index: 11;
}
.wpv-config-row.body-layout input[type="radio"] {
  display: none;
}
.result {
  color: #FF4B33;
  display: block;
}
.wpv-config-row.toggle .rcontent img {
  margin-right: 10px;
  border: 1px solid #bbb;
}
.wpv-config-row.toggle .rcontent .toggle-radio {
  display: inline-block;
  margin-right: 15px;
}
.wpv-config-row.radio .toggle-radio {
  display: inline-block;
  margin-right: 15px;
}
.wpv-config-row.social tbody th {
  text-align: right;
  font-size: 12px;
  font-weight: bold;
}
.wpv-config-row.social td {
  text-align: center;
}
#wpv-ajax-overlay {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: rgba(0,0,0,0.3);
  z-index: 9999;
}
#wpv-ajax-content {
  border-radius: 10px;
  background-color: rgba(0,0,0,0.6);
  color: #fff;
  font-size: 40px;
  height: 80px;
  left: 45%;
  padding-top: 50px;
  position: fixed;
  text-align: center;
  top: 20%;
  width: 200px;
  z-index: 10000;
}
.one_half,
.one_third,
.two_thirds,
.three_fourths,
.one_fourth,
.one_fifth,
.two_fifths,
.three_fifths,
.four_fifths,
.one_sixth,
.five_sixths,
.full,
.grid-1-2,
.grid-1-3,
.grid-1-4,
.grid-1-5,
.grid-1-6,
.grid-2-3,
.grid-2-5,
.grid-3-4,
.grid-3-5,
.grid-4-5,
.grid-5-6,
.cell-1-2,
.cell-1-3,
.cell-1-4,
.cell-1-5,
.cell-1-6,
.cell-2-3,
.cell-2-5,
.cell-3-4,
.cell-3-5,
.cell-4-5,
.cell-5-6 {
  position: relative;
  margin-right: 4%;
  float: left;
}
.one_half,
.grid-1-2,
.cell-1-2 {
  width: 48%;
}
.one_third,
.grid-1-3,
.cell-1-3 {
  width: 30.6666%;
}
.one_fourth,
.grid-1-4,
.cell-1-4 {
  width: 22%;
}
.one_fifth,
.grid-1-5,
.cell-1-5 {
  width: 16.8%;
}
.one_sixth,
.grid-1-6,
.cell-1-6 {
  width: 13.3333%;
}
.two_thirds,
.grid-2-3,
.cell-2-3 {
  width: 65.3332%;
}
.two_fifths,
.grid-2-5,
.cell-2-5 {
  width: 37.6%;
}
.three_fourths,
.grid-3-4,
.cell-3-4 {
  width: 74%;
}
.three_fifths,
.grid-3-5,
.cell-3-5 {
  width: 58.4%;
}
.four_fifths,
.grid-4-5,
.cell-4-5 {
  width: 79.2%;
}
.five_sixths,
.grid-5-6,
.cell-5-6 {
  width: 82.6665%;
}
.full {
  width: 100%;
}
.last,
.full {
  margin-right: 0 !important;
  clear: right;
}
.horizontal_blocks .rcontent {
  max-width: 648px;
}
.horizontal_blocks .rcontent .ui-range {
  height: 32px;
  margin-top: 20px;
}
.horizontal_blocks .rcontent .blocks div.block {
  border: 1px solid #bbb;
  background: #f7f7f7;
  color: #333;
  min-height: 100px;
  margin-top: 20px;
  position: relative;
  display: none;
}
.horizontal_blocks .rcontent .blocks div.block .options {
  position: absolute;
  text-align: center;
  top: 50%;
  margin-top: -12px;
  width: 100%;
}
.horizontal_blocks .rcontent .blocks div.block .options select,
.horizontal_blocks .rcontent .blocks div.block .options > div {
  display: inline-block;
  vertical-align: middle;
}
.horizontal_blocks .rcontent .blocks div.block > div label {
  display: block;
  text-align: left;
}
.horizontal_blocks .rcontent .blocks .active div.block {
  display: block;
}
.horizontal_blocks .rcontent .blocks .cell-1-5 div.block .options,
.horizontal_blocks .rcontent .blocks .cell-1-6 div.block .options {
  margin-top: -27px;
}
.wpv-config-row .slide-type {
  margin-bottom: 5px;
}
.wpv-config-row[data-slide-type="html"] .slide-types .image {
  display: none;
}
.wpv-config-row .slide-types .html textarea {
  width: 100%;
}
.hidden_el {
  border-top: 1px solid #ccc;
  padding-top: 10px;
}
.hidden_el:first-child {
  border-top: 0;
  padding: 0;
}
.wpv-config-row select[multiple] {
  height: 6em;
}
.wpv-config-row label.checkbox-row {
  line-height: 1.8;
}
.ui-range .ui-range-slider {
  background: #fff;
  height: 8px;
  position: relative;
  cursor: pointer;
  margin: 7px 0 0 20px;
  width: 240px;
  display: inline-block;
  border: 1px solid #dfdfdf;
  border-radius: 5px;
}
.ui-range .ui-slider-handle {
  background: #fff;
  height: 12px;
  width: 12px;
  top: -5px;
  margin-left: -5px;
  position: absolute;
  display: block;
  border: 3px solid #4c4c4c;
  background: #dfdfdf;
  cursor: move;
  border-radius: 100px;
}
.ui-range .ui-slider-range {
  height: 100%;
  background: #4c4c4c;
  border-radius: 5px 0 0 5px;
}
.ui-range input {
  border: 1px solid #ddd;
  float: left;
  font-size: 12px;
  margin-left: 0;
  padding: 3px 0;
  text-align: center;
  width: 40px;
  border-radius: 5px;
}
.ui-range input + span {
  vertical-align: 2px;
  padding-left: 3px;
}
.upload-basic-wrapper .image-upload-controls {
  display: inline-block;
  vertical-align: bottom;
  width: 160px;
  height: 25px;
  padding-right: 10px;
}
.upload-basic-wrapper .image-upload-controls.wpv-video-upload-controls {
  width: auto;
}
.upload-basic-wrapper .image-upload-preview {
  display: none;
  vertical-align: bottom;
}
.upload-basic-wrapper.active .image-upload-preview:not(.hidden) {
  display: inline-block;
}
.upload-basic-wrapper .button {
  display: inline-block;
  margin-right: 5px;
}
.upload-basic-wrapper img {
  border: 1px solid #dfdfdf;
  max-width: 80px;
  max-height: 25px;
  vertical-align: bottom;
}
.wpv-upload-undo,
.wpv-upload-clear {
  display: inline-block;
  margin-left: 1px;
}
.wpv-upload-undo.hidden,
.wpv-upload-clear.hidden {
  display: none;
}
.wpv-config-row.background .bg-block {
  margin-right: 15px;
  display: inline-block;
}
.wpv-config-row.background .bg-block.bg-color,
.wpv-config-row.background .bg-block.bg-image {
  width: 300px;
}
.wpv-config-row.background .bg-block .ui-range-slider {
  width: 150px;
}
.wpv-config-row.background .bg-position {
  width: 82px;
}
.wpv-config-row.background .hidden {
  display: none;
}
.wpv-config-row.background .toggle-radio {
  padding-right: 15px;
}
.wpv-config-row.background .bg-inner-row {
  padding-bottom: 25px;
}
.wpv-config-row.background .bg-inner-row:last-child {
  padding-bottom: 0;
}
#export-config + .spinner,
#delete-config + .spinner {
  margin-top: 0;
  margin-bottom: 5px;
  vertical-align: bottom;
}
.wpv-config-row.text input,
.wpv-config-row.textarea textarea {
  width: 600px;
  max-width: 100%;
}
.color-row .single-color {
  float: left;
  padding-right: 5px;
}
.wpv-config-row .single-desc {
  font-size: 9px;
  padding-bottom: 8px;
  color: #777;
}
.color-row .single-color input {
  font-size: 11px;
}
.wpv-config-row .wpv-colorpicker {
  width: 130px;
  border: 1px solid #dfdfdf;
  border-radius: 3px;
  background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAASwAAAAZCAYAAACLvRPfAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyNpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuNS1jMDE0IDc5LjE1MTQ4MSwgMjAxMy8wMy8xMy0xMjowOToxNSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENDIChNYWNpbnRvc2gpIiB4bXBNTTpJbnN0YW5jZUlEPSJ4bXAuaWlkOjJEMDQwNDAzMkM1RjExRTM4RDM4Q0M4NkZBRUE4Nzk0IiB4bXBNTTpEb2N1bWVudElEPSJ4bXAuZGlkOjJEMDQwNDA0MkM1RjExRTM4RDM4Q0M4NkZBRUE4Nzk0Ij4gPHhtcE1NOkRlcml2ZWRGcm9tIHN0UmVmOmluc3RhbmNlSUQ9InhtcC5paWQ6MkQwNDA0MDEyQzVGMTFFMzhEMzhDQzg2RkFFQTg3OTQiIHN0UmVmOmRvY3VtZW50SUQ9InhtcC5kaWQ6MkQwNDA0MDIyQzVGMTFFMzhEMzhDQzg2RkFFQTg3OTQiLz4gPC9yZGY6RGVzY3JpcHRpb24+IDwvcmRmOlJERj4gPC94OnhtcG1ldGE+IDw/eHBhY2tldCBlbmQ9InIiPz5nbDNSAAABO0lEQVR42uzdPS4FUQAF4DtBIXRCtBQ24CesACFhC4SCHShEFDZAITbgtyRhd+NM5tnDvfF9yenf5CQnkzfz7uv6vi8V65K75KoA/15X+WD9uUzukymVgcFqwXHynMyqDQxWC3aSz2RBdWCwWrCW/CQr6gOD1YLl5CtZVyEYrBbMJx/JnhrBYLVgJnlKTlQJBquJa0huk2t1gsFqxXnyWLyrBQarEYfJazKnWjBYLdgq4xPERfWCwWrBbhnf1QIMVtU2J3dYS+oFg1Wzg+St+A4LDFblzsr4lHBarWCwqr2G5GYSwGBVa7ibGt50P1UlGKyaDb8lfE/21QgGq2bDaQ3DuVgbKgSDVbPhPKzvZFV9YLBqtl3Gd6ycOAoGq2pHyUtxpjsYrMpdJA/FSQxgsGr+fMX/EgITvwIMAJBNY7YggCv5AAAAAElFTkSuQmCC');
  background-position: -15px center;
  padding-left: 50px;
  color: #444 !important;
  font-size: 12px;
  background-size: cover;
}
.wpv-config-row .wpv-colorpicker.wpv-state-transparent {
  background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAASwAAAAZCAAAAACu1kwDAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyNpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuNS1jMDE0IDc5LjE1MTQ4MSwgMjAxMy8wMy8xMy0xMjowOToxNSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENDIChNYWNpbnRvc2gpIiB4bXBNTTpJbnN0YW5jZUlEPSJ4bXAuaWlkOjJEMDQwNDA3MkM1RjExRTM4RDM4Q0M4NkZBRUE4Nzk0IiB4bXBNTTpEb2N1bWVudElEPSJ4bXAuZGlkOjJEMDQwNDA4MkM1RjExRTM4RDM4Q0M4NkZBRUE4Nzk0Ij4gPHhtcE1NOkRlcml2ZWRGcm9tIHN0UmVmOmluc3RhbmNlSUQ9InhtcC5paWQ6MkQwNDA0MDUyQzVGMTFFMzhEMzhDQzg2RkFFQTg3OTQiIHN0UmVmOmRvY3VtZW50SUQ9InhtcC5kaWQ6MkQwNDA0MDYyQzVGMTFFMzhEMzhDQzg2RkFFQTg3OTQiLz4gPC9yZGY6RGVzY3JpcHRpb24+IDwvcmRmOlJERj4gPC94OnhtcG1ldGE+IDw/eHBhY2tldCBlbmQ9InIiPz6IWNVXAAAAwklEQVRYw+3YrwvCYBDG8f3fN4PJaBSbiPHwR7M4DGJSbKLJ4sBkmuDU7QzDKDxmv0+7+oH37r1LrIk3+V4dgiQqlu8qsGQsHz3AkrGsfwNLxrLuFSwZyzr5f2NpSp9qegFLxvLxCSzXX2MG1g+ta1KBpff5YQmWPhR7BVgylg34Z8lmiztYKtbqyQ9exdrWrDsiVrpnN1SxWhsWaRWrfeTqIF8dzlwd1DE4LwIsESsrAywRa/0KsESsWR1gaVjpMsgbTfhCyWAv+vsAAAAASUVORK5CYII=');
}
#wpv-colorpicker {
  background: #fafafa;
  border: 1px solid #ccc;
  border-radius: 3px;
  z-index: 1000000;
}
#wpv-colorpicker .transparent {
  display: block;
  text-align: center;
  border-top: 1px solid #ccc;
  margin-top: 10px;
  cursor: pointer;
  color: inherit;
  padding: 5px 0;
}
.select-row .single-option,
.range-row .single-option {
  display: inline-block;
  padding-right: 5px;
}
.type-portfolio .column-thumbnail .attachment-thumbnail {
  max-width: 100%;
  max-height: 150px;
  width: auto;
  height: auto;
}
#front-static-pages label[for="page_for_posts"] {
  display: none;
}
form.wpv-add-sidebar-ui {
  border: 1px solid #eee;
  text-align: center;
  clear: both;
  margin: 8px 0;
  padding: 10px 0;
}
form.wpv-add-sidebar-ui h3 {
  margin-top: 0;
}
form.wpv-add-sidebar-ui input[type=text] {
  display: block;
  width: 100%;
  margin-bottom: 10px;
  text-align: center;
}
.sidebar-vamtam-custom {
  position: relative;
}
.sidebar-vamtam-custom .wpv-delete-sidebar {
  z-index: 100;
  position: absolute;
  top: 14px;
  right: 40px;
  cursor: pointer;
  font-size: 11px;
  opacity: .7;
}
.sidebar-vamtam-custom .wpv-delete-sidebar:after {
  font-family: 'vamtam-admin' !important;
  font-style: normal;
  speak: none;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  content: "\e004";
}
.sidebar-vamtam-custom .wpv-delete-sidebar:hover {
  opacity: 1;
  color: #f66;
}
.sidebar-vamtam-custom .wpv-active-spinner {
  display: block;
  position: absolute;
  top: 10px;
  right: 42px;
}
.wpv-config-icons-selector .icons-wrapper {
  max-height: 300px;
  overflow: auto;
  margin: -2.5px 5px -2.5px -2.5px;
  clear: both;
}
.wpv-config-icons-selector .icons-wrapper.spinner {
  display: block;
  min-height: 50px;
  width: 100%;
  background-position: center center;
}
.wpv-config-icons-selector .icons-filter {
  float: right;
  margin: 0 5px 5px 0;
  width: 50%;
}
.wpv-config-icons-selector .single-icon {
  display: inline-block;
  width: 65px;
  height: 65px;
  margin: 2.5px;
  position: relative;
  border: 1px solid #ccc;
  background-color: #fff;
  text-align: center;
  vertical-align: top;
  color: #777;
  -webkit-transition: all .3s;
  transition: all .3s;
}
.wpv-config-icons-selector .single-icon span {
  vertical-align: middle;
  line-height: 65px;
}
.wpv-config-icons-selector .single-icon span.vamtam-icon {
  font-size: 40px;
}
.wpv-config-icons-selector input[type="radio"] {
  display: none;
}
.wpv-config-icons-selector :checked + .single-icon,
.wpv-config-icons-selector .checked + .single-icon,
.wpv-config-icons-selector .single-icon:hover {
  border-color: #154F68;
  color: #21759b;
}
body > .wpv-config-icons-selector {
  display: none;
}
.mfp-content > .wpv-config-icons-selector {
  background: #fff;
  padding: 50px 10px 10px;
}
.wpv-icon-selector-trigger {
  text-decoration: none;
}
.wpv-icon-selector-trigger.no-icon:before {
  display: inline-block;
  content: "\e009";
  text-indent: 0;
  font-size: 11px;
  line-height: 14px;
}
body.toplevel_page_layerslider #wpbody-content .screen-meta-toggle a {
  background: none;
}
.vamtam-icon-font-setup .postbox-container {
  text-align: center;
}
.vamtam-icon-font-setup .postbox-container .button {
  margin: 10px 0;
}
.vamtam-icon-font-setup .inactive {
  opacity: 0.3;
  pointer-events: none;
}
.vamtam-icon-font-setup .step-in-progress {
  display: none;
}
.vamtam-icon-font-setup .result-wrapper {
  display: none;
}
#vamtam-post-format-options,
#vamtam-portfolio-format-options {
  border: 0;
}
#vamtam-post-format-options:not(.wpv-repositioned),
#vamtam-portfolio-format-options:not(.wpv-repositioned) {
  display: none;
}
#vamtam-post-format-options > .hndle,
#vamtam-post-format-options > .handlediv,
#vamtam-portfolio-format-options > .hndle,
#vamtam-portfolio-format-options > .handlediv {
  display: none;
}
#vamtam-post-format-options > .inside,
#vamtam-portfolio-format-options > .inside {
  margin: 0;
  padding: 0;
}
