.clearfix() {
	&:before,
	&:after {
		content: " "; /* 1 */
		display: table; /* 2 */
	}

	&:after {
		clear: both;
	}
}

.clearboth {
	clear: both;
}

.row, .clearfix {
	clear: both;
	.clearfix();
}

.row .row {
	margin-left: -@horizontal-padding/2;
	margin-right: -@horizontal-padding/2;
}

.grid-1-1,
.grid-1-2,
.grid-1-3,
.grid-1-4,
.grid-1-5,
.grid-1-6,
.grid-2-3,
.grid-2-5,
.grid-3-4,
.grid-3-5,
.grid-4-5,
.grid-5-6 {
	position: relative;
	padding: 0;
	float: left;
	.border-box();
	display: block;
	padding: 0 @horizontal-padding/2;
	// outline: 1px dotted green;
}

.grid-1-1 {width:100%;}
.grid-1-2 {width:50% }
.grid-1-3 {width:33.33333333% }
.grid-1-4 {width:25% }
.grid-1-5 {width:20% }
.grid-1-6 {width:16.66666666% }
.grid-2-3 {width:66.66666666% }
.grid-2-5 {width:40% }
.grid-3-4 {width:75% }
.grid-3-5 {width:60% }
.grid-4-5 {width:80% }
.grid-5-6 {width:83.33333333% }

img.lazy,
.loading {
	background: url(../wpv_theme/assets/images/loader.gif) center center no-repeat;
	background-image: url(../wpv_theme/assets/images/loader.gif),url(../wpv_theme/assets/images/loader_bg.png);
	background-position: center center, center center;
	background-color: @default-bg-color;
}
img.loaded,
img.lazy.no-animation,
.loading.no-animation {
	background-image: none;
}

.wide .limit-wrapper,
.boxed .boxed-layout {
	width: @site-max-width;
	max-width: @site-max-width;
}

.boxed {
	#header-slider-container,
	.limit-wrapper {
		.ls-container,
		.rev_slider_wrapper {
			max-width: @site-max-width;
		}
	}

	#header-slider-container .rev_slider_wrapper {
		left: 0 !important;

		.tp-leftarrow.default {
			left: 30px !important;
		}

		.tp-rightarrow.default {
			right: 30px !important;
		}
	}
}

body.full article .ls-container {
	max-width: 100%;
}

html.touch .fixed-header-box {
	-webkit-transform: translate3d(0, 0, 0);
}