<?php
return 	array(
		"name" => "Tooltip",
		"value" => "tooltip",
		"options" => array(
			array(
				'name' => __( 'Tooltip content', 'construction' ),
				'id' => 'tooltip_content',
				'default' => '',
				'type' => 'textarea'
			),
			array(
				'name' => __( 'Tooltip trigger', 'construction' ),
				'id' => 'content',
				'default' => '',
				'type' => 'textarea'
			),
		),
	);
