/*
Theme Name: Construction
Theme URI: https://construction.vamtam.com
Text Domain: construction
Description: WordPress Theme with powerful back-end framework.
Author: VamTam
Author URI: https://vamtam.com
Version: 23.6
License: Envato
License URI: https://themeforest.net/licenses
Tags: one-column, two-columns, three-columns, four-columns, left-sidebar, right-sidebar, fluid-layout, custom-background, custom-colors, custom-header, custom-menu, featured-image-header, featured-images, full-width-template, post-formats, theme-options, threaded-comments, translation-ready
*/
