#top-nav-wrapper {
	position: relative;
	z-index: 6666;
	background: @accent-color-8;
	border: none;
}

.top-nav strong {
	font-size: inherit;
	font-weight: inherit;
	color: @accent-color-6;
	font-weight: 700;
}

.top-nav {
	.bg(
		@top-nav-background-image,
		@top-nav-background-repeat,
		center top,
		scroll,
		@top-nav-background-color,
		auto
	);

	.border-box();
	margin: 0 auto;
	white-space: nowrap;

	&, p {
		color: @css-tophead-text-color;
	}

	&, p, div, li, a {
		font-size: 12px;
	}

	> .top-nav-inner {
		> .row {
			padding: 7px 0;

			> .row > div {
				vertical-align: top;
			}
		}
	}

	.grid-1-2 {
		min-height: 1px;

		&:last-child {
			text-align: right;
		}
	}

	.menu-wrapper {
		position: relative;
		height: 17px;
	}

	a {
		color: @css-tophead-link-color;

		&:hover {
			color: @css-tophead-link-hover-color;


			.icon {
				color: @css-tophead-link-hover-color !important;
			}
		}
	}

	ul > li {
		&.current_page_item,
		&.current-menu-item,
		&.current-menu-parent,
		&.current-menu-ancestor {
			> a {
				color: @css-tophead-link-hover-color;
			}
		}
	}

	.menu,
	.menu li {
		display: inline-block;
		margin: 0;
		padding: 0;
	}

	.menu {
		height: 20px;
		margin: 0 -15px;

		> li {
			&.menu-item-has-children {
				a:first-child {
					position: relative;
				}

				&:hover {
					height: 45px;

					> .sub-menu {
						display: block;
					}
				}
			}

			> a {
				padding: 0 @menuitem-padding-x;
			}

			a {
				font-size: 11px;
				line-height: 1.6em;
			}
		}

		li {
			position: relative;

			// any sub menu
			.sub-menu {
				position: absolute;
				top: 30px;
				display: none;
				margin: 0 auto auto 0;
				width: @sub-menu-width;
				text-align: left;
				box-shadow: 0 2px 4px 2px rgba(0, 0, 0, 0.09);
				background: @menu-level1-bg;
				.border-box();

				&.invert-position {
					left: auto;
					right: 0;
				}

				.sub-menu.invert-position {
					right: 100%;
				}

				.menu-item {
					display: block;

					> a {
						display: block;
						padding: 11px @menuitem-padding-x;
						color: @menu-level1-color;
						border-bottom: 1px solid @default-line-color;
					}

					&:last-child {
						padding-bottom: 0;
					}

					&.current-menu-parent,
					&.current-menu-item,
					&.current-menu-ancestor,
					&.current-menu-ancestor,
					&:hover {
						background: @css_menu_background;
						transition: all .4s;
						border-radius: 1px;

						> a {
							text-decoration: none;
							color: @menu-level1-hover-color;
							border-bottom-color: @accent-color-1 ;
							transition: all .4s;
						}
					}
				}
			}
		}
	}
}

#top-nav-social {
	> a {
		display: inline-block;
		width: 1.65em;
		height: 1.65em;
		text-align: center;
		vertical-align: middle;
		border: none;
		border-radius: 0;
		font-size: 15px;
		margin: 0px;

		&, .icon {
			line-height: 1.65em;
		}

		&:hover {
			.icon.shortcode.use-hover {
				color: @accent-color-1 !important;
			}

			background: @accent-color-8;
			border-color: none;
		}
	}
}

#top-nav-text {
	.icon.shortcode {
		vertical-align: middle;
	}
}