@icon-size: 25px;
@large-icon-size: 25px;

.wpv_icon_link {
	li {
		padding: 10px 0;

		&:first-child {
			padding-top: 0;
		}
	}

	a {
		color: inherit;
		display: block;
		height: 32px;
		line-height: 32px;
		position: relative;

		span {
			line-height: 32px;
			height: 32px;
			display: block;
			position: absolute;
		}
	}

	.content {
		left: 0;
		top: 0;
		padding-left: 40px;
	}

	.before {
		left: 0;
		top: 2px;
		font-size: 25px;
	}

	.after {
		right: 0;
		top: 0;
		font-size: 1.5em;
		opacity: 0.6;
		display: none;
	}

	[data-icon-type="facebook"] {
		color: #39599f;
	}

	[data-icon-type="twitter"] {
		color: #45b0e3;
	}

	[data-icon-type="googleplus"] {
		color: #d04f40;
	}

	[data-icon-type="pinterest1"] {
		color: #cb2027;
	}

	[data-icon-type="flickr"] {
		color: #e956a2;
	}

	[data-icon-type="vimeo"] {
		color: #1ab7ea;
	}

	[data-icon-type="youtube"] {
		color: #f33;
	}

	[data-icon-type="linkedin"] {
		color: #4875B4;
	}

	[data-icon-type="wordpress"] {
		color: #464646;
	}

	#top-nav-sidebar & {
		margin-top: -@icon-size/4;
		margin-bottom: -@icon-size/4;
	}
}