table.vamtam-styled {
	width: 100%;
	border-collapse: collapse;
	border-spacing: 0;
	border: none;
	padding-right: 10px;
	th, td, caption {
		padding: 5px;
		border: 1px solid @default-line-color;
	}

	caption {
		border-bottom: none;
	}

	thead {
		th {
			padding: 10px;
			vertical-align: bottom;
			text-align: left;
			padding: 10px 5px 5px 5px;
			border-right: 1px solid darken(@default-line-color, 10%);
			font-size: 18px;
			font-weight: normal;

			@bg: lighten(@default-line-color, 5%);
			background-color: @bg;
			color: #a7a7a7;

			&:last-child,
			.last-child {
				border-right: 0px;
			}
		}
	}
	tbody {
		tr {
			&:nth-child(even) td {
				@bg: lighten(@default-line-color, 10%);
				background: @bg;
				color: inherit;
			}

			&:last-child td {
				border-bottom: 0;
			}
		}
	}

	td {
		border: none;
		padding: 8px 0px;
		&:last-child {
			border: none;
		}

	}

	tfoot {
		font-size: 12px;
		font-style: normal;
		color: darken(@default-line-color, 25%);
	}
}