/* Shortcode Margins -------------------------------------------------------- */
.contact_info_wrap,
.flickr_wrap,
.portfolios,
.price-outer-wrapper,
.services,
.slogan,
.team-member,
.toggle,
.unapproved,
.wpv-tabs {
	padding-top: @vertical-padding/2;
	padding-bottom: @vertical-padding/2;
}

.loop-wrapper.page-content {
	padding-top: 0;
	padding-bottom: 0;
}


.page-content > .frame > .google_map,
.page-content > .row > .grid-1-1 > .frame > .google_map {
	margin: 0 -@horizontal-padding-large;
}

.wpv-grid > .linkarea,
.wpv-grid > .services.has-more {
	margin-left: -@horizontal-padding/2;
	margin-right: -@horizontal-padding/2;
}