.additional-space-after-dividers() {
	+ .frame-fl,
	+ .frame > .google_map {
		margin-top: @vertical-padding/2;
	}
}

// common styles
.sep,
.sep-2,
.sep-3 {
	position: relative;
	display: block;
	clear: both;
	margin: @vertical-padding*2 0 @vertical-padding 0;
	min-width: 100%;
	height: 1px;
	border-top: 1px solid;
	color: @default-line-color;

	&.has-icon .icon {
		margin-top: -2px;
		font-size: 24px;
	}
}

// adjustments for each divider type

.sep-2 {
	border-bottom: 1px solid;
	height: 2px;
}

.sep-text {
	.additional-space-after-dividers();
	position: relative;
	margin: @vertical-padding*2 0 @vertical-padding 0;
	text-align: center;

	.content,
	.sep-text-more {
		display: table-cell;
		vertical-align: middle;
		white-space: nowrap;

		* {
			margin: 0;
			line-height: 1;
		}
	}

	.content {
		padding-right: .8em;
	}

	.sep-text-more {
		padding-left: .8em;
	}

	.sep-text-before,
	.sep-text-after {
		display: table-cell;
		width: 100%;
		vertical-align: bottom;
	}

	.sep-text-line {
		display: inline-block;
		padding-top: 2px;
		width: 100%;
		border-top: 0 solid;
		border-bottom: 1px solid;
		color: @default-line-color;
		vertical-align: baseline;
	}

	&.centered {
		.sep-text-before,
		.sep-text-after {
			width: 50%;
			font-size: 22px;
		}

		.content {
			padding-left: .8em;
		}
	}

	&:last-child {
		margin-bottom: @small-padding;
	}

	+ .row {
		padding-top: 15px;
	}
}

.column-title {
	text-align: center;
	.additional-space-after-dividers();
	margin: @vertical-padding*2 0 @vertical-padding 0;


	+ p {
		margin-top: @vertical-padding/2 - 5px;
	}
}

.text-divider-double {
	position: relative;
	margin: @vertical-padding*2 0 25px 0;
	text-align: center;

	.icon {
		display: block;
		padding-bottom: 20px;
	}

	+ .sep {
		.additional-space-after-dividers();
		margin: 0 0 @vertical-padding 0;
		position: relative;

	}
}

.related-content-title {
	text-align: center;
	position: relative;
	margin-bottom: 30px;
	border-bottom: 1px solid @default-line-color;
	padding-bottom: 15px;

}