<?php

/**
 * List of enabled shortcodes
 *
 * shortcode_slug => menu
 *
 * @package wpv
 */

return array(
	'accordion'           => 'layouts',
	'blank'               => 'layouts',
	'blockquote'          => 'layouts',
	'blog'                => 'layouts',
	'column'              => 'layouts',
	'contact_info'        => 'layouts',
	'divider'             => 'layouts',
	'flickr'              => 'layouts',
	// 'gmap'             => 'layouts',
	'iframe'              => 'layouts',
	'linkarea'            => 'layouts',
	'portfolio'           => 'layouts',
	'price'               => 'layouts',
	'services'            => 'layouts',
	'services_expandable' => 'layouts',
	'sitemap'             => 'layouts',
	'slider'              => 'layouts',
	'slogan'              => 'layouts',
	'table'               => 'layouts',
	'tabs'                => 'layouts',
	'team_member'         => 'layouts',
	'text'                => 'layouts',
	'text_divider'        => 'layouts',
	'video'               => 'layouts',
	'widget'              => 'layouts',
	'wpv_countdown'       => 'layouts',
	'wpv_progress'        => 'layouts',
);