.alignnone {
	float: none !important;
}

.textcenter {
	text-align: center;
}
.textright {
	text-align: right;
}
.alignright {
	float:right;
	margin: 1em 0 1em 1.5em;
}

.alignleft {
	float:left;
	margin: 1em 1.5em 1em 0;
}

.aligncenter {
	display: block;
	margin: 1em auto;
}

a img.alignright {
	float:right;
	margin: 0 0 20px 25px;
}

a img.alignnone {
	margin: 0px;
}

a img.alignleft {
	float:left;
	margin: 0 25px 20px 0;
}

a img.aligncenter {
	display: block;
	margin-left: auto;
	margin-right: auto
}

img.alignleft {
	margin: 0 25px 20px 0;
}

.wp-caption.alignleft {
	margin: 5px 10px 5px 0;
}

img.alignright {
	margin: 0 0 20px 25px;
}

.wp-caption.alignright {
	margin: 5px 0 5px 10px;
}

img.aligncenter {
	margin: 0 auto;
}

img.alignnone {
	margin: 5px 0;
}

.wp-caption {
	max-width: 100%;

	&.alignleft {
		margin: 5px 10px 5px 0;
	}

	&.alignright {
		margin: 5px 0 5px 10px;
	}
}

.wp-caption .wp-caption-text,
.entry-caption,
.gallery-caption {
	margin-top: 0;

	.wpv-font(em-);
	.wpv-color(em-);
}

.wp-smiley,
.wp-smiley * {
	border: 0px !important;
}

.sticky, .gallery-caption, .bypostauthor { outline: none;}

table {
	border-collapse: collapse;
	border-spacing: 0;
	line-height: 2;
	width: 100%;
}

caption,
th,
td {
	font-weight: normal;
	text-align: left;
}

caption {
	font-size: 16px;
	margin: 20px 0;
}

th {
	font-weight: bold;
	text-transform: uppercase;
}

td {
	border: none;
	padding: 6px 10px 6px 0;
}

dl {
	margin: 0 20px;
}

dt {
	font-weight: bold;
}

dd {
	margin: 0 0 10px;
}

address {
	font-style: italic;
	margin: 0 0 24px;
}

var, cite {
	font-style: italic;
}

[class*="gallery-columns-"] {
	margin: 0 -15px;

	&.gallery-columns-1 .gallery-item { width: percentage(1 / 1); }
	&.gallery-columns-2 .gallery-item { width: percentage(1 / 2); }
	&.gallery-columns-3 .gallery-item { width: percentage(1 / 3); }
	&.gallery-columns-4 .gallery-item { width: percentage(1 / 4); }
	&.gallery-columns-5 .gallery-item { width: percentage(1 / 5); }
	&.gallery-columns-6 .gallery-item { width: percentage(1 / 6); }
	&.gallery-columns-7 .gallery-item { width: percentage(1 / 7); }
	&.gallery-columns-8 .gallery-item { width: percentage(1 / 8); }
	&.gallery-columns-9 .gallery-item { width: percentage(1 / 9); }

	figure.gallery-item {
		padding: 0 15px;
		display: inline-block;
		.border-box();

		img {
			display: inline-block;
		}
	}
}

.me-cannotplay span {
	padding: 5px;
}

.post-password-required {
	text-align: center;
}
