@font-face {
  font-family: 'vamtam-admin';
  src: url('../fonts/vamtam-admin.eot');
  src: url('../fonts/vamtam-admin.eot?#iefix') format('embedded-opentype'), url('../fonts/vamtam-admin.svg#vamtam-admin') format('svg'), url('../fonts/vamtam-admin.woff') format('woff'), url('../fonts/vamtam-admin.ttf') format('truetype');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'vamtam-icomoon';
  src: url(../../../assets/fonts/icons/icons.eot);
  src: url(../../../assets/fonts/icons/icons.eot?#iefix) format('embedded-opentype'), url(../../../assets/fonts/icons/icons.ttf) format('truetype');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'vamtam-theme';
  src: url(../../../../wpv_theme/assets/fonts/icons/theme-icons.eot);
  src: url(../../../../wpv_theme/assets/fonts/icons/theme-icons.eot?#iefix) format('embedded-opentype'), url(../../../../wpv_theme/assets/fonts/icons/theme-icons.ttf) format('truetype');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'vamtam-custom-icons';
  src: url(../../../../../../vamtam/custom-icon-font/custom-icons.eot);
  src: url(../../../../../../vamtam/custom-icon-font/custom-icons.eot?#iefix) format('embedded-opentype'), url(../../../../../../vamtam/custom-icon-font/custom-icons.ttf) format('truetype');
  font-weight: normal;
  font-style: normal;
}
.vamtam-icon {
  font-family: 'vamtam-icomoon';
}
.vamtam-icon.theme-icon {
  font-family: 'vamtam-theme';
}
.vamtam-icon.custom-icon {
  font-family: 'vamtam-custom-icons';
}
.va-icon,
[class^="va-icon-"]:before,
[class*=" va-icon-"]:before {
  font-family: 'vamtam-admin' !important;
  font-style: normal;
  speak: none;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
}
.va-icon-undo-char {
  content: "\e000";
}
.va-icon-undo:before {
  content: "\e004";
}
.va-icon-info-char {
  content: "\e001";
}
.va-icon-info:before {
  content: "\e001";
}
.va-icon-pencil-char {
  content: "\e002";
}
.va-icon-pencil:before {
  content: "\e002";
}
.va-icon-lines-char {
  content: "\e003";
}
.va-icon-lines:before {
  content: "\e003";
}
.va-icon-remove-char {
  content: "\e004";
}
.va-icon-remove:before {
  content: "\e004";
}
.va-icon-vamtam-char {
  content: "\e005";
}
.va-icon-vamtam:before {
  content: "\e005";
}
#toplevel_page_wpv_general .wp-menu-image,
.mce-ico.mce-i-wpv_shortcodes {
  text-align: center;
}
#toplevel_page_wpv_general .wp-menu-image:before,
.mce-ico.mce-i-wpv_shortcodes:before {
  display: inline-block;
  font-family: 'vamtam-admin' !important;
  font-style: normal;
  speak: none;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  content: "\e005";
}
#toplevel_page_wpv_general .wp-menu-image img,
.mce-ico.mce-i-wpv_shortcodes img {
  display: none !important;
}
#toplevel_page_wpv_general .wp-menu-image:before {
  font-size: 20px;
  padding: 8px 0;
}
.mce-ico.mce-i-wpv_shortcodes:before {
  font-size: 20px;
  padding: 2px 0;
}
.mce-ico.mce-i-wpv_shortcodes .content {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
}
