.flickr_wrap {
	padding: 5px 5px 5px 0 !important;
}
.flickr_badge_image {
    float: left;
    padding: 5px;
    position: relative;
    .border-box();
}
.flickr_badge_image img {
    width: 60px;
	display: block;
}
.ie8 .flickr_badge_image {
    width: 83px;
}

aside .flickr_badge_image {
	max-width: 50%;
}
aside .flickr_badge_image img {
	width: 100%;
	height: auto;
}