@media (max-width: 958px) {
	.responsive-layout {
		#scroll-to-top {
			bottom: 50px;
		}

		.comments {
			.children li {
				margin-left: 10px;
			}
		}
		.error-message {
			display: none;
		}

		html {
			background-image: none;
		}

		&.page-header {
			.title {
				padding: 30px 0 0 0 !important;
			}
		}


		&.no-header-sidebars.no-page-header .page-wrapper {
			padding-top: 20px;
		}

		.wpv-accordion {
			margin-bottom: 30px;
		}

		.move-into-slider .icon.shortcode.box {
			padding: 0.1em;
		}

		.move-into-slider {
			margin-top: 0px;
		}

		#ss-teaser,
		#style-switcher,
		#feedback-wrapper {
			right: auto !important;
			left: -10000px !important;
			display: none !important;
			width: 0 !important;
			height: 0 !important;
		}

		&.boxed .boxed-layout {
			.border-box();
			margin: 0 !important;
			padding: 0 !important;
		}

		.alignleft,
		.alignright {
			float: none;
		}

		.grid-1-2,
		.grid-1-3,
		.grid-1-4,
		.grid-1-5,
		.grid-1-6,
		.grid-2-3,
		.grid-2-5,
		.grid-3-4,
		.grid-3-5,
		.grid-4-5,
		.grid-5-6,
		aside.left,
		aside.right,
		.left-only,
		.right-only,
		.left-right {
			float: none !important;
			clear: both !important;
			margin-bottom: 0;
			width: 100% !important;

			&:last-child {
				margin-bottom: 0;
			}
		}

		.grid-1-1 {
			margin-bottom: 0;
			float: none;
			.clearfix();

			&:last-child {
				margin-bottom: 0;
			}
		}

		#header-sidebars,
		#footer-sidebars {
			aside {
				display: block !important;
				clear: both !important;
				margin: 0 0 @content-padding/2 0 !important;
				width: 100% !important;

				section {
					margin: 0;
				}
			}
		}

		#footer-sidebars {
			aside {
				padding: 0 !important;
			}
		}

		.row {
			margin-bottom: 0;

			&:last-child {
				margin-bottom: 0;
			}
		}

		#wpadminbar {
			overflow: hidden;
			min-width: 0;
		}

		aside.left,
		aside.right {
			.border-box();
			margin-right: 0;
			margin-left: 0;
			padding: 0 @content-padding-large/2;
		}

		aside .menu-item > .sub-menu {
			display: none !important;
		}

		.copyrights {
			padding: 10px 0;

			&,
			* {
				text-align: center !important;
			}

			img.alignleft,
			img.alignright {
				display: inline-block;
				float: none;
			}

			.wpv-grid {
				margin-bottom: 0;
			}
		}

		.price-wrapper.featured {
			margin-top: 0;
		}

		.meta-header-inside {
			width: 100%;
		}

		&.fast-slider {
			.fast-slider-caption {
				height: auto;
			}

			.fast-slider-navbar {
				right: auto;
				left: 0;
				width: 100%;
			}
		}

		.slogan.has-button {
			.slogan-content,
			.button-wrp {
				display: block;
			}

			.button-wrp {
				padding-top: @element-padding;
				padding-left: 0;
			}
		}

		#sub-footer-menu li {
			display: inline-block;
			float: none;
		}

		.portfolio-viewer-wrap {
			padding: 0 @horizontal-padding;

			.content .share-btns {
				margin-bottom: 20px;
			}
		}

		.woocommerce.woocommerce-scrollable .products.vamtam-wc .product {
			clear: none;
		}

		&.post-type-archive-product,
		&.tax-product_cat {
			.products.vamtam-wc .product {
				margin-bottom: 20px;

				html.csstransforms & span.onsale:before {
					border-width: 0 65px 65px 65px;
					left: -28px;
				}
			}
		}

		&.woocommerce {
			table.cart {
				max-width: 100%;

				td,
				th {
					&.product-thumbnail {
						display: none;
					}
				}

				td.actions {
					text-align: left;

					div.coupon {
						margin-bottom: 1em;
					}

					> input[type="submit"] {
						display: block;
						float: none !important;
						margin-bottom: 1em !important;
						margin-left: 0 !important;
					}
				}
			}

			.cart-collaterals {
				.shipping_calculator,
				.cart_totals {
					float: none;
					width: 100%;
				}

				.shipping_calculator {
					padding-top: @element-padding;
				}
			}

			div.product {
				span.onsale {
					right: 0;
				}

				div.summary,
				div.images {
					float: none;
					width: 100%;
				}

				div.images {
					margin-bottom: 30px;
				}

				.woocommerce-tabs {
					> ul.tabs {
						li {
							float: none !important;
							border: none !important;
							text-align: center;

							&:first-child {
								margin-left: 0;
							}
						}
					}
				}
			}

			.summary {
				form.cart,
				> div,
				.product_meta {
					padding-left: 0;
				}

				.share-btns {
					margin-left: 0;
				}

				.product_meta {
					margin: 0;
				}
			}

			.woocommerce-result-count {
				float: none;
				margin-top: 0;
			}

			.woocommerce-ordering {
				float: none;
				margin-bottom: 40px;
			}

			.related,
			.upsells {
				&.products {
					.products.vamtam-wc .product {
						width: 45%;
						margin: 5% 2%;
						display: inline-block;
						vertical-align: top;
					}
				}
			}

			.type-featured .limit-wrapper .row {
				margin-left: -5px;
				margin-right: -5px;
			}

			.email-offers input{
				margin-bottom: 1em !important;
			}
		}

		.woocommerce {
			&.columns-3 .products.vamtam-wc .product {
				width: 48%;

				&:nth-child(2n+1) {
					clear: both;
				}
			}

			.widget_shopping_cart {
				.widget_shopping_cart_content {
					.buttons {
						a.button {
							float: left;
							clear: both;
						}
					}
				}
			}
		}

		&.single-product {
			aside.left {
				display: none;
			}
		}

		&.single-portfolio {
			.portfolios {
				> ul {
					> li.has-description {
						margin-bottom: @content-padding !important;
					}
				}
			}
		}

		.portfolios {
			.portfolio-filters {
				margin-bottom: 0px;

				.cbp-l-filters-dropdownWrap {
					background: @default-bg-color;
					border: 1px solid @default-line-color;

				}

				.cbp-l-filters-dropdownHeader {
					color: @primary-font-color;
					text-transform: uppercase;

					&:after {
						border-color: @primary-font-color transparent;
					}
				}

				.cbp-l-filters-dropdownWrap {
					.cbp-filter-item {
						margin: 0;
					}
				}

				.cbp-l-filters-dropdown,
				.cbp-l-filters-dropdownWrap,
				.cbp-search {
					width: 100%;
					max-width: 300px;
					display: inline-block;
					float: none;
				}

				.cbp-search {
					margin-top: 0px;
				}
			}

			.portfolio_details {
				.excerpt {
					display: none;
				}

				.title {
					&, a {
						font-size: 1em;
						line-height: 1em;
					}
				}
			}
		}

		.page-content {
			.load-more {
				margin-bottom: @content-padding;

				a {
					padding: 0;
				}
			}
		}

		#footer-sidebars {
			overflow: hidden;

			.widget {
				padding: 0 @content-padding !important;
			}
		}

		footer.main-footer {
			padding-top: @vertical-padding;
			padding-bottom: @vertical-padding;
		}

		article {
			.loop-wrapper {
				padding: 0 0 20px 0 !important;

				.list-item header.single {
					padding-top: 20px;
				}
			}
		}

		.post-article {
			.post-media .media-inner {
				position: relative;
				display: block;
				min-height: 21px;
			}

			a.single-post-format {
				display: none;
			}
		}

		#header-breadcrumbs {
			display: none;
		}

		#sub-header {
			position: relative;
			z-index: 2;

			header.page-header {
				padding: 0 @horizontal-padding;

				.title {
					padding: 30px 0 0 0;
				}

				.post-siblings {
					margin-bottom: -20px;
				}
			}

			.meta-header-inside {
				position: relative;
				padding: 0 0 @content-padding 0;
				width: 100%;
			}
		}

		.row > .has-more-button {
			padding-right: @content-padding/2 !important;
		}

		.column-read-more-btn {
			display: none;
		}

		#commentform .form-submit {
			float: none;
			text-align: center;
		}

		.respond-box {
			margin-top: 30px;
		}

		.page-wrapper {
			> div,
			> article {
				padding-right: @horizontal-padding/2 !important;
				padding-left: @horizontal-padding/2 !important;
			}
		}

		.header-middle {
			margin-bottom: 0;

			> .limit-wrapper,
			> .row .limit-wrapper > .extended-column-inner,
			.header-middle-content {
				padding-right: @horizontal-padding;
				padding-left: @horizontal-padding;
			}
		}

		&.boxed .row > div.extended.grid-1-1 {
			margin-right: -@horizontal-padding/2;
			margin-left: -@horizontal-padding/2;
			padding-right: @horizontal-padding;
			padding-left: @horizontal-padding;
		}

		.services.smallimage {
			margin: 0 @horizontal-padding-large;
		}

		#page {
			overflow: hidden;
		}

		.meta-header-inside {
			padding: 0 0 @content-padding 0;
		}

		#header-breadcrumbs {
			padding   : 10px 0 0 @content-padding-large;
			color: @accent-color-5;
			text-align: left;

			a {
				color: @css_link_color;
			}

			&:after {
				position: absolute;
				top: @small-padding+14px;
				left: @content-padding-large;
				width: 70px;
				height: 1px;
				border-bottom: 1px solid @accent-color-7;
				content: "";
			}
		}

		&.single-post {
			.meta-header-inside {
				padding: 0 0 @small-padding 0 !important;
			}
		}

		.wpv-grid.has-more-button .column-read-more-btn {
			display: none;
		}

		.loop-wrapper.regular {
			.post-row-left {
				display: none;
			}

			.post-row-center {
				padding-left: 0;
				padding-right: 0;
				padding-top: 0;
				width: 100%;
			}

			.post-article {
				.post-media {
					float: none;
					max-width: 100%;
					width: 100%;

					img {
						width: 100%;
					}
				}

				.post-content-outer {
					padding-left: 5px;
					padding-right: 5px;

					&.single-post {
						padding-left: 0;
					}

					.post-meta div {
						border: none;

						&.blog-buttons a:after {
							display: none;
						}
					}
				}

				.quote-post-format {
					.cite {
						float: none;
						padding-bottom: 25px;
						width: auto;
						text-align: left;

						img {
							display: inline-block;
							margin-bottom: 0;
							padding: 0 20px 0 0;
							max-width: 85px;
							border: 0;
							vertical-align: middle;

							+ .quote-author {
								display: inline;
								vertical-align: middle;
							}
						}

						+ .quote-text {
							padding-left: 0;
						}
					}

					.quote-text {
						padding-bottom: 25px;
					}
				}
			}
		}

		.loop-wrapper.news .post-content-wrapper {
			padding: 0px;
			background: none;
		}

		.team-member {
			text-align: center;

			img {
				display: inline-block;
			}

			.share-icons {
				.icon {
					float: none;
				}
			}
		}

		.wpv-tabs {
			.ui-tabs-nav li {
				display: block;
				float: none;
				margin-left: 0 !important;
			}

			&.vertical {
				overflow: hidden;
				margin: 0 -@horizontal-padding;

				&:before {
					display: none;
				}

				.ui-tabs-nav {
					position: relative;
					padding: 0 30px !important;
					width: 100%;

					&:before {
						display: none;
					}

					li {
						width: 100%;
						text-align: center;

						&.inactive-block-title {
							padding: @content-padding 0;
						}
						&:last-child {
							margin-bottom: @content-padding;
						}

						&:not(.has-icon) a .title-text {
							width: auto;
						}
					}
				}

				.pane {
					float: none;
					clear: both;
					padding: @content-padding;
					width: 100%;

					&:before {
						display: none;
					}
				}
			}

			&.horizontal {
				.ui-tabs-nav li:first-child {
					border-top-right-radius: 5px;
				}

				.ui-tabs-nav li:last-child {
					border-top-right-radius: 0;
				}
			}
		}

		.comments .children {
			margin-left: 0;
			border-top: 0;
		}

		.ls-bottom-nav-wrapper {
			display: none;
		}

		.sep-text:not(.keep-always) {
			.content {
				display: block;
				white-space: normal;
			}

			.sep-text-before,
			.sep-text-after {
				display: none;
			}
		}

		.sep-text-more {
			display: none;
		}

		.sep, .sep-2, .sep-3 {
			margin-top: 30px;
		}

		blockquote.simple {
			.quote-thumbnail {
				float: none;
				width: auto;
				text-align: left;
				margin: 0;

				img {
					display: none;
				}
			}
		}

		.vamtam-rsvp-form {
			padding: 0;

			.wpcf7-file {
				width: 92%;
				padding: 4%;
			}
		}

		.wpv-grid.hide-bg-lowres {
			&, > .wpv-parallax-bg-img {
				background-image: none !important;
			}
		}

		.wpv-grid.extended-content {
			&.has-horizontal-padding {
				padding-left: 5px !important;
				padding-right: 5px !important;
			}

			&.has-extended-padding{
				padding-left: 0px;
				padding-right: 0px
			}

			.extended-column-inner {
				padding: 0 10px;
			}
		}

		.wpv-hide-lowres {
			display: none;
		}

		.wpv-restrict-mobile-map {
			height: 180px;
		}

		.extended-column-inner {
			padding: 0;
		}
	}
}