<?php
/**
 * List of option definitions for Theme options / Styles
 *
 * @package wpv
 * @subpackage construction
 */

return array(
	'global',
	'typography',
	'header',
	'body',
	'footer',
	'skins',
);
