@keyframes flash {
	0%, 50%, 100% {opacity: 1;}
	25%, 75% {opacity: 0;}
}

@keyframes wiggle {
    0% { transform: skewX(9deg); }
    10% { transform: skewX(-8deg); }
    20% { transform: skewX(7deg); }
    30% { transform: skewX(-6deg); }
    40% { transform: skewX(5deg); }
    50% { transform: skewX(-4deg); }
    60% { transform: skewX(3deg); }
    70% { transform: skewX(-2deg); }
    80% { transform: skewX(1deg); }
    90% { transform: skewX(0deg); }
	100% { transform: skewX(0deg); }
}

.animated {
	.animation-fill-mode(both);
	.animation-duration(1s);
	.animation-iteration-count(infinite);

	&.flash {
		.animation-name(flash);
	}

	&.wiggle {
		.animation-name(wiggle);
		.animation-timing-function(ease-in);
	}

    &.dialog-message {
        animation-iteration-count: 1;
    }
}
