.services.has-more {
	position: relative;
	padding: 0;
	z-index: 2000;

	.title {
		margin: 20px 0 0 -20px;
		color: @accent-color-8 !important;
	}

	.image-wrapper {
		padding: 20px;
		text-align: center;

		img {
			display: inline-block;
			vertical-align: bottom;
		}

		&:hover {
			img {
				.transform(scale(1.2));
			}
		}
	}

	.services-content-wrapper {

		> .row {
			margin: 0;
		}
	}

	.open {
		width: 100%;
		position: absolute;
		top: 100%;
		padding: 0 20px 0 20px;

		.services-content-wrapper {
			padding: 10px 0px;
		}

		.border-box();

		p:first-child {
			margin-top: 0;
		}

		p:last-child {
			margin-bottom: 0;
		}
	}

	.closed {
		padding: 20px;
		max-height: 100%;
		max-width: 100%;

		.services-content-wrapper {
			padding-bottom: 20px;
			text-align: center;
		}


		.title {
			display: inline-block;
			position: relative;
			background: none;
			font-weight: 600;
			margin: 0px;
			width: 90%;
			padding: 0px 5% 15px 5%;
		}
	}

	&.expandable-animation-3d {
		.open {
			transform-origin: top;
			transform: translate(0, 0) scaleY(0);
			transform-style: preserve-3d;
			-webkit-backface-visibility: hidden;
			will-change: transform;
		}

		.closed {
			-webkit-backface-visibility: hidden;
			will-change: transform;
		}
	}

	html.touch & {
		.open {
			transform: none;
			position: relative;
			top: 0;
		}
	}
}
