<?php
return array(
	'name' => __( 'Help', 'construction' ),
	'auto' => true,
	'config' => array(

		array(
			'name' => __( 'Help', 'construction' ),
			'type' => 'title',
			'desc' => '',
		),

		array(
			'name' => __( 'Help', 'construction' ),
			'type' => 'start',
			'nosave' => true,
		),
//----
		array(
			'type' => 'docs',
		),

			array(
				'type' => 'end',
			),
	),
);