@font-face {
  font-family: 'vamtam-editor';
  src: url('../fonts/vamtam-editor.eot');
  src: url('../fonts/vamtam-editor.eot?#iefix') format('embedded-opentype'), url('../fonts/vamtam-editor.svg#vamtam-editor') format('svg'), url('../fonts/vamtam-editor.woff') format('woff'), url('../fonts/vamtam-editor.ttf') format('truetype');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'vamtam-editor-icomoon';
  src: url(../fonts/icomoon/icons.eot);
  src: url(../fonts/icomoon/icons.eot?#iefix) format('embedded-opentype'), url(../fonts/icomoon/icons.ttf) format('truetype');
  font-weight: normal;
  font-style: normal;
}
[class^="icon-"]:before,
[class*=" icon-"]:before,
[class^="a-icon-"]:before,
[class*=" a-icon-"]:before {
  font-family: 'vamtam-editor';
  font-style: normal;
  speak: none;
  font-weight: normal;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
}
.icon-minus:before {
  content: "\e000";
}
.icon-plus:before {
  content: "\e001";
}
.icon-copy:before {
  content: "\e002";
}
.icon-edit:before {
  content: "\e003";
}
.icon-menu:before {
  content: "\e004";
}
.icon-remove:before {
  content: "\e005";
}
.icon-checkmark:before {
  content: "\e006";
}
.a-icon-checkmark:before {
  content: "\e006";
}
#wpv_visual_editor .ui-helper-hidden {
  display: none;
}
#wpv_visual_editor .ui-helper-hidden-accessible {
  position: absolute !important;
  clip: rect(1px 1px 1px 1px);
  clip: rect(1px,1px,1px,1px);
}
#wpv_visual_editor .ui-helper-reset {
  margin: 0;
  padding: 0;
  outline: 0;
  border: 0;
  list-style: none;
  text-decoration: none;
  font-size: 100%;
  line-height: 1.3;
}
#wpv_visual_editor .ui-helper-clearfix:after {
  display: block;
  visibility: hidden;
  clear: both;
  height: 0;
  content: ".";
}
#wpv_visual_editor .ui-helper-clearfix {
  display: inline-block;
}
#wpv_visual_editor .ui-helper-clearfix {
  display: block;
}
#wpv_visual_editor .ui-helper-zfix {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  opacity: 0;
  filter: Alpha(Opacity=0);
}
#wpv_visual_editor .ui-tabs {
  position: relative;
  zoom: 1;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav {
  margin: 0;
  padding: 0;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li {
  -webkit-transition: all .3s ease;
  transition: all .3s ease;
  display: inline-block;
  float: left;
  overflow: hidden;
  margin: 0 6px -1px 0;
  padding: 0;
  padding: 4px 14px 6px;
  border-width: 1px;
  border-style: solid;
  border-color: #DFDFDF;
  border-radius: 3px 3px 0 0;
  background: #FBFBFB;
  list-style: none;
  text-decoration: none;
  text-shadow: white 0 1px 0;
  white-space: nowrap;
  display: flex;
  align-items: center;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-icon-selector {
  float: left;
  margin-left: .5em;
  padding: 3px;
  width: 1em;
  height: 1em;
  border-radius: 2px;
  background: #fff;
  color: #666;
  text-align: center;
  font-size: 14px;
  font-family: "vamtam-icomoon";
  line-height: 1;
  cursor: pointer;
  order: -1;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-icon-selector.theme {
  font-family: "vamtam-theme";
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-icon-selector.no-icon {
  text-indent: -9999px;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-icon-selector.no-icon:before {
  display: block;
  content: "\e009";
  text-indent: 0;
  font-size: 11px;
  line-height: 14px;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-title {
  float: left;
  color: #AAA;
  text-decoration: none;
  font-size: 14px;
  font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
  line-height: 16px;
  cursor: pointer;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-title input {
  margin: -0.3em 0;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li.ui-tabs-active {
  border-bottom-color: #F9F9F9;
  background: #F9F9F9;
  -webkit-box-shadow: inset 0 1px 0 white;
  box-shadow: inset 0 1px 0 white;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li.ui-tabs-active .tab-title {
  color: #464646;
  cursor: normal;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li.ui-state-disabled .tab-title,
#wpv_visual_editor .ui-tabs .ui-tabs-nav li.ui-state-processing .tab-title {
  cursor: normal;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li.ui-state-disabled .tab-remove,
#wpv_visual_editor .ui-tabs .ui-tabs-nav li.ui-state-disabled .tab-clone,
#wpv_visual_editor .ui-tabs .ui-tabs-nav li.ui-state-processing .tab-remove,
#wpv_visual_editor .ui-tabs .ui-tabs-nav li.ui-state-processing .tab-clone {
  display: none;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-remove,
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-clone {
  float: right;
  margin-left: .5em;
  color: #f66;
  font-size: 10px;
  cursor: pointer;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-remove:hover,
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-clone:hover {
  color: #f33;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-clone {
  color: #666;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-clone:hover {
  color: #333;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-add {
  position: relative;
  top: 1px;
  display: block;
  color: #AAA;
  text-decoration: none;
  text-shadow: white 0px 1px 0px;
  font-size: 14px;
  line-height: 16px;
  cursor: pointer;
}
#wpv_visual_editor .ui-tabs .ui-tabs-nav li .tab-add:hover {
  color: #d54e21;
}
#wpv_visual_editor .ui-tabs .ui-tabs-panel {
  display: block;
  padding: 5px;
  border: 1px solid #dfdfdf;
  background: #f9f9f9;
}
#wpv_visual_editor .ui-accordion {
  width: 100%;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header {
  position: relative;
  margin-top: 1px;
  font-weight: inherit;
  font-size: inherit;
  font-family: inherit;
  cursor: pointer;
  zoom: 1;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header a {
  display: inline-block;
  padding: .5em 1em;
  color: #aaa;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header .accordion-remove,
#wpv_visual_editor .ui-accordion .ui-accordion-header .accordion-clone {
  display: inline-block;
  float: right;
  margin: .5em 1em .5em 0;
  padding: 0;
  color: #f66;
  font-size: 10px;
  cursor: pointer;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header .accordion-remove:hover,
#wpv_visual_editor .ui-accordion .ui-accordion-header .accordion-clone:hover {
  color: #f33;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header .accordion-clone {
  color: #666;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header .accordion-clone:hover {
  color: #333;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header .accordion-background-selector {
  float: left;
  margin-left: .5em;
  padding: 3px;
  width: 1em;
  height: 1em;
  border-radius: 2px;
  background: #fff;
  color: #666;
  content: "'";
  text-align: center;
  font-size: 14px;
  font-family: "vamtam-icomoon";
  line-height: 19px;
  cursor: pointer;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header-active {
  border-bottom: 0 !important;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header-active a {
  color: #464646;
}
#wpv_visual_editor .ui-accordion .ui-accordion-heading {
  display: block;
  padding: .5em .5em .5em .7em;
}
#wpv_visual_editor .ui-accordion .ui-accordion-content {
  box-sizing: border-box;
  position: relative;
  top: 1px;
  display: none;
  overflow: auto;
  margin-top: -2px;
  margin-bottom: 2px;
  padding: 5px;
  width: 100%;
  border: 1px dotted #cdcdcd;
  border-top: 0;
  zoom: 1;
}
#wpv_visual_editor .ui-accordion .ui-accordion-content-active {
  display: block;
  min-height: 2em;
}
#wpv_visual_editor .ui-accordion .accordion-add {
  display: inline-block;
  margin: -7px -10px;
  padding: 7px 0;
  width: 100%;
  color: #444;
  text-align: center;
  font-weight: normal;
  font-size: 14px;
  cursor: pointer;
}
#wpv_visual_editor .ui-accordion .accordion-add:hover {
  color: #d54e21;
}
@media (max-width: 1130px) {
  #visual_editor_edit_form .wpv-config-row.editor .rcontent {
    margin-left: 0;
  }
}
.wpv-editor-toggle.active {
  border-color: #CCC #CCC #E9E9E9;
  background-color: #E9E9E9;
  color: #333;
}
#wpv_visual_editor {
  display: none;
  background: #ffffff;
  min-height: 250px;
  width: 100%;
  padding: 10px;
  box-sizing: border-box;
}
#wpv_visual_editor.scrolled {
  padding-top: 38px;
}
#wpv_visual_editor.element-edit-mode {
  padding-top: 10px !important;
  overflow: visible !important;
}
#wpv_visual_editor.element-edit-mode .wpv_main_sortable {
  display: none;
}
#wpv_visual_editor .edit_title {
  background: #F1F1F1;
  padding: 5px 8px 8px;
  font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
  font-size: 11px;
  font-style: normal;
  font-weight: bold;
  line-height: 1em;
  margin: 0;
  text-align: center;
}
#visual_editor_content {
  font-size: 12px;
  clear: both;
  min-height: 190px;
  outline: 3px dashed #eee;
  position: relative;
  padding: .5%;
  background: #eee;
}
#visual_editor_content .inner-sortable-empty-notice {
  display: block;
  text-align: center;
  line-height: 50px;
}
#visual_editor_content > .inner-sortable-empty-notice {
  line-height: 190px;
}
#visual_editor_content.spinner {
  display: block;
  float: none;
  width: 100%;
  max-height: 190px;
  background-position: center center;
  padding: 0;
  margin: 0;
}
#visual_editor_content.spinner .column,
#visual_editor_content.spinner .inner-sortable-empty-notice {
  display: none;
}
#visual_editor_content .first {
  clear: both;
}
#visual_editor_content .column_placeholder {
  width: 120px;
  background: #FEFFAF;
  font-size: 0.9em;
  text-align: center;
  padding: 5px 10px 8px 5px;
  border: 1px solid #bbbbbb;
}
#visual_editor_content .column {
  box-sizing: border-box;
  height: 30px;
  overflow-y: hidden;
  position: relative;
  z-index: 0;
  border-color: #DFDFDF;
  box-shadow: inset 0 1px 0 #fff;
  border-radius: 3px;
  background: #fff;
}
#visual_editor_content .column:not(.expanded) .expanded {
  height: 30px;
}
#visual_editor_content .column:not(.expanded) .column {
  display: none;
}
#visual_editor_content .column.expanded {
  height: auto;
}
#visual_editor_content .column.expanded > .controls > .handlediv:before {
  content: '\f142';
}
#visual_editor_content .column.inner-sortable.wpv_ed_column {
  min-height: 0;
}
#visual_editor_content .column.inner-sortable.wpv_ed_column.expanded {
  min-height: 70px;
}
#visual_editor_content .column .controls {
  min-height: 15px;
  font-size: 15px;
  font-weight: normal;
  padding: 7px 10px;
  margin: -5px -5px 5px -5px;
  line-height: 1;
  cursor: move;
  box-shadow: 0 1px 0 #fff;
  position: relative;
  z-index: 100;
}
#visual_editor_content .column .controls:hover {
  color: #000;
}
#visual_editor_content .column .inner-sortable {
  min-height: 50px;
}
#visual_editor_content .column textarea.wpv-ed-param-holder {
  min-height: 120px;
}
#visual_editor_content .column.ui-draggable-dragging {
  max-width: 250px;
}
#visual_editor_content .column .controls {
  border-bottom: 1px solid #eee;
  border-radius: 0;
  background: #fff;
  text-shadow: none;
  font-family: "Open Sans", sans-serif;
}
#visual_editor_content .column .column-size-wrapper,
#visual_editor_content .column .column-remove,
#visual_editor_content .column .column-clone,
#visual_editor_content .column .column-edit,
#visual_editor_content .column .column-increase,
#visual_editor_content .column .column-decrease {
  background: #fff;
}
#visual_editor_content .column .column .controls {
  border-bottom: 1px solid #eee;
  border-radius: 0;
  background: #ededed;
  text-shadow: none;
  font-family: "Open Sans", sans-serif;
}
#visual_editor_content .column .column .column-size-wrapper,
#visual_editor_content .column .column .column-remove,
#visual_editor_content .column .column .column-clone,
#visual_editor_content .column .column .column-edit,
#visual_editor_content .column .column .column-increase,
#visual_editor_content .column .column .column-decrease {
  background: #ededed;
}
#visual_editor_content .column .column .column .controls {
  border-bottom: 1px solid #eee;
  border-radius: 0;
  background: #dbdbdb;
  text-shadow: none;
  font-family: "Open Sans", sans-serif;
}
#visual_editor_content .column .column .column .column-size-wrapper,
#visual_editor_content .column .column .column .column-remove,
#visual_editor_content .column .column .column .column-clone,
#visual_editor_content .column .column .column .column-edit,
#visual_editor_content .column .column .column .column-increase,
#visual_editor_content .column .column .column .column-decrease {
  background: #dbdbdb;
}
#visual_editor_content .column .column .column .column .controls {
  border-bottom: 1px solid #eee;
  border-radius: 0;
  background: #c9c9c9;
  text-shadow: none;
  font-family: "Open Sans", sans-serif;
}
#visual_editor_content .column .column .column .column .column-size-wrapper,
#visual_editor_content .column .column .column .column .column-remove,
#visual_editor_content .column .column .column .column .column-clone,
#visual_editor_content .column .column .column .column .column-edit,
#visual_editor_content .column .column .column .column .column-increase,
#visual_editor_content .column .column .column .column .column-decrease {
  background: #c9c9c9;
}
#visual_editor_content .column-decrease,
#visual_editor_content .column-increase,
#visual_editor_content .column-remove,
#visual_editor_content .column-clone,
#visual_editor_content .column-edit,
#visual_editor_content .tab-remove,
#visual_editor_content .tab-clone,
#visual_editor_content .accordion-remove,
#visual_editor_content .accordion-clone {
  display: inline-block;
  width: 12px;
  height: 12px;
  font-size: 10px;
  line-height: 18px;
  text-align: center;
  text-decoration: none;
  color: #666;
  z-index: 99;
}
#visual_editor_content .column-decrease:hover,
#visual_editor_content .column-increase:hover,
#visual_editor_content .column-remove:hover,
#visual_editor_content .column-clone:hover,
#visual_editor_content .column-edit:hover,
#visual_editor_content .tab-remove:hover,
#visual_editor_content .tab-clone:hover,
#visual_editor_content .accordion-remove:hover,
#visual_editor_content .accordion-clone:hover {
  text-decoration: none;
  color: #000;
}
#visual_editor_content .column-remove,
#visual_editor_content .column-clone,
#visual_editor_content .column-edit {
  top: 0;
  height: 29px;
  line-height: 29px;
  width: 15px;
}
#visual_editor_content .column-size-wrapper {
  position: relative;
  float: left;
  height: 29px;
  margin: -7px 0 -7px -10px;
  z-index: 100;
}
#visual_editor_content .column-size-wrapper .column-size {
  display: inline-block;
  font-size: 0.8em;
  position: relative;
  top: -7px;
  opacity: .8;
}
#visual_editor_content .column-increase-decrease {
  border-right: 1px solid #ddd;
  display: inline-block;
  padding: 3px 2px 0 2px;
}
#visual_editor_content .column-decrease,
#visual_editor_content .column-increase {
  color: #21759b;
  font-size: 10px;
  display: block;
  height: 13px;
  width: 15px;
  line-height: 13px;
}
#visual_editor_content .column-decrease:hover,
#visual_editor_content .column-increase:hover {
  color: #5c5c99;
}
#visual_editor_content .column-name {
  margin: 0 1em;
  white-space: nowrap;
  font-weight: bold;
  font-size: 14px;
}
#visual_editor_content .column-name:first-child {
  margin-left: 0;
}
#visual_editor_content .column-remove {
  display: none;
  color: #f66;
  margin-left: 1em;
}
#visual_editor_content .column-remove:hover {
  color: #f33;
}
#visual_editor_content .column:hover .column-remove {
  display: inline-block;
}
#visual_editor_content .handlediv {
  margin: -7px -10px;
  float: right;
  width: 25px;
  overflow: hidden;
}
#visual_editor_content .handlediv:before {
  display: inline-block;
  color: #888;
  content: '\f140';
  text-decoration: none !important;
  font: normal 20px/30px 'dashicons';
  speak: none;
  -webkit-font-smoothing: antialiased;
}
#visual_editor_content .column > .controls .column-edit,
#visual_editor_content .column > .controls .column-clone,
#visual_editor_content .column > .controls .column-remove {
  position: absolute;
}
#visual_editor_content .column > .controls .column-edit::before,
#visual_editor_content .column > .controls .column-clone::before,
#visual_editor_content .column > .controls .column-remove::before {
  line-height: 29px;
}
#visual_editor_content .column.non-expandable > .controls .column-edit {
  right: 25px;
}
#visual_editor_content .column.non-expandable > .controls .column-clone {
  right: 10px;
}
#visual_editor_content .column.non-expandable > .controls .column-remove {
  right: 40px;
}
#visual_editor_content .column.expandable > .controls .column-edit {
  right: 45px;
}
#visual_editor_content .column.expandable > .controls .column-clone {
  right: 30px;
}
#visual_editor_content .column.expandable > .controls .column-remove {
  right: 60px;
}
#visual_editor_content .wpved-tabs {
  overflow: hidden;
}
#visual_editor_content .narrow-column {
  overflow: hidden;
}
#visual_editor_content .narrow-column .controls {
  padding-right: 25px;
  cursor: pointer;
}
#visual_editor_content .narrow-column .controls .column-size-wrapper,
#visual_editor_content .narrow-column .controls .column-edit,
#visual_editor_content .narrow-column .controls .column-clone,
#visual_editor_content .narrow-column .controls .column-remove {
  display: none;
}
#visual_editor_content .narrow-column .controls .handlediv {
  position: absolute;
  right: 11px;
  top: 7px;
  z-index: 1000;
}
#visual_editor_content .narrow-column .controls .column-name {
  display: inline-block;
  margin: 0;
  height: 1em;
  overflow: hidden;
}
#visual_editor_content .narrow-column.very-narrow .column-size {
  display: none;
}
#visual_editor_content .narrow-column:hover .controls .column-name {
  display: none;
}
#visual_editor_content .narrow-column:hover .controls .column-size-wrapper,
#visual_editor_content .narrow-column:hover .controls .column-edit,
#visual_editor_content .narrow-column:hover .controls .column-clone,
#visual_editor_content .narrow-column:hover .controls .column-remove {
  display: block;
  position: absolute;
}
#visual_editor_content .column-1-1 {
  width: 99%;
}
#visual_editor_content .column-1-2 {
  width: 49%;
}
#visual_editor_content .column-1-3 {
  width: 32.333333333333%;
}
#visual_editor_content .column-1-4 {
  width: 24%;
}
#visual_editor_content .column-1-5 {
  width: 19%;
}
#visual_editor_content .column-1-6 {
  width: 15.666666666667%;
}
#visual_editor_content .column-2-3 {
  width: 65.666666666667%;
}
#visual_editor_content .column-2-5 {
  width: 39%;
}
#visual_editor_content .column-3-4 {
  width: 74%;
}
#visual_editor_content .column-3-5 {
  width: 59%;
}
#visual_editor_content .column-4-5 {
  width: 79%;
}
#visual_editor_content .column-5-6 {
  width: 82.333333333333%;
}
#visual_editor_content .wpv_main_sortable .column {
  padding: 5px;
  min-height: 60px;
}
#visual_editor_content .column,
#visual_editor_content .wpv_main_sortable .wpv_ed_cta_button {
  border: 1px solid #f0f0f0;
}
#visual_editor_content .column .textarea_html {
  margin: 5px 5px -10px 5px;
}
#visual_editor_content .column,
#visual_editor_content .wpv-sortable-placeholder {
  display: inline;
  float: left;
  position: relative;
  padding: 5px;
  margin: .5%;
}
#visual_editor_content p,
#poststuff #visual_editor_content p {
  margin: 0 0 1.3em 0;
  font-size: inherit;
  line-height: 150%;
}
#visual_editor_content p:last-child,
#poststuff #visual_editor_content p:last-child {
  margin-bottom: 0;
}
#visual_editor_content .alignleft {
  margin: 0 10px 10px 0;
}
#visual_editor_content .alignright {
  margin: 0 0 10px 10px;
}
#visual_editor_content .aligncenter {
  text-align: center;
  margin-bottom: 10px;
}
#visual_editor_content img.aligncenter {
  margin-left: auto;
  margin-right: auto;
  display: block;
}
#visual_editor_content ul,
#visual_editor_content ol {
  margin-left: 2.5em;
  margin-bottom: 1.3em;
}
#visual_editor_content ul {
  list-style: disc;
  margin-left: 2em;
}
#visual_editor_content ul li {
  padding-left: 0.5em;
}
#visual_editor_content .ui-tabs-nav {
  margin: 0;
}
#visual_editor_content .ui-tabs-nav li {
  padding-left: inherit;
  left: 3px;
  top: 3px;
  list-style: none;
}
#visual_editor_content blockquote {
  margin: 1em 0 1em 1.2em;
  padding-left: 1.2em;
  border-left: 3px solid #DFDFDF;
}
#visual_editor_content .wpv-ed-param-holder {
  width: 100%;
}
#visual_editor_content .wpv-ed-param-holder:empty:before {
  content: attr(placeholder);
}
#visual_editor_content img.wpv-ed-param-holder {
  width: auto;
  display: block;
  margin: auto;
}
#visual_editor_content textarea.wpv-ed-param-holder {
  min-height: 5em;
}
#visual_editor_content .toggle-title {
  border: 1px solid #ddd;
  margin: 0;
  padding: 5px;
  box-sizing: border-box;
}
#visual_editor_content .toggle-title:before {
  content: "+ ";
  color: green;
  font-weight: bold;
}
#visual_editor_content .toggle-content {
  border: 1px solid #ddd;
  border-top: 0;
  padding: 10px 5px 5px 5px;
  box-sizing: border-box;
}
#visual_editor_content .text-divider-text {
  position: absolute;
  top: 0;
  text-align: center;
  z-index: 0;
  left: 10%;
  width: 80%;
  line-height: 23px;
}
#visual_editor_content .wpv_expandable_services .inner-sortable {
  border: 1px dotted #cdcdcd;
  padding: 10px;
}
#visual_editor_content .slide-config {
  border: 1px solid #cdcdcd;
  margin: 5px 0;
}
#visual_editor_content .wpv-sortable-placeholder {
  background-color: #f5f5f5;
  border: 1px dashed #bbb;
  max-width: 100%;
  box-sizing: border-box;
}
#visual_editor_content.wpv-dd-active,
#visual_editor_content .wpv-dd-active {
  background: #F1FA93 !important;
}
#visual_editor_content.wpv-dd-active > .controls,
#visual_editor_content.wpv-dd-active > .controls .column-size-wrapper,
#visual_editor_content.wpv-dd-active > .controls .column-remove,
#visual_editor_content.wpv-dd-active > .controls .column-clone,
#visual_editor_content.wpv-dd-active > .controls .column-edit,
#visual_editor_content .wpv-dd-active > .controls,
#visual_editor_content .wpv-dd-active > .controls .column-size-wrapper,
#visual_editor_content .wpv-dd-active > .controls .column-remove,
#visual_editor_content .wpv-dd-active > .controls .column-clone,
#visual_editor_content .wpv-dd-active > .controls .column-edit {
  background-color: #F1FA93 !important;
}
#visual_editor_edit_form {
  display: none;
  margin: 0 0 40px 0;
  border: 1px solid #DFDFDF;
  background: #F9F9F9;
  border-radius: 3px;
}
#visual_editor_edit_form .wp-editor-container {
  background: #fff;
}
#visual_editor_edit_form .wpv-config-group {
  border: 0;
  background: transparent;
}
#visual_editor_edit_form .wpv-config-group .last-row {
  padding-top: 40px;
  padding-right: 20px;
  text-align: right;
}
#visual_editor_edit_form .wpv-config-group .shortcode-title {
  padding: 20px;
  position: relative;
  border-radius: 3px 3px 0 0;
}
#visual_editor_edit_form .wpv-config-group .shortcode-title h3 {
  border-radius: 3px 3px 0 0;
  font-size: 18px;
  line-height: 28px;
  margin: 0;
}
#visual_editor_edit_form .wpv-config-group .shortcode-title .action-buttons {
  position: absolute;
  right: 20px;
  top: 20px;
}
#visual_editor_edit_form .wpv-config-group .wpv-cancel-element {
  display: inline-block;
  padding-right: 10px;
}
#visual_editor_edit_form .wpv-config-group .wpv-save-element:active {
  vertical-align: baseline;
}
#visual_editor_edit_form .wp-editor-wrap {
  max-width: 99%;
}
#visual_editor_edit_form textarea {
  min-height: 300px;
  width: 100%;
}
#visual_editor_edit_form.inner-column .hide-inner,
#visual_editor_edit_form.column-1-1 .hide-1-1,
#visual_editor_edit_form.column-1-2 .hide-1-2,
#visual_editor_edit_form.column-1-3 .hide-1-3,
#visual_editor_edit_form.column-1-4 .hide-1-4,
#visual_editor_edit_form.column-1-5 .hide-1-5,
#visual_editor_edit_form.column-1-6 .hide-1-6,
#visual_editor_edit_form.column-2-3 .hide-2-3,
#visual_editor_edit_form.column-2-5 .hide-2-5,
#visual_editor_edit_form.column-3-4 .hide-3-4,
#visual_editor_edit_form.column-3-5 .hide-3-5,
#visual_editor_edit_form.column-3-5 .hide-3-5,
#visual_editor_edit_form.column-4-5 .hide-4-5,
#visual_editor_edit_form.column-4-5 .hide-4-5,
#visual_editor_edit_form.column-5-6 .hide-5-6 {
  display: none !important;
}
#visual_editor_edit_form[data-ff-fbprlx-state="fixed"] .bg-block.bg-attachment,
#visual_editor_edit_form[data-ff-fbprlx-state="fixed"] .bg-block.bg-position,
#visual_editor_edit_form[data-ff-fbprlx-state="to-centre"] .bg-block.bg-attachment,
#visual_editor_edit_form[data-ff-fbprlx-state="to-centre"] .bg-block.bg-position {
  display: none !important;
}
.edit_form .mceEditor {
  display: block;
}
.wpv_media-buttons {
  margin: 0 auto 8px auto;
  min-width: 500px;
  width: 100%;
}
.wpv_media-buttons a img {
  vertical-align: middle;
}
.wpv_media-buttons a {
  padding: 0 0 5px 8px;
}
.visual_editor_tinymce {
  width: 780px;
  height: 300px;
  margin: 0 auto;
  display: block;
}
.edit_form_actions {
  border-top: 1px solid #DDDDDD;
  background: #EAF2FA;
  padding: 12px;
  clear: both;
  text-align: center;
}
#wpv-editor-title {
  line-height: 24px;
  font-size: 14px;
  margin-right: 10px;
}
#menu-wpv-editor .submenu ul {
  width: 400px;
}
#menu-wpv-editor .submenu ul li div {
  border: 1px solid #f1f1f1;
  padding: 10px 10px;
}
#wpv-editor-shortcodes {
  border: 1px solid #ccc;
  border-radius: 3px;
  padding: 5px;
  margin-bottom: 20px;
  background-color: #f1f1f1;
  background-image: -webkit-linear-gradient(top,#ececec 0%,#f9f9f9 100%);
  background-image: linear-gradient(to bottom,#ececec 0%,#f9f9f9 100%);
}
#wpv-editor-shortcodes > ul > li h5 {
  margin: 0 0 10px 0;
  text-transform: capitalize;
  font-size: 11px;
  text-align: center;
}
#wpv-editor-shortcodes > ul > li li {
  display: inline-block;
  margin: 2.5px;
  border: 1px solid #ccc;
  position: relative;
  text-align: center;
  background-color: #fff;
  vertical-align: top;
}
#wpv-editor-shortcodes > ul > li li > a {
  display: inline-block;
  padding: 5px;
  width: 65px;
  min-height: 65px;
  text-decoration: none;
  -moz-hyphens: auto;
  -webkit-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto;
}
#wpv-editor-shortcodes > ul > li li > a.added {
  cursor: default;
}
#wpv-editor-shortcodes > ul > li li > a.added span {
  opacity: 0;
}
#wpv-editor-shortcodes > ul > li li > a.added:before {
  position: absolute;
  left: 50%;
  top: 50%;
  margin: -0.5em;
  font-size: 40px;
}
#wpv-editor-shortcodes > ul > li li .title {
  color: #777;
  display: block;
  margin-top: 4px;
  font-size: 11px;
}
#wpv-editor-shortcodes > ul > li li .description {
  position: absolute;
  top: 5px;
  left: 60px;
  padding-top: 25px;
  text-align: left;
}
#wpv-editor-shortcodes > ul > li li .description .description-trigger {
  position: absolute;
  top: 0;
  left: 0;
}
#wpv-editor-shortcodes > ul > li li .description > div {
  display: none;
  border: 1px solid #ccc;
  background: #fff;
  box-shadow: 2px 3px 6px rgba(0,0,0,0.4);
  position: relative;
  width: 380px;
  margin-left: -12px;
  z-index: 10;
}
#wpv-editor-shortcodes > ul > li li .description > div .content {
  padding: 14px;
}
#wpv-editor-shortcodes > ul > li li .description > div footer {
  padding: 9px 14px;
  border-top: 1px solid #ccc;
  background: #f1f1f1;
}
#wpv-editor-shortcodes > ul > li li .description > div:after,
#wpv-editor-shortcodes > ul > li li .description > div:before {
  top: 0;
  left: 5px;
  border: solid transparent;
  content: "";
  height: 0;
  width: 0;
  position: absolute;
}
#wpv-editor-shortcodes > ul > li li .description > div:after {
  border-bottom-color: #fff;
  border-width: 10px;
  z-index: 100;
  margin-top: -20px;
  margin-left: 1px;
}
#wpv-editor-shortcodes > ul > li li .description > div:before {
  border-bottom-color: #989898;
  border-width: 11px;
  z-index: 99;
  margin-top: -22px;
}
#wpv-editor-shortcodes > ul > li li .description:hover > div {
  display: block;
}
#wpv-editor-shortcodes > ul > li:last-child {
  margin-bottom: 0;
}
.wp-editor-tools {
  min-height: 30px;
}
.wpv-editor-toggle.active {
  border-color: #dedede;
  border-bottom: 1px solid #f5f5f5;
  background: #f5f5f5;
}
#wpv_visual_editor {
  margin-top: 2px;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header {
  border: 1px dotted #ccc;
}
#wpv_visual_editor .ui-accordion .ui-accordion-header-active {
  border-bottom: 1px dotted #ccc !important;
}
#wpv-editor-shortcodes {
  margin: -10px -10px 20px -10px;
  border: 0;
  border-bottom: 1px solid #dedede;
  border-radius: 0;
  background: #f5f5f5;
}
#wpv-editor-shortcodes > ul {
  margin: 0;
}
.vamtam-editor-active {
  padding-top: 0 !important;
}
.vamtam-editor-active > #wp-content-editor-tools {
  position: static !important;
  top: 0 !important;
}
