<?php
/**
 * TinyMCE-based shortcode generator
 *
 * @package wpv
 * @subpackage construction
 */

return array(
	'button',
	'dropcap',
	'highlight',
	'icon',
	'inline_divider',
	'list',
	'push',
	'tooltip',
);