.body-layout img.selected,
.body-layout img:hover,
.wpv-autofill.selected img,
.wpv-autofill:hover img {
	border-color: #288BB9;
	border-width: 2px;
	margin: -1px;
}

#wpv-templates-name {
	width: 182px;
}

#wpv-ajax-content {
	background-color: #666;
	line-height: 1.5;
}

#wpv-config-tabs {
	position: relative;
	z-index: 50;
}
#wpv-config-tabs {
	z-index: 40;
}

#adminmenuwrap {
	z-index: 120;
}

#adminmenu {
	zoom: 1;
}

#adminmenu li {
	z-index: 60;
}

.ui-range-slider {
	position: relative;
}
