.sitemap {
	ul {
		list-style-type: none;

		li {
			padding-left: 1.5em;
			text-indent: -1.5em;

			&:before {
				text-indent: 0;
				font-family: theme;
				padding-right: .5em;
				font-size: 8px;
				vertical-align: middle;
			}
		}

		> li {
			&:before {
				content: icon(angle-bottom);

			}

			li {
				font-size: .9em;

				&:before {
					content: icon(angle-right);
				}
			}
		}
	}

	.top + h2 {
		margin-top: 20px;
	}
}