html, body, th, td, p {
	color: @primary-font-color;
}

.accent-1 { color: @accent-color-1; }
.accent-2 { color: @accent-color-2; }
.accent-3 { color: @accent-color-3; }
.accent-4 { color: @accent-color-4; }
.accent-5 { color: @accent-color-5; }
.accent-6 { color: @accent-color-6; }
.accent-7 { color: @accent-color-7; }
.accent-8 { color: @accent-color-8; }

.hover-accent-1:hover { color: @accent-color-1; }
.hover-accent-2:hover { color: @accent-color-2; }
.hover-accent-3:hover { color: @accent-color-3; }
.hover-accent-4:hover { color: @accent-color-4; }
.hover-accent-5:hover { color: @accent-color-5; }
.hover-accent-6:hover { color: @accent-color-6; }
.hover-accent-7:hover { color: @accent-color-7; }
.hover-accent-8:hover { color: @accent-color-8; }

*,
p,
.main-container {
	.wpv-font(primary-font-);
}

.page-header .desc,
.page-header .desc a,
em {
	.wpv-font(em-);
	.wpv-color(em-);
}

h1 {
	&, a, a:visited { .wpv-color(h1-); }
	&, a { .wpv-font(h1-); }
	footer.main-footer & a { .wpv-font(h1-); }

	em {
		font: ~"@{em-weight}" @h1-size/@h1-lheight @em-face;
		color: @h1-color;
	}
}

h2 {
	&, a, a:visited { .wpv-color(h2-); }
	&, a { .wpv-font(h2-); }
	footer.main-footer & a { .wpv-font(h2-); }

	em {
		font: ~"@{em-weight}" @h2-size/@h2-lheight @em-face;
		color: @h2-color;
	}
}

h3 {
	&, a, a:visited { .wpv-color(h3-); }
	&, a { .wpv-font(h3-); }
	footer.main-footer & a { .wpv-font(h3-); }

	em {
		font: ~"@{em-weight}" @h3-size/@h3-lheight @em-face;
		color: @h3-color;
	}
}

h4 {
	&, a, a:visited { .wpv-color(h4-); }
	&, a { .wpv-font(h4-); }
	footer.main-footer & a { .wpv-font(h4-); }

	em {
		font: ~"@{em-weight}" @h4-size/@h4-lheight @em-face;
		color: @h4-color;
	}
}

h5 {
	&, a, a:visited { .wpv-color(h5-); }
	&, a { .wpv-font(h5-); }
	footer.main-footer & a { .wpv-font(h5-); }

	em {
		font: ~"@{em-weight}" @h5-size/@h5-lheight @em-face;
		color: @h5-color;
	}
}

h6 {
	&, a, a:visited { .wpv-color(h6-); }
	&, a { .wpv-font(h6-); }
	footer.main-footer & a { .wpv-font(h6-); }

	em {
		font: ~"@{em-weight}" @h6-size/@h6-lheight @em-face;
		color: @h6-color;
	}
}

small {
	color: #e2e2e2;
	font-size: 11px !important;
}

a {
	text-decoration: none;
	color: @css_link_color;
	transition: color .3s;

	.icon.shortcode.use-hover {
		transition: all .3s ease;
	}

	&:hover {
		text-decoration: none;
		color: @css_link_hover_color;

		.icon.shortcode.use-hover {
			color: @accent-color-2;
		}
	}
}

p { margin: 1em 0 }

p:empty {display: none}

h1, h2, h3, h4, h5, h6 {
	margin-top: 0.6em;
	margin-bottom: 0.6em
}

.vamtam-font-style-1 {
	.wpv-font( additional-font-1- );
	padding-bottom: 10px;

	&.with-color {
		color: @additional-font-1-color;
	}
}

.vamtam-font-style-2 {
	.wpv-font( additional-font-2- );

	&.with-color {
		color: @additional-font-2-color;
	}
}