.select2-container {
  display: block!important;
  margin: 0;
  position: relative;
  vertical-align: middle;
  zoom: 1;
}
.select2-container,.select2-drop,.select2-search,.select2-search input {
  box-sizing: border-box;
  moz-box-sizing: border-box;
  webkit-box-sizing: border-box;
}
.select2-container .select2-choice {
  background-clip: padding-box;
  background-color: #fff;
  border: 1px solid #ccc;
  border-radius: 3px;
  color: #444;
  display: block;
  font-weight: 400;
  moz-user-select: none;
  ms-user-select: none;
  overflow: hidden;
  padding: 0 0 0 8px;
  position: relative;
  text-decoration: none;
  user-select: none;
  webkit-touch-callout: none;
  webkit-user-select: none;
  white-space: nowrap;
}
html[dir=rtl] .select2-container .select2-choice {
  padding: 0 8px 0 0;
}
.select2-container.select2-drop-above .select2-choice {
  border-bottom-color: #ccc;
  border-radius: 0 0 4px 4px;
}
.select2-container.select2-allowclear .select2-choice .select2-chosen {
  margin-right: 42px;
}
.select2-container .select2-choice>.select2-chosen {
  display: block;
  float: none;
  margin-right: 26px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  width: auto;
}
html[dir=rtl] .select2-container .select2-choice>.select2-chosen {
  margin-left: 26px;
  margin-right: 0;
}
.select2-container .select2-choice abbr {
  background: url(../images/select2.png) right top no-repeat;
  border: 0;
  cursor: pointer;
  display: none;
  font-size: 1px;
  height: 12px;
  outline: 0;
  position: absolute;
  right: 24px;
  text-decoration: none;
  top: 5px;
  width: 12px;
}
.select2-container.select2-allowclear .select2-choice abbr {
  display: inline-block;
}
.select2-container .select2-choice abbr:hover {
  background-position: right -11px;
  cursor: pointer;
}
.select2-drop-mask {
  background-color: #fff;
  border: 0;
  filter: alpha(opacity=0);
  height: auto;
  left: 0;
  margin: 0;
  min-height: 100%;
  min-width: 100%;
  opacity: 0;
  padding: 0;
  position: fixed;
  top: 0;
  width: auto;
  z-index: 9998;
}
.select2-drop {
  background: #fff;
  border: 1px solid #ccc;
  border-radius: 0 0 3px 3px;
  border-top: 0;
  color: #000;
  margin-top: -1px;
  position: absolute;
  top: 100%;
  width: 100%;
  z-index: 9999;
}
.select2-drop.select2-drop-above {
  border-bottom: 0;
  border-radius: 3px 3px 0 0;
  border-top: 1px solid #ccc;
  margin-top: 1px;
}
.select2-drop-active {
  border: 1px solid #666;
  border-top: none;
}
.select2-drop.select2-drop-above.select2-drop-active {
  border-top: 1px solid #666;
}
.select2-drop-auto-width {
  border-top: 1px solid #ccc;
  width: auto;
}
.select2-drop-auto-width .select2-search {
  padding-top: 4px;
}
.select2-container .select2-choice .select2-arrow {
  background-clip: padding-box;
  border-radius: 0 3px 3px 0;
  display: inline-block;
  height: 100%;
  position: absolute;
  right: 0;
  top: 0;
  width: 18px;
}
html[dir=rtl] .select2-container .select2-choice .select2-arrow {
  border-radius: 3px 0 0 3px;
  left: 0;
  right: auto;
}
.select2-container .select2-choice .select2-arrow b {
  display: block;
  height: 100%;
  position: relative;
  width: 100%;
}
.select2-container .select2-choice .select2-arrow b:after {
  border: 4px solid transparent;
  border-top-color: #666;
  content: "";
  display: block;
  left: 50%;
  margin-left: -7px;
  margin-top: -2px;
  position: absolute;
  top: 50%;
}
.select2-search {
  display: inline-block;
  margin: 0;
  padding-bottom: 4px;
  padding-left: 4px;
  padding-right: 4px;
  position: relative;
  white-space: nowrap;
  width: 100%;
  z-index: 10000;
}
.select2-search input {
  background: url(../images/select2.png) 100% -22px no-repeat #fff;
  border: 1px solid #ccc;
  box-shadow: none;
  font-family: sans-serif;
  font-size: 1em;
  height: auto!important;
  margin: 0;
  outline: 0;
  padding: 4px 20px 4px 5px!important;
  webkit-box-shadow: none;
  width: 100%;
}
html[dir=rtl] .select2-search input {
  background: url(../images/select2.png) -37px -22px no-repeat #fff;
  padding: 4px 5px 4px 20px;
}
.select2-drop.select2-drop-above .select2-search input {
  margin-top: 4px;
}
.select2-search input.select2-active {
  background: url(../images/select2-spinner.gif) no-repeat 100% #fff;
}
.select2-container-active .select2-choice,.select2-container-active .select2-choices {
  border: 1px solid #666;
  outline: 0;
}
.select2-dropdown-open .select2-choice {
  border-bottom-color: transparent;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  box-shadow: 0 1px 0 #fff inset;
  webkit-box-shadow: 0 1px 0 #fff inset;
}
.select2-dropdown-open .select2-choice .select2-arrow b:after {
  border-bottom-color: #666;
  border-top-color: transparent;
  margin-top: -6px;
}
.select2-dropdown-open.select2-drop-above .select2-choice,.select2-dropdown-open.select2-drop-above .select2-choices {
  border: 1px solid #666;
  border-top-color: transparent;
}
.select2-dropdown-open .select2-choice .select2-arrow {
  background: 0 0;
  border-left: none;
  filter: none;
}
html[dir=rtl] .select2-dropdown-open .select2-choice .select2-arrow {
  border-right: none;
}
.select2-dropdown-open .select2-choice .select2-arrow b {
  background-position: -18px 1px;
}
html[dir=rtl] .select2-dropdown-open .select2-choice .select2-arrow b {
  background-position: -16px 1px;
}
.select2-hidden-accessible {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
}
.select2-results {
  background: #fafafa;
  margin: 0;
  max-height: 200px;
  overflow-x: hidden;
  overflow-y: auto;
  padding: 4px;
  position: relative;
  webkit-tap-highlight-color: transparent;
}
html[dir=rtl] .select2-results {
  margin: 4px 0 4px 4px;
  padding: 0 4px 0 0;
}
.select2-results ul.select2-result-sub {
  margin: 0;
  padding-left: 0;
}
.select2-results li {
  background-image: none;
  display: list-item;
  list-style: none;
  margin: 3px 0;
}
.select2-results li.select2-result-with-children>.select2-result-label {
  font-weight: 700;
}
.select2-results .select2-result-label {
  cursor: pointer;
  margin: 0;
  min-height: 1em;
  moz-user-select: none;
  ms-user-select: none;
  padding: 5px 7px;
  user-select: none;
  webkit-touch-callout: none;
  webkit-user-select: none;
}
.select2-results-dept-1 .select2-result-label {
  padding-left: 20px;
}
.select2-results-dept-2 .select2-result-label {
  padding-left: 40px;
}
.select2-results-dept-3 .select2-result-label {
  padding-left: 60px;
}
.select2-results-dept-4 .select2-result-label {
  padding-left: 80px;
}
.select2-results-dept-5 .select2-result-label {
  padding-left: 100px;
}
.select2-results-dept-6 .select2-result-label {
  padding-left: 110px;
}
.select2-results-dept-7 .select2-result-label {
  padding-left: 120px;
}
.select2-results .select2-highlighted {
  background: #f1f1f1;
  border-radius: 3px;
}
.select2-results li em {
  background: #feffde;
  font-style: normal;
}
.select2-results .select2-highlighted em {
  background: 0 0;
}
.select2-results .select2-highlighted ul {
  background: #fff;
  color: #000;
}
.select2-results .select2-ajax-error,.select2-results .select2-no-results,.select2-results .select2-searching,.select2-results .select2-selection-limit {
  background: #f4f4f4;
  display: list-item;
  padding-left: 5px;
}
.select2-results .select2-disabled.select2-highlighted {
  background: #f4f4f4;
  color: #666;
  cursor: default;
  display: list-item;
}
.select2-results .select2-disabled {
  background: #f4f4f4;
  cursor: default;
  display: list-item;
}
.select2-results .select2-selected {
  display: none;
}
.select2-more-results.select2-active {
  background: url(../images/select2-spinner.gif) no-repeat 100% #f4f4f4;
}
.select2-results .select2-ajax-error {
  background: rgba(255,50,50,.2);
}
.select2-more-results {
  background: #f4f4f4;
  display: list-item;
}
.select2-container.select2-container-disabled .select2-choice {
  background-color: #f4f4f4;
  background-image: none;
  border: 1px solid #ddd;
  cursor: default;
}
.select2-container.select2-container-disabled .select2-choice .select2-arrow {
  background-color: #f4f4f4;
  background-image: none;
  border-left: 0;
}
.select2-container.select2-container-disabled .select2-choice abbr {
  display: none;
}
.select2-container-multi .select2-choices {
  background-color: #fff;
  border: 1px solid #ccc;
  cursor: text;
  height: 1%;
  height: auto!important;
  margin: 0;
  overflow: hidden;
  padding: 0 5px 0 0;
  position: relative;
}
html[dir=rtl] .select2-container-multi .select2-choices {
  padding: 0 0 0 5px;
}
.select2-locked {
  padding: 3px 5px!important;
}
.select2-container-multi .select2-choices {
  min-height: 26px;
}
.select2-container-multi.select2-container-active .select2-choices {
  border: 1px solid #666;
  outline: 0;
}
.select2-container-multi .select2-choices li {
  float: left;
  list-style: none;
}
html[dir=rtl] .select2-container-multi .select2-choices li {
  float: right;
}
.select2-container-multi .select2-choices .select2-search-field {
  margin: 0;
  padding: 0;
  white-space: nowrap;
}
.select2-container-multi .select2-choices .select2-search-field input {
  background: 0 0!important;
  border: 0;
  box-shadow: none;
  font-family: sans-serif;
  margin: 1px 0;
  outline: 0;
  padding: 5px;
  webkit-box-shadow: none;
}
.select2-container-multi .select2-choices .select2-search-field input.select2-active {
  background: url(../images/select2-spinner.gif) no-repeat 100% #fff!important;
}
.select2-default {
  color: #999!important;
}
.select2-container-multi .select2-choices .select2-search-choice {
  background-clip: padding-box;
  background-color: #e4e4e4;
  border-radius: 2px;
  color: #333;
  cursor: default;
  line-height: 15px;
  margin: 3px 0 3px 5px;
  moz-user-select: none;
  ms-user-select: none;
  padding: 5px 8px 5px 24px;
  position: relative;
  user-select: none;
  webkit-touch-callout: none;
  webkit-user-select: none;
}
html[dir=rtl] .select2-container-multi .select2-choices .select2-search-choice {
  margin: 3px 5px 3px 0;
  padding: 5px 24px 5px 8px;
}
.select2-container-multi .select2-choices .select2-search-choice .select2-chosen {
  cursor: default;
}
.select2-container-multi .select2-choices .select2-search-choice-focus {
  background: #d4d4d4;
}
.select2-search-choice-close {
  background: url(../images/select2.png) right top no-repeat;
  display: block;
  font-size: 1px;
  height: 13px;
  outline: 0;
  position: absolute;
  right: 7px;
  top: 6px;
  width: 12px;
}
html[dir=rtl] .select2-search-choice-close {
  left: 7px;
  right: auto;
}
.select2-container-multi .select2-search-choice-close {
  left: 7px;
}
html[dir=rtl] .select2-container-multi .select2-search-choice-close {
  left: auto;
  right: 7px;
}
.select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close:hover,.select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close {
  background-position: right -11px;
}
.select2-container-multi.select2-container-disabled .select2-choices {
  background-color: #f4f4f4;
  background-image: none;
  border: 1px solid #ddd;
  cursor: default;
}
.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice {
  background-color: #f4f4f4;
  background-image: none;
  border: 1px solid #ddd;
  padding: 3px 5px;
}
.select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close {
  background: 0 0;
  display: none;
}
.select2-result-selectable .select2-match,.select2-result-unselectable .select2-match {
  text-decoration: underline;
}
.select2-offscreen,.select2-offscreen:focus {
  border: 0!important;
  clip: rect(0 0 0 0)!important;
  height: 1px!important;
  left: 0!important;
  margin: 0!important;
  outline: 0!important;
  overflow: hidden!important;
  padding: 0!important;
  position: absolute!important;
  top: 0!important;
  width: 1px!important;
}
.select2-display-none {
  display: none;
}
.select2-measure-scrollbar {
  height: 100px;
  left: -10000px;
  overflow: scroll;
  position: absolute;
  top: -10000px;
  width: 100px;
}
@media only screen and (-webkit-min-device-pixel-ratio:1.5),only screen and (min-resolution:2dppx) {
  .select2-search input {
    background-image: url(../images/select2x2.png)!important;
    background-position: 100% -21px!important;
    background-repeat: no-repeat!important;
    background-size: 60px 40px!important;
  }
}