.icon {

	&.shortcode {
		line-height: 1.15;

		&.inverted-colors {
			border-radius: 1000px;
			padding: .4em !important;
			width: 1.15em;
			height: 1.15em;
			text-align: center;
		}

		&.box {
		}

		&.border {
		}

		&.box,
		&.border {
			padding: .6em;
			position: relative;
			min-height: 1em;
			min-width: 1em;
			.transition(all 0.5s);

			svg {
				position: absolute;
				width: 100%;
				height: 100%;
				top: 0;
				left: 0;
			}

			.char {
				position: relative;
			}
		}

		h1 &,
		h2 &,
		h3 &,
		h4 &,
		h5 &,
		h6 & {
			vertical-align: bottom;
		}
	}
}