@font-face {
	font-family: 'vamtam-editor';
	src:url('../fonts/vamtam-editor.eot');
	src:url('../fonts/vamtam-editor.eot?#iefix') format('embedded-opentype'),
		url('../fonts/vamtam-editor.svg#vamtam-editor') format('svg'),
		url('../fonts/vamtam-editor.woff') format('woff'),
		url('../fonts/vamtam-editor.ttf') format('truetype');
	font-weight: normal;
	font-style: normal;
}

@font-face {
	font-family: 'vamtam-editor-icomoon';
	src: url(../fonts/icomoon/icons.eot);
	src: url(../fonts/icomoon/icons.eot?#iefix) format('embedded-opentype'),
		url(../fonts/icomoon/icons.ttf) format('truetype');
	font-weight: normal;
	font-style: normal;
}

[class^="icon-"]:before,
[class*=" icon-"]:before,
[class^="a-icon-"]:before,
[class*=" a-icon-"]:before {
	font-family: 'vamtam-editor';
	font-style: normal;
	speak: none;
	font-weight: normal;
	line-height: 1;
	-webkit-font-smoothing: antialiased;
}

.icon-minus:before {
	content: "\e000";
}
.icon-plus:before {
	content: "\e001";
}
.icon-copy:before {
	content: "\e002";
}
.icon-edit:before {
	content: "\e003";
}
.icon-menu:before {
	content: "\e004";
}
.icon-remove:before {
	content: "\e005";
}
.icon-checkmark:before {
	content: "\e006";
}
.a-icon-checkmark:before {
	content: "\e006";
}