@footer-border-color: darken(@footer-background-color, 5);

footer.main-footer {
	position: relative;

	div.wpcf7 {
		input,
		textarea,
		select {
			background: none !important;
			color: @accent-color-4;
			border: 1px solid fade(@accent-color-8, 15%);

			&:hover {
				border-color: rgba(255, 255, 255, 0.3);
			}
		}

		select {
			height: 30px;
		}

		input.wpcf7-submit:hover {
			border-color: @accent-color-1;
		}
	}

	.sep-3 {
		margin: 0px; opacity: 0.2;
	}


	.bg(
		@footer-background-image,
		@footer-background-repeat,
		@footer-background-position,
		@footer-background-attachment,
		@footer-background-color,
		@footer-background-size
	);
	.rgba-bg(fadeout(@footer-background-color, 100% * (1 - @footer-background-opacity)));

	&, p, a, th, td {
		.wpv-font(footer-sidebars-font-);
		.wpv-color(footer-sidebars-font-);
	}

	p {
		line-height: 170%;
	}

	.widget {
		li {
			background: transparent;
			border-bottom: none !important;
		}

		&.widget_nav_menu {
			#menu-horizontal-footer {
				text-align: center;

				li {
					display: inline-block;
					vertical-align: top;

					&:hover,
					&.current-menu-item {
						a {
							background: none;
							color: @accent-color-1 !important;
						}
					}

					a {
						padding: 5px 20px;
						color: @footer-sidebars-titles-color;
						font-size: 14px;
					}
				}
			}

			.menu {
				li {
					&:last-child,
					&.last-child { border-bottom: none; }

					a {
						color: @css_footer_link_color;
						padding: 5px 8px 8px 3px;

						&:visited {
							color: @css_footer_link_visited_color !important;
						}

						&:hover {
							color: @css_footer_link_hover_color !important;
							text-decoration: none !important;
							background: none;
						}
					}

					&:hover,
					&.current_page_item {
						position : relative;

						a {
							color: @css_footer_link_visited_color;
							background: none;
						}
					}
				}
			}
		}

		.widget-title {
			border: none;
			text-align: left;
			padding: 0;
			margin: 0 0 10px;
			.wpv-font(footer-sidebars-titles-) !important;
			.wpv-color(footer-sidebars-titles-) !important;

			> .icon {

				margin-bottom: 17px;
			}
		}
	}

	a {
		color: @css_footer_link_color;
		.transition(all .3s ease);

		&:visited {
			color: @css_footer_link_visited_color;
		}

		h4 {
			color: @accent-color-8 !important;
		}

		&:hover {
			color: @css_footer_link_hover_color;
			text-decoration: none;

			.icon.shortcode {
				color: @css_footer_link_hover_color !important;
			}
		}
	}
}

#footer-sidebars {
	max-width: @site-max-width;
	margin: 0 auto;
	.border-box();
	position: relative;

	.row {
		&:first-child:not(:last-child) {
			border-bottom: solid 1px fade(@accent-color-7 20%);
			margin-bottom: 30px;
		}
	}

	> .row {
		aside {
			border-right: 0;
			padding: 10px 0 30px;
			float: left;
			.border-box();

			&.full { width: percentage(1/1); }
			&.cell-1-2 { width: percentage(1/2); }
			&.cell-1-3 { width: percentage(1/3); }
			&.cell-1-4 { width: percentage(1/4); }
			&.cell-1-5 { width: percentage(1/5); }
			&.cell-1-6 { width: percentage(1/6); }
			&.cell-2-3 { width: percentage(2/3); }
			&.cell-2-4 { width: percentage(2/4); }
			&.cell-2-5 { width: percentage(2/5); }
			&.cell-2-6 { width: percentage(2/6); }
			&.cell-3-4 { width: percentage(3/4); }
			&.cell-3-5 { width: percentage(3/5); }
			&.cell-3-6 { width: percentage(3/6); }
			&.cell-4-5 { width: percentage(4/5); }
			&.cell-4-6 { width: percentage(4/6); }
			&.cell-5-6 { width: percentage(5/6); }
			&.last {
				border-right: 0;
			}
		}

		.widget {
			padding-left: 30px;
			padding-right: 30px;

			&,
			&:last-child {
				margin-bottom: 0;
				padding-bottom: 0px;
			}

			.widget-title {
				text-align: left;
				padding-top: 0px;
				padding-bottom: 5px;
				letter-spacing: 2px;
			}
		}
	}

	.wpv_icon_link {
		li {
			padding: 5px;

			&:first-child {
				padding-top: 0;
			}
	 	}
     }

	.wpv_posts {
		.wpv-tabs > ul {
			border-bottom-color: @footer-border-color;
			background-color: @footer-background-color;

			li {
				border-bottom: 1px solid transparent !important;

				&.ui-state-hover,
				&.ui-state-selected,
				&.ui-state-active {
					border-color: @footer-border-color;
					background: transparent;
					border-bottom-color: @footer-background-color !important;
				}
			}
		}

		.ui-tabs-panel {
			border-color: @footer-border-color;
		}

		.posts_list {
			li {
				border-top-color: @footer-border-color;
				padding: 0 0 10px 0;
			}
		}
	}
}

.copyrights {
	.bg(
		@subfooter-background-image,
		@subfooter-background-repeat,
		@subfooter-background-position,
		@subfooter-background-attachment,
		@subfooter-background-color,
		@subfooter-background-size
	);

	padding: 25px 30px;
	margin: 0;
	position: relative;
	z-index: 5;

	.alignright,
	.alignleft {
		margin: 0px !important;
	}

	a {

		color: @css_footer_link_color;
		.transition(all .3s ease);

		&:visited {
			color: @css_footer_link_visited_color;
		}

		&:hover {
			color: @accent-color-6;
			text-decoration: none;

			.icon.shortcode {
				color: @accent-color-6 !important;
			}
		}
	}

	.aligncenter {
		margin-top: 0;
		margin-bottom: 0;
	}

	> .row {
		padding: 0;
		margin: 0 auto;
	}

	.wpv-grid {
		min-height: 1px;
	}

	&, & * {
		.wpv-font(sub-footer-);
		.wpv-color(sub-footer-);
	}
}

#sub-footer-menu {
	ul {
		margin: 0;
	}

	li {
		list-style: none;
		float: left;
		padding: 0 5px;
		border-left: 1px solid lighten(@subfooter-background-color, 15%);

		a {
			color: @css_footer_link_color;
			.wpv-font(sub-footer-);
		}

		&:first-child {
			padding-left: 0;
			border-left: 0;
		}
	}
}
