<?php

/**
 * List of icons in Icomoon
 *
 * @package wpv
 */

return array(
	'home' => 0xe000,
	'home1' => 0xe001,
	'home2' => 0xe002,
	'home3' => 0xe003,
	'home4' => 0xe004,
	'home5' => 0xe005,
	'home6' => 0xe006,
	'office' => 0xe007,
	'newspaper' => 0xe008,
	'pencil' => 0xe009,
	'pencil1' => 0xe00a,
	'pencil2' => 0xe00b,
	'pencil3' => 0xe00c,
	'quill' => 0xe00d,
	'quill1' => 0xe00e,
	'pen' => 0xe00f,
	'pen1' => 0xe010,
	'pen2' => 0xe011,
	'marker' => 0xe012,
	'blog' => 0xe013,
	'eyedropper' => 0xe014,
	'droplet' => 0xe015,
	'droplet1' => 0xe016,
	'paint-format' => 0xe017,
	'image' => 0xe018,
	'image1' => 0xe019,
	'images' => 0xe01a,
	'image2' => 0xe01b,
	'image3' => 0xe01c,
	'image4' => 0xe01d,
	'camera' => 0xe01e,
	'camera1' => 0xe01f,
	'camera2' => 0xe020,
	'camera3' => 0xe021,
	'music' => 0xe022,
	'music1' => 0xe023,
	'music2' => 0xe024,
	'piano' => 0xe025,
	'headphones' => 0xe026,
	'headphones1' => 0xe027,
	'play' => 0xe028,
	'movie' => 0xe029,
	'movie1' => 0xe02a,
	'film' => 0xe02b,
	'film1' => 0xe02c,
	'film2' => 0xe02d,
	'camera4' => 0xe02e,
	'camera5' => 0xe02f,
	'camera6' => 0xe030,
	'dice' => 0xe031,
	'pacman' => 0xe032,
	'spades' => 0xe033,
	'clubs' => 0xe034,
	'diamonds' => 0xe035,
	'king' => 0xe036,
	'queen' => 0xe037,
	'rock' => 0xe038,
	'bishop' => 0xe039,
	'knight' => 0xe03a,
	'pawn' => 0xe03b,
	'bullhorn' => 0xe03c,
	'megaphone' => 0xe03d,
	'new' => 0xe03e,
	'connection' => 0xe03f,
	'connection1' => 0xe040,
	'podcast' => 0xe041,
	'radio' => 0xe042,
	'feed' => 0xe043,
	'mic' => 0xe044,
	'mic1' => 0xe045,
	'mic2' => 0xe046,
	'mic3' => 0xe047,
	'book' => 0xe048,
	'book1' => 0xe049,
	'books' => 0xe04a,
	'library' => 0xe04b,
	'file' => 0xe04c,
	'profile' => 0xe04d,
	'file1' => 0xe04e,
	'file2' => 0xe04f,
	'file3' => 0xe050,
	'file4' => 0xe051,
	'file5' => 0xe052,
	'file-plus' => 0xe053,
	'file-minus' => 0xe054,
	'file-download' => 0xe055,
	'file-upload' => 0xe056,
	'file-check' => 0xe057,
	'file-remove' => 0xe058,
	'file6' => 0xe059,
	'copy' => 0xe05a,
	'copy1' => 0xe05b,
	'copy2' => 0xe05c,
	'copy3' => 0xe05d,
	'paste' => 0xe05e,
	'paste1' => 0xe05f,
	'paste2' => 0xe060,
	'stack' => 0xe061,
	'folder' => 0xe062,
	'folder-download' => 0xe063,
	'folder-upload' => 0xe064,
	'folder-plus' => 0xe065,
	'folder-plus1' => 0xe066,
	'folder-minus' => 0xe067,
	'folder-minus1' => 0xe068,
	'folder8' => 0xe069,
	'folder-remove' => 0xe06a,
	'folder1' => 0xe06b,
	'folder-open' => 0xe06c,
	'folder-plus2' => 0xe06d,
	'folder-minus2' => 0xe06e,
	'folder-download1' => 0xe06f,
	'folder-upload1' => 0xe070,
	'folder2' => 0xe071,
	'folder-open1' => 0xe072,
	'certificate' => 0xe073,
	'cc' => 0xe074,
	'tag' => 0xe075,
	'tag1' => 0xe076,
	'tag2' => 0xe077,
	'tag3' => 0xe078,
	'tags' => 0xe079,
	'tags1' => 0xe07a,
	'tag4' => 0xe07b,
	'barcode' => 0xe07c,
	'barcode1' => 0xe07d,
	'qrcode' => 0xe07e,
	'ticket' => 0xe07f,
	'cart' => 0xe080,
	'cart1' => 0xe081,
	'cart2' => 0xe082,
	'cart3' => 0xe083,
	'cart4' => 0xe084,
	'cart-plus' => 0xe085,
	'cart-minus' => 0xe086,
	'cart-add' => 0xe087,
	'cart-remove' => 0xe088,
	'cart-checkout' => 0xe089,
	'cart-remove1' => 0xe08a,
	'basket' => 0xe08b,
	'basket1' => 0xe08c,
	'coin' => 0xe08d,
	'credit' => 0xe08e,
	'calculate' => 0xe08f,
	'calculate1' => 0xe090,
	'support' => 0xe091,
	'phone' => 0xe092,
	'phone1' => 0xe093,
	'phone2' => 0xe094,
	'contact-add' => 0xe095,
	'contact-remove' => 0xe096,
	'contact-add1' => 0xe097,
	'contact-remove1' => 0xe098,
	'call-incoming' => 0xe099,
	'call-outgoing' => 0xe09a,
	'phone3' => 0xe09b,
	'phone4' => 0xe09c,
	'phone-hang-up' => 0xe09d,
	'phone-hang-up1' => 0xe09e,
	'address-book' => 0xe09f,
	'notebook' => 0xe0a0,
	'envelop' => 0xe0a1,
	'mail-send' => 0xe0a2,
	'envelop1' => 0xe0a3,
	'pushpin' => 0xe0a4,
	'location' => 0xe0a5,
	'location1' => 0xe0a6,
	'location2' => 0xe0a7,
	'location3' => 0xe0a8,
	'compass' => 0xe0a9,
	'compass1' => 0xe0aa,
	'map' => 0xe0ab,
	'map1' => 0xe0ac,
	'map2' => 0xe0ad,
	'direction' => 0xe0ae,
	'history' => 0xe0af,
	'clock' => 0xe0b0,
	'clock1' => 0xe0b1,
	'clock2' => 0xe0b2,
	'clock3' => 0xe0b3,
	'watch' => 0xe0b4,
	'alarm' => 0xe0b5,
	'alarm1' => 0xe0b6,
	'bell' => 0xe0b7,
	'stopwatch' => 0xe0b8,
	'calendar' => 0xe0b9,
	'calendar1' => 0xe0ba,
	'calendar2' => 0xe0bb,
	'calendar3' => 0xe0bc,
	'print' => 0xe0bd,
	'print1' => 0xe0be,
	'mouse' => 0xe0bf,
	'mouse1' => 0xe0c0,
	'keyboard' => 0xe0c1,
	'screen' => 0xe0c2,
	'screen1' => 0xe0c3,
	'laptop' => 0xe0c4,
	'mobile' => 0xe0c5,
	'mobile1' => 0xe0c6,
	'tablet' => 0xe0c7,
	'tv' => 0xe0c8,
	'cabinet' => 0xe0c9,
	'archive' => 0xe0ca,
	'drawer' => 0xe0cb,
	'drawer1' => 0xe0cc,
	'drawer2' => 0xe0cd,
	'box-add' => 0xe0ce,
	'box-remove' => 0xe0cf,
	'download' => 0xe0d0,
	'upload' => 0xe0d1,
	'disk' => 0xe0d2,
	'storage' => 0xe0d3,
	'storage1' => 0xe0d4,
	'database' => 0xe0d5,
	'database1' => 0xe0d6,
	'undo' => 0xe0d7,
	'redo' => 0xe0d8,
	'rotate' => 0xe0d9,
	'rotate1' => 0xe0da,
	'flip' => 0xe0db,
	'flip1' => 0xe0dc,
	'undo1' => 0xe0dd,
	'redo1' => 0xe0de,
	'forward' => 0xe0df,
	'reply' => 0xe0e0,
	'reply1' => 0xe0e1,
	'bubble' => 0xe0e2,
	'bubbles' => 0xe0e3,
	'bubbles1' => 0xe0e4,
	'bubble1' => 0xe0e5,
	'bubbles2' => 0xe0e6,
	'bubbles3' => 0xe0e7,
	'bubble-notification' => 0xe0e8,
	'bubble2' => 0xe0e9,
	'bubble-dots' => 0xe0ea,
	'bubble3' => 0xe0eb,
	'bubble4' => 0xe0ec,
	'bubble-dots1' => 0xe0ed,
	'bubble5' => 0xe0ee,
	'bubbles4' => 0xe0ef,
	'bubbles5' => 0xe0f0,
	'bubble-blocked' => 0xe0f1,
	'bubble-quote' => 0xe0f2,
	'bubble-user' => 0xe0f3,
	'bubble-check' => 0xe0f4,
	'bubble-video-chat' => 0xe0f5,
	'bubble-link' => 0xe0f6,
	'bubble-locked' => 0xe0f7,
	'bubble-star' => 0xe0f8,
	'bubble-heart' => 0xe0f9,
	'bubble-paperclip' => 0xe0fa,
	'bubble-cancel' => 0xe0fb,
	'bubble-plus' => 0xe0fc,
	'bubble-minus' => 0xe0fd,
	'bubble-notification1' => 0xe0fe,
	'bubble-trash' => 0xe0ff,
	'bubble-left' => 0xe100,
	'bubble-right' => 0xe101,
	'bubble-up' => 0xe102,
	'bubble-down' => 0xe103,
	'bubble-first' => 0xe104,
	'bubble-last' => 0xe105,
	'bubble-replu' => 0xe106,
	'bubble-forward' => 0xe107,
	'bubble-reply' => 0xe108,
	'bubble-forward1' => 0xe109,
	'user' => 0xe10a,
	'users' => 0xe10b,
	'user-plus' => 0xe10c,
	'user-plus1' => 0xe10d,
	'user-minus' => 0xe10e,
	'user-minus1' => 0xe10f,
	'user-cancel' => 0xe110,
	'user-block' => 0xe111,
	'user1' => 0xe112,
	'users1' => 0xe113,
	'user-plus2' => 0xe114,
	'user-minus2' => 0xe115,
	'user-cancel1' => 0xe116,
	'user-block1' => 0xe117,
	'user2' => 0xe118,
	'user3' => 0xe119,
	'vcard' => 0xe11a,
	'hanger' => 0xe11b,
	'quotes-left' => 0xe11c,
	'quotes-right' => 0xe11d,
	'quotes-right1' => 0xe11e,
	'quotes-right2' => 0xe11f,
	'busy' => 0xe120,
	'busy1' => 0xe121,
	'busy2' => 0xe122,
	'spinner' => 0xe123,
	'spinner1' => 0xe124,
	'spinner2' => 0xe125,
	'spinner3' => 0xe126,
	'spinner4' => 0xe127,
	'spinner5' => 0xe128,
	'spinner6' => 0xe129,
	'spinner7' => 0xe12a,
	'binoculars' => 0xe12b,
	'search' => 0xe12c,
	'search1' => 0xe12d,
	'zoomin' => 0xe12e,
	'zoomout' => 0xe12f,
	'search2' => 0xe130,
	'zoomin1' => 0xe131,
	'zoomout1' => 0xe132,
	'expand' => 0xe133,
	'contract' => 0xe134,
	'expand1' => 0xe135,
	'contract1' => 0xe136,
	'key' => 0xe137,
	'key1' => 0xe138,
	'lock' => 0xe139,
	'lock1' => 0xe13a,
	'unlocked' => 0xe13b,
	'lock2' => 0xe13c,
	'unlocked1' => 0xe13d,
	'wrench' => 0xe13e,
	'wrench1' => 0xe13f,
	'settings' => 0xe140,
	'equalizer' => 0xe141,
	'equalizer1' => 0xe142,
	'equalizer2' => 0xe143,
	'cog' => 0xe144,
	'cogs' => 0xe145,
	'cog1' => 0xe146,
	'cog2' => 0xe147,
	'cog3' => 0xe148,
	'factory' => 0xe149,
	'hammer' => 0xe14a,
	'tools' => 0xe14b,
	'wand' => 0xe14c,
	'wand1' => 0xe14d,
	'aid' => 0xe14e,
	'patch' => 0xe14f,
	'bug' => 0xe150,
	'bug1' => 0xe151,
	'inject' => 0xe152,
	'construction' => 0xe153,
	'cone' => 0xe154,
	'pie' => 0xe155,
	'pie1' => 0xe156,
	'pie2' => 0xe157,
	'pie3' => 0xe158,
	'stats' => 0xe159,
	'stats1' => 0xe15a,
	'stats2' => 0xe15b,
	'bars' => 0xe15c,
	'bars1' => 0xe15d,
	'bars2' => 0xe15e,
	'stats-up' => 0xe15f,
	'stats-down' => 0xe160,
	'ladder' => 0xe161,
	'cake' => 0xe162,
	'gift' => 0xe163,
	'balloon' => 0xe164,
	'rating' => 0xe165,
	'rating1' => 0xe166,
	'rating2' => 0xe167,
	'podium' => 0xe168,
	'medal' => 0xe169,
	'medal1' => 0xe16a,
	'medal2' => 0xe16b,
	'medal3' => 0xe16c,
	'medal4' => 0xe16d,
	'crown' => 0xe16e,
	'trophy' => 0xe16f,
	'trophy1' => 0xe170,
	'trophy-star' => 0xe171,
	'diamond' => 0xe172,
	'glass' => 0xe173,
	'glass1' => 0xe174,
	'bottle' => 0xe175,
	'bottle1' => 0xe176,
	'mug' => 0xe177,
	'food' => 0xe178,
	'food1' => 0xe179,
	'leaf' => 0xe17a,
	'apple-fruit' => 0xe17b,
	'paw' => 0xe17c,
	'steps' => 0xe17d,
	'flower' => 0xe17e,
	'rocket' => 0xe17f,
	'meter' => 0xe180,
	'meter2' => 0xe181,
	'meter-slow' => 0xe182,
	'meter-medium' => 0xe183,
	'meter-fast' => 0xe184,
	'dashboard' => 0xe185,
	'hammer1' => 0xe186,
	'balance' => 0xe187,
	'fire' => 0xe188,
	'lab' => 0xe189,
	'magnet' => 0xe18a,
	'dumbbell' => 0xe18b,
	'skull' => 0xe18c,
	'skull1' => 0xe18d,
	'lamp' => 0xe18e,
	'lamp1' => 0xe18f,
	'lamp2' => 0xe190,
	'remove' => 0xe191,
	'remove1' => 0xe192,
	'remove2' => 0xe193,
	'remove3' => 0xe194,
	'remove4' => 0xe195,
	'briefcase' => 0xe196,
	'briefcase1' => 0xe197,
	'briefcase2' => 0xe198,
	'airplane' => 0xe199,
	'airplane1' => 0xe19a,
	'paperplane' => 0xe19b,
	'car' => 0xe19c,
	'gas-pump' => 0xe19d,
	'bus' => 0xe19e,
	'truck' => 0xe19f,
	'road' => 0xe1a0,
	'boat' => 0xe1a1,
	'cube' => 0xe1a2,
	'cube1' => 0xe1a3,
	'pyramid' => 0xe1a4,
	'puzzle' => 0xe1a5,
	'puzzle1' => 0xe1a6,
	'puzzle2' => 0xe1a7,
	'puzzle3' => 0xe1a8,
	'glasses' => 0xe1a9,
	'glasses1' => 0xe1aa,
	'glasses2' => 0xe1ab,
	'sunglasses' => 0xe1ac,
	'accessibility' => 0xe1ad,
	'accessibility1' => 0xe1ae,
	'target' => 0xe1af,
	'target1' => 0xe1b0,
	'target2' => 0xe1b1,
	'gun' => 0xe1b2,
	'gun-ban' => 0xe1b3,
	'shield' => 0xe1b4,
	'shield1' => 0xe1b5,
	'lightning' => 0xe1b6,
	'power' => 0xe1b7,
	'power1' => 0xe1b8,
	'switch' => 0xe1b9,
	'powercord' => 0xe1ba,
	'clipboard' => 0xe1bb,
	'signup' => 0xe1bc,
	'list' => 0xe1bd,
	'list1' => 0xe1be,
	'numbered-list' => 0xe1bf,
	'playlist' => 0xe1c0,
	'grid' => 0xe1c1,
	'grid1' => 0xe1c2,
	'grid2' => 0xe1c3,
	'grid3' => 0xe1c4,
	'tree' => 0xe1c5,
	'tree1' => 0xe1c6,
	'tree2' => 0xe1c7,
	'menu' => 0xe1c8,
	'menu1' => 0xe1c9,
	'menu2' => 0xe1ca,
	'menu3' => 0xe1cb,
	'menu4' => 0xe1cc,
	'cloud' => 0xe1cd,
	'cloud-download' => 0xe1ce,
	'cloud-upload' => 0xe1cf,
	'download1' => 0xe1d0,
	'upload1' => 0xe1d1,
	'download2' => 0xe1d2,
	'upload2' => 0xe1d3,
	'download3' => 0xe1d4,
	'upload3' => 0xe1d5,
	'download4' => 0xe1d6,
	'upload4' => 0xe1d7,
	'globe' => 0xe1d8,
	'globe1' => 0xe1d9,
	'earth' => 0xe1da,
	'link' => 0xe1db,
	'link1' => 0xe1dc,
	'link2' => 0xe1dd,
	'link2' => 0xe1de,
	'link3' => 0xe1df,
	'link4' => 0xe1e0,
	'link5' => 0xe1e1,
	'anchor' => 0xe1e2,
	'flag' => 0xe1e3,
	'flag1' => 0xe1e4,
	'flag2' => 0xe1e5,
	'flag3' => 0xe1e6,
	'attachment' => 0xe1e7,
	'attachment1' => 0xe1e8,
	'eye' => 0xe1e9,
	'eye-blocked' => 0xe1ea,
	'eye1' => 0xe1eb,
	'eye2' => 0xe1ec,
	'eye-blocked1' => 0xe1ed,
	'eye3' => 0xe1ee,
	'eye4' => 0xe1ef,
	'eye5' => 0xe1f0,
	'eye6' => 0xe1f1,
	'bookmark' => 0xe1f2,
	'bookmark1' => 0xe1f3,
	'bookmarks' => 0xe1f4,
	'bookmark2' => 0xe1f5,
	'weather-lightning' => 0xe1f6,
	'weather-rain' => 0xe1f7,
	'weather-snow' => 0xe1f8,
	'windy' => 0xe1f9,
	'fan' => 0xe1fa,
	'umbrella' => 0xe1fb,
	'sun' => 0xe1fc,
	'sun1' => 0xe1fd,
	'brightness-high' => 0xe1fe,
	'brightness-medium' => 0xe1ff,
	'brightness-low' => 0xe200,
	'brightness-contrast' => 0xe201,
	'contrast' => 0xe202,
	'moon' => 0xe203,
	'bed' => 0xe204,
	'bed1' => 0xe205,
	'star' => 0xe206,
	'star1' => 0xe207,
	'star2' => 0xe208,
	'star3' => 0xe209,
	'star4' => 0xe20a,
	'star5' => 0xe20b,
	'heart' => 0xe20c,
	'heart1' => 0xe20d,
	'heart-broken' => 0xe20e,
	'heart2' => 0xe20f,
	'heart3' => 0xe210,
	'heart-broken1' => 0xe211,
	'heart4' => 0xe212,
	'heart5' => 0xe213,
	'heart-broken2' => 0xe214,
	'thumbs-up' => 0xe215,
	'thumbs-up1' => 0xe216,
	'thumbs-down' => 0xe217,
	'thumbs-down1' => 0xe218,
	'thumbs-up2' => 0xe219,
	'thumbs-up3' => 0xe21a,
	'people' => 0xe21b,
	'man' => 0xe21c,
	'male' => 0xe21d,
	'woman' => 0xe21e,
	'female' => 0xe21f,
	'peace' => 0xe220,
	'yin-yang' => 0xe221,
	'happy' => 0xe222,
	'happy1' => 0xe223,
	'smiley' => 0xe224,
	'smiley1' => 0xe225,
	'tongue' => 0xe226,
	'tongue1' => 0xe227,
	'sad' => 0xe228,
	'sad1' => 0xe229,
	'wink' => 0xe22a,
	'wink1' => 0xe22b,
	'grin' => 0xe22c,
	'grin1' => 0xe22d,
	'cool' => 0xe22e,
	'cool1' => 0xe22f,
	'angry' => 0xe230,
	'angry1' => 0xe231,
	'evil' => 0xe232,
	'evil1' => 0xe233,
	'shocked' => 0xe234,
	'shocked1' => 0xe235,
	'confused' => 0xe236,
	'confused1' => 0xe237,
	'neutral' => 0xe238,
	'neutral1' => 0xe239,
	'wondering' => 0xe23a,
	'wondering1' => 0xe23b,
	'cursor' => 0xe23c,
	'cursor1' => 0xe23d,
	'point-up' => 0xe23e,
	'point-right' => 0xe23f,
	'point-down' => 0xe240,
	'point-left' => 0xe241,
	'move' => 0xe242,
	'warning' => 0xe243,
	'notification' => 0xe244,
	'question' => 0xe245,
	'question1' => 0xe246,
	'question2' => 0xe247,
	'question3' => 0xe248,
	'question4' => 0xe249,
	'plus-circle' => 0xe24a,
	'plus-circle1' => 0xe24b,
	'minus-circle' => 0xe24c,
	'minus-circle1' => 0xe24d,
	'info' => 0xe24e,
	'info1' => 0xe24f,
	'blocked' => 0xe250,
	'cancel-circle' => 0xe251,
	'cancel-circle1' => 0xe252,
	'checkmark-circle' => 0xe253,
	'checkmark-circle1' => 0xe254,
	'cancel' => 0xe255,
	'spam' => 0xe256,
	'close' => 0xe257,
	'checkmark' => 0xe258,
	'checkmark1' => 0xe259,
	'checkmark2' => 0xe25a,
	'checkmark3' => 0xe25b,
	'spell-check' => 0xe25c,
	'minus' => 0xe25d,
	'plus' => 0xe25e,
	'enter' => 0xe25f,
	'exit' => 0xe260,
	'enter1' => 0xe261,
	'exit1' => 0xe262,
	'enter2' => 0xe263,
	'exit2' => 0xe264,
	'exit3' => 0xe265,
	'play1' => 0xe266,
	'pause' => 0xe267,
	'stop' => 0xe268,
	'backward' => 0xe269,
	'forward1' => 0xe26a,
	'play2' => 0xe26b,
	'pause1' => 0xe26c,
	'stop1' => 0xe26d,
	'backward1' => 0xe26e,
	'forward2' => 0xe26f,
	'first' => 0xe270,
	'last' => 0xe271,
	'previous' => 0xe272,
	'next' => 0xe273,
	'eject' => 0xe274,
	'volume-high' => 0xe275,
	'volume-medium' => 0xe276,
	'volume-low' => 0xe277,
	'volume-mute' => 0xe278,
	'volume-mute1' => 0xe279,
	'volume-increase' => 0xe27a,
	'volume-decrease' => 0xe27b,
	'volume-high1' => 0xe27c,
	'volume-medium1' => 0xe27d,
	'volume-low1' => 0xe27e,
	'volume-mute2' => 0xe27f,
	'volume-mute3' => 0xe280,
	'volume-increase1' => 0xe281,
	'volume-decrease1' => 0xe282,
	'volume5' => 0xe283,
	'volume4' => 0xe284,
	'volume3' => 0xe285,
	'volume2' => 0xe286,
	'volume1' => 0xe287,
	'volume0' => 0xe288,
	'volume-mute4' => 0xe289,
	'volume-mute5' => 0xe28a,
	'loop' => 0xe28b,
	'loop1' => 0xe28c,
	'loop2' => 0xe28d,
	'loop3' => 0xe28e,
	'loop4' => 0xe28f,
	'shuffle' => 0xe290,
	'shuffle1' => 0xe291,
	'wave' => 0xe292,
	'wave1' => 0xe293,
	'arrow-first' => 0xe294,
	'arrow-right' => 0xe295,
	'arrow-up' => 0xe296,
	'arrow-right1' => 0xe297,
	'arrow-down' => 0xe298,
	'arrow-left' => 0xe299,
	'arrow-up1' => 0xe29a,
	'arrow-right2' => 0xe29b,
	'arrow-down1' => 0xe29c,
	'arrow-left1' => 0xe29d,
	'arrow-up-left' => 0xe29e,
	'arrow-up2' => 0xe29f,
	'arrow-up-right' => 0xe2a0,
	'arrow-right3' => 0xe2a1,
	'arrow-down-right' => 0xe2a2,
	'arrow-down2' => 0xe2a3,
	'arrow-down-left' => 0xe2a4,
	'arrow-left2' => 0xe2a5,
	'arrow-up-left1' => 0xe2a6,
	'arrow-up3' => 0xe2a7,
	'arrow-up-right1' => 0xe2a8,
	'arrow-right4' => 0xe2a9,
	'arrow-down-right1' => 0xe2aa,
	'arrow-down3' => 0xe2ab,
	'arrow-down-left1' => 0xe2ac,
	'arrow-left3' => 0xe2ad,
	'arrow-up-left2' => 0xe2ae,
	'arrow-up4' => 0xe2af,
	'arrow-up-right2' => 0xe2b0,
	'arrow-right5' => 0xe2b1,
	'arrow-down-right2' => 0xe2b2,
	'arrow-down4' => 0xe2b3,
	'arrow-down-left2' => 0xe2b4,
	'arrow-left4' => 0xe2b5,
	'arrow' => 0xe2b6,
	'arrow1' => 0xe2b7,
	'arrow2' => 0xe2b8,
	'arrow3' => 0xe2b9,
	'arrow-up-left3' => 0xe2ba,
	'arrow-up5' => 0xe2bb,
	'arrow-up-right3' => 0xe2bc,
	'arrow-right6' => 0xe2bd,
	'arrow-down-right3' => 0xe2be,
	'arrow-down5' => 0xe2bf,
	'arrow-down-left3' => 0xe2c0,
	'arrow-left5' => 0xe2c1,
	'arrow-up-left4' => 0xe2c2,
	'arrow-up6' => 0xe2c3,
	'arrow-up-right4' => 0xe2c4,
	'arrow-right7' => 0xe2c5,
	'arrow-down-right4' => 0xe2c6,
	'arrow-down6' => 0xe2c7,
	'arrow-down-left4' => 0xe2c8,
	'arrow-left6' => 0xe2c9,
	'arrow-up7' => 0xe2ca,
	'arrow-right8' => 0xe2cb,
	'arrow-down7' => 0xe2cc,
	'arrow-left7' => 0xe2cd,
	'arrow-up8' => 0xe2ce,
	'arrow-right9' => 0xe2cf,
	'arrow-down8' => 0xe2d0,
	'arrow-left8' => 0xe2d1,
	'arrow-up9' => 0xe2d2,
	'arrow-right10' => 0xe2d3,
	'arrow-down9' => 0xe2d4,
	'arrow-left9' => 0xe2d5,
	'arrow-up10' => 0xe2d6,
	'arrow-right11' => 0xe2d7,
	'arrow-down10' => 0xe2d8,
	'arrow-left10' => 0xe2d9,
	'enter3' => 0xe2da,
	'enter4' => 0xe2db,
	'esc' => 0xe2dc,
	'backspace' => 0xe2dd,
	'backspace1' => 0xe2de,
	'backspace2' => 0xe2df,
	'tab' => 0xe2e0,
	'transmission' => 0xe2e1,
	'transmission1' => 0xe2e2,
	'sort' => 0xe2e3,
	'sort1' => 0xe2e4,
	'command' => 0xe2e5,
	'checkbox-checked' => 0xe2e6,
	'checkbox-unchecked' => 0xe2e7,
	'checkbox-partial' => 0xe2e8,
	'radio-checked' => 0xe2e9,
	'radio-unchecked' => 0xe2ea,
	'crop' => 0xe2eb,
	'vector' => 0xe2ec,
	'rulers' => 0xe2ed,
	'scissors' => 0xe2ee,
	'scissors1' => 0xe2ef,
	'filter' => 0xe2f0,
	'filter1' => 0xe2f1,
	'filter2' => 0xe2f2,
	'filter3' => 0xe2f3,
	'font' => 0xe2f4,
	'text-height' => 0xe2f5,
	'text-width' => 0xe2f6,
	'font-size' => 0xe2f7,
	'bold' => 0xe2f8,
	'underline' => 0xe2f9,
	'italic' => 0xe2fa,
	'strikethrough' => 0xe2fb,
	'omega' => 0xe2fc,
	'sigma' => 0xe2fd,
	'nbsp' => 0xe2fe,
	'page-break' => 0xe2ff,
	'page-break1' => 0xe300,
	'superscript' => 0xe301,
	'subscript' => 0xe302,
	'superscript1' => 0xe303,
	'subscript1' => 0xe304,
	'text-color' => 0xe305,
	'pagebreak' => 0xe306,
	'clear-formatting' => 0xe307,
	'table' => 0xe308,
	'table1' => 0xe309,
	'insert-template' => 0xe30a,
	'pilcrow' => 0xe30b,
	'left-to-right' => 0xe30c,
	'right-to-left' => 0xe30d,
	'paragraph-left' => 0xe30e,
	'paragraph-center' => 0xe30f,
	'paragraph-right' => 0xe310,
	'paragraph-justify' => 0xe311,
	'paragraph-left1' => 0xe312,
	'paragraph-center1' => 0xe313,
	'paragraph-right1' => 0xe314,
	'paragraph-justify1' => 0xe315,
	'indent-increase' => 0xe316,
	'indent-decrease' => 0xe317,
	'share' => 0xe318,
	'newtab' => 0xe319,
	'newtab1' => 0xe31a,
	'popout' => 0xe31b,
	'embed' => 0xe31c,
	'code' => 0xe31d,
	'console' => 0xe31e,
	'share1' => 0xe31f,
	'share2' => 0xe320,
	'mail' => 0xe321,
	'mail1' => 0xe322,
	'mail2' => 0xe323,
	'mail3' => 0xe324,
	'google' => 0xe325,
	'googleplus' => 0xe326,
	'googleplus1' => 0xe327,
	'googleplus2' => 0xe328,
	'googleplus3' => 0xe329,
	'google-drive' => 0xe32a,
	'facebook' => 0xe32b,
	'facebook1' => 0xe32c,
	'facebook2' => 0xe32d,
	'instagram' => 0xe32e,
	'twitter' => 0xe32f,
	'twitter1' => 0xe330,
	'twitter2' => 0xe331,
	'feed1' => 0xe332,
	'feed2' => 0xe333,
	'feed3' => 0xe334,
	'youtube' => 0xe335,
	'youtube1' => 0xe336,
	'vimeo' => 0xe337,
	'vimeo2' => 0xe338,
	'vimeo1' => 0xe339,
	'lanyrd' => 0xe33a,
	'flickr' => 0xe33b,
	'flickr1' => 0xe33c,
	'flickr2' => 0xe33d,
	'flickr3' => 0xe33e,
	'picassa' => 0xe33f,
	'picassa1' => 0xe340,
	'dribbble' => 0xe341,
	'dribbble1' => 0xe342,
	'dribbble2' => 0xe343,
	'forrst' => 0xe344,
	'forrst1' => 0xe345,
	'deviantart' => 0xe346,
	'deviantart1' => 0xe347,
	'steam' => 0xe348,
	'steam1' => 0xe349,
	'github' => 0xe34a,
	'github1' => 0xe34b,
	'github2' => 0xe34c,
	'github3' => 0xe34d,
	'github4' => 0xe34e,
	'wordpress' => 0xe34f,
	'wordpress1' => 0xe350,
	'joomla' => 0xe351,
	'blogger' => 0xe352,
	'blogger1' => 0xe353,
	'tumblr' => 0xe354,
	'tumblr1' => 0xe355,
	'yahoo' => 0xe356,
	'tux' => 0xe357,
	'apple' => 0xe358,
	'finder' => 0xe359,
	'android' => 0xe35a,
	'windows' => 0xe35b,
	'windows8' => 0xe35c,
	'soundcloud' => 0xe35d,
	'soundcloud1' => 0xe35e,
	'skype' => 0xe35f,
	'reddit' => 0xe360,
	'linkedin' => 0xe361,
	'lastfm' => 0xe362,
	'lastfm1' => 0xe363,
	'delicious' => 0xe364,
	'stumbleupon' => 0xe365,
	'stumbleupon1' => 0xe366,
	'stackoverflow' => 0xe367,
	'pinterest' => 0xe368,
	'pinterest1' => 0xe369,
	'xing' => 0xe36a,
	'xing1' => 0xe36b,
	'flattr' => 0xe36c,
	'foursquare' => 0xe36d,
	'foursquare1' => 0xe36e,
	'paypal' => 0xe36f,
	'paypal1' => 0xe370,
	'paypal2' => 0xe371,
	'yelp' => 0xe372,
	'libreoffice' => 0xe373,
	'file-pdf' => 0xe374,
	'file-openoffice' => 0xe375,
	'file-word' => 0xe376,
	'file-excel' => 0xe377,
	'file-zip' => 0xe378,
	'file-powerpoint' => 0xe379,
	'file-xml' => 0xe37a,
	'file-css' => 0xe37b,
	'html5' => 0xe37c,
	'html51' => 0xe37d,
	'css3' => 0xe37e,
	'chrome' => 0xe37f,
	'firefox' => 0xe380,
	'IE' => 0xe381,
	'opera' => 0xe382,
	'safari' => 0xe383,
	'IcoMoon' => 0xe384,
);