.tagcloud {
	padding-bottom: 5px !important;

	a {
		display: inline-block;
		position: relative;
		text-transform: lowercase;
		color: @accent-color-2;
		background: @accent-color-8;
		.readable-border(@accent-color-2);
		.wpv-font(additional-font-2-);
		font-weight: normal;
		border-radius: 0px;
		margin: 0px;
		padding: 5px 10px;
		line-height: 1em;

		&:hover {
			background: @accent-color-1;
			text-decoration: none;
			color: @accent-color-8 !important;
		}
	}
}