@media (max-width: 479px) {
	.responsive-layout {
        .comment {
			.comment-content {
				margin-left: 10px;
			}

			.comment-author {
				display: none;
			}
		}

		.socialcount {

			> li {
				min-width: 60px;
			}

			.count {
				display: none;
			}
		}

		.page-header {
			h1 {
				line-height: 1.2em;
				font-size: 24px;
			}
		}

		.post-article {
			header {
				h3 {
					&, a {
						font-size: 1.3em;
						padding-top: 0;
					}
				}
			}
		}

		.loop-wrapper.news {
			.post-actions-wrapper {
				bottom: -4px;

				.icon {
					margin-right: 4px;
					font-size: 11px;
				}

				.post-date {
					text-transform: none;
					margin-right: 0;
					width: 68%;
					padding: 5px;
					line-height: 2em;
					font-size: 0.6em;
				}
			}

			.comment-count {
				width: 25%;

				a {
					padding: 5px;
					text-align: center;
				}
			}
		}

		.loop-wrapper .list-item .post-content-outer {
			padding: 0;
			margin-bottom: 0;
		}

		.post-content-wrapper {
			background: none;
			h3 {

				&, a {
					font-size: 15px;
				}
			}
		}

		article .loop-wrapper .list-item header.single {
			padding-top: 20px;
		}

		header.main-header {
			&.layout-logo-menu .first-row .logo-wrapper .logo img {
				max-width: 120px;
			}

			&.layout-logo-text-menu .first-row-left .logo-wrapper .logo img {
				max-width: 120px !important;
			}
		}

		&.woocommerce {
			table.cart {
				td,
				th {
					font-size: 10px;

					&.product-price {
						display: none;
					}
				}

				td.product-name a {
					font-size: 13px;
				}
			}
		}

		&.single-post .related-posts {
			padding-top: 0px;
		}

		#commentform .form-submit {
			margin: 0px;
		}

		h3 .vamtam-button {
			margin-top: 20px;
		}

		.linkarea table td {
			display: block;
		}
	}
}