#comments-list,
#trackbacks-list {
	margin-bottom: 0px;
}

.respond-box {
	position: relative;
	margin: 10px 0 0;
	padding: 0;
	border-top: 0;
	background: @accent-color-7;
}

.respond-box-title.sep-text {
	position: relative;
	padding: 30px 0 0 0;
	width: auto;
	height: 0;

	.sep-text-before,
	.sep-text-after {
		width: 50%;
		vertical-align: bottom;
	}
}

.comments-wrapper {
	clear: both;
	border: solid 1px @accent-color-7;
	margin-top: 20px;

	&:first-child {
		border: solid 1px @accent-color-7;
		margin-top: 20px;
	}

	.sep-text {
		z-index: 2;
		margin-top: 20px;
		margin-bottom: 0px;
		padding-bottom: 20px;
		padding-bottom: 20px;
		border-bottom: solid 1px @accent-color-7;
		.sep-text-before,
		.sep-text-after,
		.sep-text-line {
			display: none;
		}

		.content {
			padding: 0 10px;

			h5,
			h5 a {
				.wpv-font(h3-);
			}

			a:hover {
				text-decoration: none;
			}
		}

		.sep-text-more {
			padding-right: 20px;
			padding-left: 0px;

			a.icon-b {
				font-size: 12px;

				&:before {
					color: @accent-color-3 !important;
				}
			}
		}
	}

	.children > li {
		margin-left: 0;
		padding-left: 0;
	}

	label {
		font-size: 12px !important;
	}
}

.comments {
	@comment-avatar: 70px;

	ol {
		margin: 0px;
	}

	li {
		position: relative;
		min-height: @comment-avatar;
		border-bottom: solid 1px @accent-color-7;
		padding: 15px;

		&.has-children {
			padding-bottom: 0;
		}
	}
	ol li {
		clear: both;
		margin-top: -1px;
		list-style: none;
	}
	> ol > li:first-child {
		margin-top: 0px;
	}

	.children {
		border-top: 0;
		margin: 0px;
	}
	.children li {
		clear: both;
		margin-left: @comment-avatar + 10px;
		padding-left: 10px;

		&:last-child {
			padding-bottom: 15px;
			border-bottom: none;

		}
	}

	.avatar {
		max-width: @comment-avatar !important;
		max-height: @comment-avatar;
		background-color: @accent-color-7;
	}

	.comment-author {
		position: absolute;
		top: 0;
		bottom: 0;
		padding: 10px;
		min-height: @comment-avatar;
		width: @comment-avatar;
	}

	.bypostauthor {
		position: relative;
		z-index: 1;
		transition: .3s;

		&:hover {
			background: lighten(@accent-color-7, 3%);

			.comment-author {
				&:after {
					border-right-color: @accent-color-8;
				}
			}
		}
	}

	.comment-author-link {
		display: inline;

	}
	.comment-time {
		display: inline;
		font-size: 10px !important;
	}
	.comment-time:before {
		margin: auto 5px;
		content: " | ";
	}
	.comment-content {
		position: relative;
		margin-left: @comment-avatar + 30;
		min-height: @comment-avatar - 20;

		&:hover {
			h6.comment-reply-link {
				display: block;
			}
		}
	}
	.comment-meta {
		margin-top: -3px;
		margin-bottom: 6px;

		> .comment-author-link {
			.wpv-font(h4-);
		}

	}

	h6.comment-reply-link {
		position: absolute;
		top: 0px;
		right: 0px;
		display: none;
		padding: 0 0 0 5px;

		a {
			margin: 0 0 0 5px;
			color: @css_link_color;
			font-size: 12px;

			&:hover {
				color: @css_link_hover_color;
			}
		}

		&:before {
			position: relative;
			top: 5px;
			color: @accent-color-3;
			content: icon(theme-next2);
			font-size: 18px;
			font-family: theme;
			line-height: 18px;
		}

	}
	#reply-title {
		margin-bottom: 0px !important;
	}
	#cancel-comment-reply-link {
		position: relative;
	}
	.comment-notes {
		margin-bottom: 14px;
	}
}

#commentform {
	position: relative;
	padding-bottom: 10px;

	&:after {
		display: block;
		clear: both;
		content: "";
	}

	.form-input {
		float: left;
		margin-bottom: 10px;
		width: 100%;
		background: none;

		input {
			width: 100%;
			font-size: 14px;
			padding: 10px;
			box-shadow: none !important;
			font-weight: 200;
			transition: all .2s ease;
			border: solid 1px fade(@accent-color-6, 10%);
			margin-top: 5px;

			&:hover {
				-moz-box-shadow:  0px 2px 4px 0px rgba(0,0,0,0.05) !important;
				box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05) !important;
				border: solid 1px rgba(0, 0, 0, 0.2);
			}
		}
	}

	.comment-form-comment textarea {
		width: 100%;
		height: 160px;
		font-size: 14px;
		padding: 10px;
		box-shadow: none !important;
		font-weight: 200;
		transition: all .2s ease;
		border: solid 1px fade(@accent-color-6, 10%);
		margin-top: 5px;

		&:hover {
			-moz-box-shadow:  0px 2px 4px 0px rgba(0,0,0,0.05) !important;
			box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05) !important;
			border: solid 1px rgba(0, 0, 0, 0.2);
		}

	}
	.form-submit {
		bottom: 0;
		height: auto;
		float: none;
		margin: 0px 0px 0px 20px;
	}

	#submit {
		.submit-button-style;
		position: relative;
		color: @accent-color-1;
		padding: 0.9em 1.5em;
		border: 2px solid @accent-color-1;
		background: transparent;

		&:before {
			position: absolute;
			top: 50%;
			left: 0;
			content: icon(theme-pencil);
			font-family: theme;
		}

		&:hover {
			background: @accent-color-1;
			color: @accent-color-8;
		}
	}

	input[type="checkbox"] {
		vertical-align: middle;
	}
}

#respond {
	padding: 10px;
}

.respond-box {

	background: none;
	margin-bottom: 0px;
	margin-top: 0px;

	.respond-box-title.sep-text {
			margin: 0px;
			height: auto;
			padding: 20px;
		.content {
			.wpv-font(h3-);
			padding: 0 1em;
		}

		.sep-text-line {
			border-top-width: 0;
			border-bottom: 0;
		}
	}
}

.comment-meta {
	color: @accent-color-5;
	font-size: 13px;
}
.comment-author {
	line-height: 1em !important;

	span {
		float: left;
		margin-top: 3px;
	}
}

#cancel-comment-reply-link,
h6.comment-reply-link,
.comment-edit-link,
.comment-notes {
	font-size: 12px !important;
}

.comment-content {
	line-height: 1.4em;
}

body.page-template-guestbook-php {
	#commentform {
		.form-input {
			background: none;

			&.grid-1-2 {
				width: 50%;
			}

			&.grid-1-1 {
				width: auto;
			}
		}

		.comment-notes {
			float: right;
		}

		textarea {
			height: auto;
		}

		.form-submit {
			float: left;
			margin-right: 0;
			margin-left: 0;
			width: 100%;
			text-align: center;
		}

		#submit {
			.submit-button-style;
			position: relative;
			color: @accent-color-1;
			padding: 0.9em 1.5em;
			border: 2px solid @accent-color-1;
			background: transparent;

			&:hover {
				background: @accent-color-1;
				color: @accent-color-8;
			}
		}
	}

	.comments .bypostauthor:hover {
		background: transparent;
	}

	.respond-box {
		margin-top: 0;
		margin-bottom: 60px;
		border: 0;
		background: @accent-color-8;
		box-shadow: 0 1px 3px 1px @accent-color-7;
		-moz-box-shadow:  0px 1px 4px 2px fade(@accent-color-6, 10%) !important;
		box-shadow: 0px 1px 4px 2px fade(@accent-color-6, 10%) !important;

		&, p {
			color: @accent-color-6;
		}

		a {
			color: @accent-color-1;
		}
	}

	.comments-title {
		text-align: center;
		text-transform: uppercase;
		margin-bottom: 30px;

		a {
			color: @accent-color-6;
		}
	}

	.comment-time {
		text-transform: uppercase;
		display: block;

		&:before {
			display: none;
		}
	}

	.comments {
		.content {
			font-size: 23px;
			color: @accent-color-3;
		}

		.comment {
			clear: none;
			padding: 0 15px;
			margin: 20px 0;
			border-bottom: 0;

			> .cbp-item-wrapper > .sep-text {
				margin: 0;

				.sep-text-before,
				.sep-text-after {
					vertical-align: top;
					padding-bottom: 5px;
				}
			}

			.comment-inner {
				padding: 20px;
				border: 1px solid @default-line-color;
				border-top: 0;
				margin-top: -9px;
				text-align: center;

				.comment-header {
					font-size: 24px;
					margin: 1em 0 1em 0;
				}
			}
		}
	}
}