<?php

/**
 * List of theme icons
 *
 * @package wpv
 * @subpackage construction
 */

return array(
	'bars'               => 0xe000,
	'heart'              => 0xe001,
	'search'             => 0xe002,
	'angle-bottom'       => 0xe003,
	'angle-top'          => 0xe004,
	'angle-right'        => 0xe005,
	'angle-left'         => 0xe006,
	'arrow-right'        => 0xe007,
	'arrow-left'         => 0xe008,
	'mail'               => 0xe009,
	'play'               => 0xe00a,
	'lightning'          => 0xe00b,
	'like'               => 0xe00c,
	'audio'              => 0xe00d,
	'font'               => 0xe00e,
	'lock'               => 0xe00f,
	'tablet'             => 0xe010,
	'cellphone'          => 0xe011,
	'video'              => 0xe012,
	'camera'             => 0xe013,
	'tag'                => 0xe014,
	'next'               => 0xe015,
	'previous'           => 0xe016,
	'map'                => 0xe017,
	'bookmark'           => 0xe018,
	'comments'           => 0xe019,
	'home'               => 0xe01a,
	'libreoffice'        => 0xe01b,
	'triangle-right'     => 0xe01c,
	'checkbox-unchecked' => 0xe01d,
	'checkmark'          => 0xe01e,
	'libreoffice2'       => 0xe01f,
	'radio-unchecked'    => 0xe021,
	'vimeo-outline'      => 0xe022,
	'eye'                => 0xe023,
	'quote'              => 0xe024,
	'pencil'             => 0xe025,
	'phone'              => 0xe026,
	'phone-outline'      => 0xe027,
	'tag2'               => 0xe028,
	'a'                  => 0xe029,
	'twitter'            => 0xe02a,
	'facebook'           => 0xe02b,
	'flickr-outline'     => 0xe02c,
	'facebook-outline'   => 0xe02d,
	'twitter-outline'    => 0xe02e,
	'share'              => 0xe02f,
	'print'              => 0xe030,
	'comment'            => 0xe031,
	'read-more'          => 0xe032,
	'quote-flag'         => 0xe034,
	'brush'              => 0xe035,
	'ink-tool'           => 0xe036,
	'gallery'            => 0xe037,
	'play2'              => 0xe038,
	'twitterbird'        => 0xe039,
	'next2'              => 0xe03a,
	'x'                  => 0xe03b,
	'user-female'        => 0xe03c,
	'user-follow'        => 0xe03d,
	'user-following'     => 0xe03e,
	'user-unfollow'      => 0xe03f,
	'trophy'             => 0xe040,
	'screen-smartphone'  => 0xe041,
	'screen-desktop'     => 0xe042,
	'plane'              => 0xe043,
	'notebook'           => 0xe044,
	'moustache'          => 0xe045,
	'mouse'              => 0xe046,
	'magnet'             => 0xe047,
	'energy'             => 0xe048,
	'emoticon-smile'     => 0xe049,
	'cursor-move'        => 0xe04a,
	'crop'               => 0xe04b,
	'credit-card'        => 0xe04c,
	'chemistry'          => 0xe04d,
	'user'               => 0xe04e,
	'speedometer'        => 0xe04f,
	'social-youtube'     => 0xe050,
	'social-twitter'     => 0xe051,
	'social-tumblr'      => 0xe052,
	'social-facebook'    => 0xe053,
	'social-dropbox'     => 0xe054,
	'social-dribbble'    => 0xe055,
	'shield'             => 0xe056,
	'screen-tablet'      => 0xe057,
	'hourglass'          => 0xe058,
	'graduation'         => 0xe059,
	'ghost'              => 0xe05a,
	'game-controller'    => 0xe05b,
	'fire'               => 0xe05c,
	'eyeglasses'         => 0xe05d,
	'envelope-open'      => 0xe05e,
	'envelope-letter'    => 0xe05f,
	'bell'               => 0xe060,
	'badge'              => 0xe061,
	'anchor'             => 0xe062,
	'wallet'             => 0xe063,
	'vector'             => 0xe064,
	'speech'             => 0xe065,
	'printer'            => 0xe066,
	'present'            => 0xe067,
	'playlist'           => 0xe068,
	'pin'                => 0xe069,
	'picture'            => 0xe06a,
	'map2'               => 0xe06b,
	'layers'             => 0xe06c,
	'handbag'            => 0xe06d,
	'globe-alt'          => 0xe06e,
	'globe'              => 0xe06f,
	'frame'              => 0xe070,
	'folder-alt'         => 0xe071,
	'film'               => 0xe072,
	'feed'               => 0xe073,
	'earphones'          => 0xe074,
	'drop'               => 0xe075,
	'drawer'             => 0xe076,
	'docs'               => 0xe077,
	'directions'         => 0xe078,
	'direction'          => 0xe079,
	'diamond'            => 0xe07a,
	'cup'                => 0xe07b,
	'compass'            => 0xe07c,
	'call-out'           => 0xe07d,
	'call-in'            => 0xe07e,
	'call-end'           => 0xe07f,
	'calculator'         => 0xe080,
	'bubbles'            => 0xe081,
	'book-open'          => 0xe082,
	'basket-loaded'      => 0xe083,
	'basket'             => 0xe084,
	'bag'                => 0xe085,
	'action-undo'        => 0xe086,
	'action-redo'        => 0xe087,
	'wrench'             => 0xe088,
	'umbrella'           => 0xe089,
	'trash'              => 0xe08a,
	'tag3'               => 0xe08b,
	'support'            => 0xe08c,
	'size-fullscreen'    => 0xe08d,
	'size-actual'        => 0xe08e,
	'shuffle'            => 0xe08f,
	'share2'             => 0xe090,
	'rocket'             => 0xe091,
	'question'           => 0xe092,
	'pie-chart'          => 0xe093,
	'pencil2'            => 0xe094,
	'note'               => 0xe095,
	'music-tone-alt'     => 0xe096,
	'music-tone'         => 0xe097,
	'microphone'         => 0xe098,
	'loop'               => 0xe099,
	'logout'             => 0xe09a,
	'login'              => 0xe09b,
	'list'               => 0xe09c,
	'like2'              => 0xe09d,
	'disc'               => 0xe09e,
	'magic-wand'         => 0xe09f,
	'puzzle'             => 0xe0a0,
	'earphones-alt'      => 0xe0a1,
	'briefcase'          => 0xe0a2,
	'share-alt'          => 0xe0a3,
	'home2'              => 0xe0a4,
	'grid'               => 0xe0a5,
	'graph'              => 0xe0a6,
	'equalizer'          => 0xe0a7,
	'dislike'            => 0xe0a8,
	'cursor'             => 0xe0a9,
	'control-start'      => 0xe0aa,
	'control-rewind'     => 0xe0ab,
	'control-play'       => 0xe0ac,
	'control-pause'      => 0xe0ad,
	'control-forward'    => 0xe0ae,
	'control-end'        => 0xe0af,
	'calendar'           => 0xe0b0,
	'arrow-up'           => 0xe0b1,
	'arrow-right2'       => 0xe0b2,
	'arrow-left2'        => 0xe0b3,
	'arrow-down'         => 0xe0b4,
	'ban'                => 0xe0b5,
	'bubble'             => 0xe0b6,
	'camcorder'          => 0xe0b7,
	'camera2'            => 0xe0b8,
	'check'              => 0xe0b9,
	'clock'              => 0xe0ba,
	'close'              => 0xe0bb,
	'cloud-download'     => 0xe0bc,
	'cloud-upload'       => 0xe0bd,
	'eye2'               => 0xe0be,
	'flag'               => 0xe0bf,
	'folder'             => 0xe0c0,
	'heart2'             => 0xe0c1,
	'info'               => 0xe0c2,
	'key'                => 0xe0c3,
	'link'               => 0xe0c4,
	'lock2'              => 0xe0c5,
	'lock-open'          => 0xe0c6,
	'magnifier'          => 0xe0c7,
	'magnifier-add'      => 0xe0c8,
	'magnifier-remove'   => 0xe0c9,
	'paper-clip'         => 0xe0ca,
	'pointer'            => 0xe0cb,
	'power'              => 0xe0cc,
	'refresh'            => 0xe0cd,
	'reload'             => 0xe0ce,
	'settings'           => 0xe0cf,
	'star'               => 0xe0d0,
	'symbol-female'      => 0xe0d1,
	'symbol-male'        => 0xe0d2,
	'target'             => 0xe0d3,
	'volume-1'           => 0xe0d4,
	'volume-2'           => 0xe0d5,
	'volume-off'         => 0xe0d6,
	'users'              => 0xe0d7,
	'bulb'               => 0xe0d8,
	'bar-chart'          => 0xe0d9,
	'doc'                => 0xe0da,
	'envelope'           => 0xe0db,
	'paper-plane'        => 0xe0dc,
	'plus2'              => 0xe0dd,
	'line-vertical'      => 0xe600,
	'circle-user'        => 0xe601,
	'circle-tablet'      => 0xe602,
	'circle-pencil'      => 0xe603,
	'circle-book'        => 0xe604,
	'circle-pulse'       => 0xe605,
	'arrow-right22'      => 0xe606,
	'arrow-left22'       => 0xe607,
	'like3'              => 0xe608,
	'search2'            => 0xe609,
	'comment2'           => 0xe60a,
	'home3'              => 0xe60b,
	'arrow-right3'       => 0xe60c,
	'arrow-left3'        => 0xe60d,
	'plus'               => 0xe60e,
	'minus'              => 0xe60f,
	'circle-search'      => 0xe610,
	'circle-post'        => 0xe611,
	'woman'              => 0xe612,
	'man'                => 0xe613,
	'arrow-bg-down'      => 0xe614,
	'arrow-bg-up'        => 0xe615,
	'arrow-bg-left'      => 0xe616,
	'arrow-bg-right'     => 0xe617,
	'linkedin'           => 0xe618,
	'arrow-up2'          => 0xe619,
	'arrow-down2'        => 0xe61a,
	'builder-roller'     => 0xe61b,
	'builder-plumbing'   => 0xe61c,
	'builder-roof'       => 0xe61d,
	'builder-electrical' => 0xe61e,
	'builder-kitchen'    => 0xe61f,
	'builder-floor'      => 0xe620,
	'builder-excavator'  => 0xe621,
	'builder-power-plug' => 0xe622,
);
