/***
 * BxSlider v4.2.3 - Fully loaded, responsive content slider
 * http://bxslider.com
 *
 * Written by: Steven Wanderski, 2014
 * http://stevenwanderski.com
 * (while drinking Belgian ales and listening to jazz)
 *
 * CEO and founder of bxCreative, LTD
 * http://bxcreative.com
 ***/


/** RESET AND LAYOUT
===================================*/

.bx-wrapper {
	position: relative;
	margin: 0 auto;
	padding: 0;
	*zoom: 1;
	-ms-touch-action: pan-y;
	touch-action: pan-y;
}

.bxslider {
	margin: 0;
	padding: 0;
}

ul.bxslider {
	list-style: none;
	margin-left: 0;
}

.bx-viewport {
	/*fix other elements on the page moving (on Chrome)*/
	-webkit-transform: translatez(0);
}

.bxslider-container {
	margin: 0;

	> li {
		padding: 0;

		> img,
		> a > img {
			width: 100%;
		}
	}
}

/** THEME
===================================*/

.bx-wrapper {
	.bx-pager,
	.bx-controls-auto {
		position: absolute;
		bottom: 0;
		width: 100%;
	}
}

/* LOADER */
.bx-wrapper .bx-loading {
	min-height: 50px;
	background: url(@theme-images-dir + 'bx_loader.gif') center center no-repeat #fff;
	height: 100%;
	width: 100%;
	position: absolute;
	top: 0;
	left: 0;
	z-index: 2000;
}

/* PAGER */
.bx-wrapper {
	.bx-pager {
		text-align: left;
		font-size: .85em;
		font-family: Arial;
		font-weight: bold;
		color: #666;
		left: 0;

		&.bx-default-pager a {
			background: none;
			text-indent: -9999px;
			display: block;
			width: 12px;
			height: 12px;
			margin: 0 5px;
			outline: 0;
			border-radius: 50%;
			transition: background .3s ease-out;
			border: solid 1px @accent-color-3;

			&:hover,
			&.active,
			&:focus {
				background: @accent-color-1;
				border-color: @accent-color-1;
			}
		}
	}

	.bx-pager-item,
	.bx-controls-auto .bx-controls-auto-item {
		display: inline-block;
		*zoom: 1;
		*display: inline;
	}

	.bx-pager-item {
		font-size: 0;
		line-height: 0;
	}
}

/* DIRECTION CONTROLS (NEXT / PREV) */
.bx-wrapper {
	.bx-prev {
		right: 40px;

		&:after {
			content: icon(theme-arrow-left22);
		}
	}

	.bx-next {
		right: 10px;

		&:after {
			content: icon(theme-arrow-right22);
		}
	}

	.bx-controls-direction a {
		color: @accent-color-8;
		position: absolute;
		top: 30px;
		margin-top: -16px;
		outline: 0;
		width: 32px;
		height: 32px;
		line-height: 0;
		text-indent: -9999px;
		z-index: 9999;

		&:after {
			font-family: theme;
			text-indent: 0;
			display: block;
			font-size: 32px;
			line-height: 32px;
			font-style: normal;
			margin-top: -1px;
		}

		&.disabled {
			display: none;
		}

		&:hover {
			color: @accent-color-1;
			text-decoration: none;
		}
	}
}

/* AUTO CONTROLS (START / STOP) */
.bx-wrapper .bx-controls-auto {
	text-align: center;
	.bx-start {
		display: block;
		text-indent: -9999px;
		width: 10px;
		height: 11px;
		outline: 0;
		background: url(@theme-images-dir + 'controls.png') -86px -11px no-repeat;
		margin: 0 3px;
		&:hover,
		&.active,
		&:focus {
			background-position: -86px 0;
		}
	}
	.bx-stop {
		display: block;
		text-indent: -9999px;
		width: 9px;
		height: 11px;
		outline: 0;
		background: url(@theme-images-dir + 'controls.png') -86px -44px no-repeat;
		margin: 0 3px;
		&:hover,
		&.active,
		&:focus {
			background-position: -86px -33px;
		}
	}
}

/* PAGER WITH AUTO-CONTROLS HYBRID LAYOUT */
.bx-wrapper {
	.bx-controls.bx-has-controls-auto.bx-has-pager {
		.bx-pager {
			text-align: left;
			width: 80%;
		}
		.bx-controls-auto {
			right: 0;
			width: 35px;
		}
	}
}

/* IMAGE CAPTIONS */
.bx-wrapper .bx-caption {
	position: absolute;
	bottom: 0;
	left: 0;
	background: #666;
	background: rgba(80, 80, 80, 0.75);
	width: 100%;
	span {
		color: #fff;
		font-family: Arial;
		display: block;
		font-size: .85em;
		padding: 10px;
	}
}