.widget_calendar {
	max-width: 100%;

	#wp-calendar {
		width: 100%;

		caption {
			.wpv-font(h4-);
			color:@css_link_color;
			padding: 0 0 10px 0;
		}

		thead {
			border-top: 1px solid @accent-color-7;
			border-bottom: 1px solid @accent-color-7;
		}

		tbody {
			padding: 10px 0;

			tr {
				&:first-child td {
					padding-top: 10px;
				}

				&:last-child td {
					padding-bottom: 10px;
				}
			}
		}

		tfoot {
			border-top: 1px solid @accent-color-7;

			td {
				padding-top: 10px;
				margin-top: 5px;

				&:first-child {
					text-align: left;
				}

				&:last-child {
					text-align: right;
				}

				a {
					font-weight: bold;
				}
			}
		}

		td#today {
			background: @accent-color-1;
			color: @accent-color-8;
			border-radius: 3px;
		}
	}
}

.widget_calendar th,
.widget_calendar td {
    padding: 2px;
    text-align: center;
}
.widget_calendar th {
	font-size: 100%;
}