.wpv_social a,
.wpv_social a img,
.wpv_social img {
    border: 0px !important;
	min-width:20px;
	min-height:16px;
	display: block;
}
.wpv_social a {
    zoom: 1;
    filter: none;
    opacity: 1;
    -webkit-transition: opacity 0.3s ease !important;
    -moz-transition: opacity 0.3s ease !important;
    -o-transition: opacity 0.3s ease !important;
    transition: opacity 0.3s ease !important;
	float:left;
}
.wpv_social a:hover {
    zoom: 1;
    opacity: 0.7;
    filter: ~"alpha(opacity=70)";
}
.social_wrap a,
.wpv_social .vamtam_full a {
    clear: both;
    margin-bottom: 3px;
}
.wpv_social .vamtam_full a img {
    padding: 0px 0px 7px 0px;
}
aside .social_wrap a {
	float: left;
	clear: none;
}
aside .social_wrap:after {
	content:"";
	display: block;
	clear:both;
}