.wpv-progress {
	@size: 130px;

	position: relative;
	text-align: center;
	width: @size;
	height: auto;
	line-height: normal;
	font-weight: 300;
	font-size: 1.2em;
	margin: auto;
	margin-top: 20px;
	margin-bottom: 20px;

	canvas {
		position: absolute;
		top: 0;
		left: 0;
	}

	span:not(.icon) {
		.wpv-font(h3-);
		font-size: 40px;
		color: @accent-color-1;
	}

	+ .wpv-progress-content {
		color: @accent-color-6;
		font-size: 12px;
		line-height: 16px;
	}

	&.number {
		width: auto;
		font-size: 30px;

		.icon {
			font-size: 36px;
			display: block;
			margin-bottom: 20px;
			color: @accent-color-6;
			font-weight: 100;
		}

		+ .wpv-progress-content {
			padding-top: 20px;
			border-top: 1px solid @default-line-color;
		}
	}

	&.pie {
		padding-top: 47px;
		min-height: 85px;
		font-size: 1.8em;
		margin-top: 5px;

		span:not(.icon) {
			font-size: 2em;
		}
	}

	+ .wpv-progress-content {
		text-align: center;
	}
}