.loop-wrapper.news {

	.post-media-date {
		background: none;
		position: relative;
		overflow: hidden;

		.thumbnail {
			img {
				-webkit-transition: opacity 0.35s, -webkit-transform 0.35s;
				transition: opacity 0.35s, transform 0.35s;
				.transform( translate3d(0,0,300px) );
			}
		}
	}

	.as-standard-post-format,
	.aside-post-format,
	.link-post-format,
	.audio-post-format,
	.quote-post-format {
		.post-media-date {
			background: none;
			-webkit-transition:  0.35s, -webkit-transform 0.35s;
			transition:  0.35s, transform 0.35s;

			.post-actions-wrapper {
				padding-bottom: 0px;
			}
		}
	}

	.post-article {
		overflow: hidden;
		margin: 0;
		border-bottom: 0px !important;

		&:hover {
			.image-post-format,
			.as-image {
			   .thumbnail {
					img {
						.transform( scale(1.15) );
						opacity: 1;
					}
				}
			}

          	.post-actions-wrapper {
				.transform( translate3d(0,0,0) );
			}
		}

		.post-content-outer {
			&, p {
				.wpv-font(primary-font-);
				font-size: inherit;
				margin-bottom: 0.5em;
			}
		}
	}

	.page-content:not(.has-post-thumbnail) .post-article:hover {
		.as-standard-post-format,
		.aside-post-format,
		.link-post-format,
		.audio-post-format,
		.quote-post-format {
			.post-media-date {
				padding-bottom: 40px;
			}
		}
	}

	.post-content-wrapper {
		padding: 10px 20px 20px;
		background: @accent-color-8;

		h3 {
			font-weight: bold;

			&, a {
				color: @css_link_color;
				font-weight: normal;
				font-size: 1.2em;

				&:hover {
					color: @css_link_hover_color;
				}
			}
		}
	}

	.comment-count {
		position: relative;
		display: inline-block;
		float: right;
		background: @accent-color-1;
		margin: 0;
		color: @accent-color-8;


		a {
			font-weight: normal;
			font-size: 12px;
			color: @accent-color-8;
			padding: 10px 15px;
			display: block;


			&:hover {
				color: @css_link_color;
				background: @accent-color-2;
			}
		}
	}

	.post-actions-wrapper {
		position: absolute;
		left: 0;
		top: auto;
		height: auto;
		background: fade( @accent-color-2, 50% );
		-webkit-transition: -webkit-transform 0.35s;
		transition: transform 0.35s;
		-webkit-transform: translate3d(0,100%,0);
		transform: translate3d(0,100%,0);
		width: 100%;
		bottom: 0;


		html.touch & {
			.transform( translate3d(0,0,0) );
		}

		.icon {
			color: @accent-color-8;
			position: relative;
			display: inline-block;
			width: auto;
			height: auto;
			margin: inherit;
			opacity: 1;
			margin-right: 0.7em;
			vertical-align: top;
			font-size: 14px;
			text-align: left;

		}

		.post-date {
			position: relative;
			display: inline-block;
			float: left;
			font-size: 10px;
			font-style: normal;
			text-transform: uppercase;
			color: @accent-color-8;
			font-family: arial;
			font-weight: bold;
			padding: 10px 0px 10px 20px;
		}

		a {
			&:hover {
				.icon {
					color: @accent-color-1;
				}
			}
		}
	}

	.post-content-meta,
	.author {
		margin: 0px;
		padding-top: 0px;
		border: none;
		text-align: left;
		font-size: 10px;
		font-style: normal;
		text-transform: uppercase;
		color: @accent-color-4;

		a {

			font-size: 10px;
			font-style: normal;
			text-transform: uppercase;
			color: @css_link_color;

			&:hover {
				color: @css_link_hover_color;
			}
		}
	}

	.list-item {
		padding-top: 15px;
		border-bottom: 0;

		header.single {
			padding: 10px 0 0 0;
			position: relative;
			border-bottom: none;

			&:after {
				display: none;
			}
		}

		> div {
			position: relative;
			position: relative;
			z-index: 1;
			overflow: hidden;
			background: transparent;
		}
	}

	&.wpv-isotope-loaded {
		padding-top: 2px;
		padding-bottom: @vertical-padding/2;
	}

	.thumbnail {
		position: relative;
		overflow: visible;
		width: 100%;
		text-align: center;
		background: none;

		img {
			width: 100%;
			height: auto;
			transition: opacity .4s;
		}

		.icon {
			@icon-size: 65px;
			position: absolute;
			top: 50%;
			left: 50%;
			display: inline-block;
			width: @icon-size;
			height: @icon-size;
			color: @accent-color-8;
			font-size: @icon-size;
			margin: -@icon-size/2 0 0 -@icon-size/2;
			opacity: 0;
		}
	}

	.post-edit-link,
	.sep-text-after {
		display: none;
	}

	.image-post-format,
	.video-post-format.as-image,
	.standard-post-format.as-image {
		.thumbnail {
			overflow: hidden;
			.translateZ(0);
		}
	}

	> .page-content {
		margin-bottom: 20px;
	}

	.post-article {
		.quote-post-format {
			.cite {
				float: none;
				padding: 20px 0 20px;
				width: auto;
				text-align: left;

				img {
					display: inline-block;
					margin-bottom: 0;
					padding: 0 20px 0 0;
					max-width: 85px;
					border: 0;
					vertical-align: middle;

					+ .quote-author {
						display: inline;
						vertical-align: middle;
					}
				}

				+ .quote-text {
					padding-left: 0;
				}
			}

			.quote-text {
				padding-bottom: 25px;
			}
		}
	}
}
