.post-article .gallery-post-format  .post-media,
.portfolio-image-wrapper {
	padding: 0;
	border: 0;
	box-shadow: none;
}

.thumbnail.partner {
	display: block;
	position: relative;
	opacity: 0.8;
	padding-bottom: .5em;
	.transition(all .3s ease);

	&:after {
		color: #aeaeae !important;
		content: attr(title);
		display: block;
		border-top: 1px solid;
		text-align: center;
		position: absolute;
		bottom: -1em;
		left: 0;
		right: 0;
		height: 1.5em;
		opacity: 0;
		.transition(all .3s ease);
	}

	&:hover {
		opacity: 1;

		&:after {
			opacity: 1;
		}
	}
}