.wpv_posts {
	.wpv-tabs.horizontal {
		.ui-tabs-nav {
			display: block;

			li {
				display: block;
				float: left;
				background: @accent-color-8;
				border: 1px solid @default-line-color;
				padding: 10px;
				border-radius: 1px 1px 0 0;
				margin-bottom: -1px;
				margin-right: -1px;

				.icon {
					color: @accent-color-6;
				}

				&:hover,
				&.ui-state-active,
				&.ui-state-selected {
					.icon {
						color: @accent-color-1;
					}
				}

				&.ui-state-active {
					border-bottom-color: @accent-color-8;
				}

				a {
					padding: 5px;

					&:hover {
						text-decoration: none;

						.icon {
							color: @accent-color-1 !important;
							font-size: 20px;
						}
					}

					.icon {
						color: @accent-color-6;
						text-align: center;
						font-size: 20px;
						padding: 0;
					}
				}

				.icon {
					display: block;
					text-transform: none;
					font-size: 17px;
					line-height: 22px;
				}
			}
		}
	}

	[data-single] .icon {
		color: @accent-color-1;
	}

	.ui-tabs-panel {
		background: transparent;
		padding: 0;

		.tagcloud {
			margin-bottom: -@small-padding + 15;
			padding-top: @small-padding - 10 !important;
		}
	}

	.wpv-tabs.horizontal .pane {
		background: @accent-color-8;
		color: @accent-color-6;
		border: 1px solid @default-line-color;
		border-top-right-radius: 1px;

		&.tab-comments {
			.title {
				a:last-child {
					font-size: 11px;
					color: @accent-color-3;
				}
			}
		}
	 }

	.posts_list {
		padding: 0;
		background: transparent;

		li {
			padding: 10px;
			display: table;
			width: 100%;
			.border-box();

			.thumbnail {
				position: relative;
				display: table-cell;
				width: 70px;
				vertical-align: top;

				img {
					width: 70px;
					height: auto;
					padding-right: 10px;
				}
			}

			.post_extra_info  {
				display: table-cell;
				vertical-align: text-top;
				padding-left: 0;
				font-size: 11px;
				font-color: @accent-color-7;
				font-style: italic;


				.title {
					margin: 0;

					a {
						font-weight: normal;
						font-size: 15px;
						line-height: 20px;
					}

					+ div {
						color: @accent-color-3;
					}
				}

				.nothumb {
					.title a {
						padding-top: 0;
						font-weight: normal;
						font-size: 11px;
						line-height: 20px;
					}
				}

				.comments {
					display: none;;
				}
			}
		}
	}
}
