@menu-top-bar-resolution:959;
@tribe-events-join-text:false;
@full-width-header:false;
@header-layout:false;
@related-portfolios-title:false;
@related-posts-title:false;
@top-bar-layout:false;
@enable-header-search:false;
@single-portfolio-images-wth:false;
@page-images-wth:1.25;
@portfolio-loop-images-wth:1.5;
@post-small-images-wth:1.3;
@post-loop-images-wth:1.3;
@single-post-images-wth:false;
@fmap-zoom:14;
@fmap-marker:false;
@fmap-popup:false;
@lcolumn-text-color:#ff5400;
@site-layout-type:false;
@javascript_move_bottom:1;
@enable-featured-posts:false;
@default-body-layout:false;
@primary-font-face:"Lato";
@primary-font-weight:"normal";
@primary-font-size:19px;
@primary-font-lheight:22px;
@primary-font-color:#080909;
@secondary-font-face:"Droid Serif";
@secondary-font-weight:"normal";
@secondary-font-size:13px;
@secondary-font-lheight:18px;
@secondary-font-color:#777777;
@footer-sidebars-font-face:"Lato";
@footer-sidebars-font-weight:"normal";
@footer-sidebars-font-size:14px;
@footer-sidebars-font-lheight:22px;
@footer-sidebars-font-color:#B4B4B4;
@footer-sidebars-titles-face:"Lato";
@footer-sidebars-titles-weight:300;
@footer-sidebars-titles-size:24px;
@footer-sidebars-titles-lheight:28px;
@footer-sidebars-titles-color:#A7D9EE;
@sub-footer-face:"Lato";
@sub-footer-weight:"normal";
@sub-footer-size:12px;
@sub-footer-lheight:16px;
@sub-footer-color:#898989;
@em-face:"Lato";
@em-weight:"italic";
@em-size:14px;
@em-lheight:22px;
@em-color:#5F5F5F;
@logo-face:"Lato";
@logo-weight:"bold";
@logo-size:18px;
@logo-lheight:40px;
@logo-color:#253993;
@menu-font-face:"Lato";
@menu-font-weight:"normal";
@menu-font-size:15px;
@menu-font-lheight:30px;
@menu-font-color:#4A4F55;
@h1-face:"Lato";
@h1-size:36px;
@h1-lheight:40px;
@h1-weight:"normal";
@h1-color:#4A4F55;
@h2-face:"Lato";
@h2-size:34px;
@h2-lheight:38px;
@h2-weight:300;
@h2-color:#4A4F55;
@h3-face:"Lato";
@h3-size:22px;
@h3-lheight:26px;
@h3-weight:"normal";
@h3-color:#4A4F55;
@h4-face:"Lato";
@h4-size:20px;
@h4-lheight:24px;
@h4-weight:300;
@h4-color:#4A4F55;
@h5-face:"Lato";
@h5-size:12px;
@h5-lheight:16px;
@h5-weight:"bold";
@h5-color:#242323;
@h6-face:"Lato";
@h6-size:10px;
@h6-lheight:12px;
@h6-weight:"bold";
@h6-color:#6A6A6A;
@show_scroll_to_top:false;
@footer-sidebars:5;
@footer-sidebars-1-width:false;
@footer-sidebars-2-width:false;
@footer-sidebars-3-width:false;
@footer-sidebars-4-width:false;
@footer-sidebars-5-width:false;
@footer-sidebars-6-width:false;
@footer-sidebars-7-width:false;
@footer-sidebars-1-last:false;
@footer-sidebars-2-last:false;
@footer-sidebars-3-last:false;
@footer-sidebars-4-last:false;
@footer-sidebars-5-last:false;
@footer-sidebars-6-last:false;
@footer-sidebars-7-last:false;
@header-sidebars:3;
@header-sidebars-1-width:false;
@header-sidebars-2-width:false;
@header-sidebars-3-width:false;
@header-sidebars-4-width:false;
@header-sidebars-5-width:false;
@header-sidebars-6-width:false;
@header-sidebars-1-last:false;
@header-sidebars-2-last:false;
@header-sidebars-3-last:false;
@header-sidebars-4-last:false;
@header-sidebars-5-last:false;
@header-sidebars-6-last:false;
@has-header-slider:false;
@has-header-sidebars:false;
@has-footer-sidebars:false;
@has-fullwidth-slider:false;
@header-slider-position:static;
@header-slider-pausetime:6438;
@header-slider-animationtime:934;
@header-slider-effect:false;
@header-slider-direction:false;
@header-slider-prevtext:false;
@header-slider-nexttext:false;
@header-slider-captionopacity:1;
@header-slider-easing:false;
@header-slider-waveduration:300;
@header-slider-wavetype:false;
@header-slider-subslideduration:false;
@header-slider-visiblegrid:1;
@header-slider-gridcolor:#cccccc;
@header-slider-rows:4;
@header-slider-cols:6;
@header-slider-captiontime:659;
@header-slider-resizing:false;
@post-thumbnail-width:250px;
@post-thumbnail-height:200px;
@fullimage-height:560px;
@accent-color-1:#eeeff2;
@accent-color-2:#4A4F55;
@accent-color-3:#A7D9EE;
@accent-color-4:#8F8D8E;
@accent-color-5:transparent;
@accent-color-6:#2B2F34;
@header-helper-style:false;
@slider-helper-style:false;
@body-helper-style:false;
@footer-helper-style:false;
@css_link_color:#080909;
@css_link_visited_color:#040404;
@css_link_hover_color:#1C2446;
@css_header_link_color:#4e89a5;
@css_header_link_visited_color:#4e89a5;
@css_header_link_hover_color:#4e89a5;
@css_footer_link_color:#A7D9EE;
@css_footer_link_visited_color:#A7D9EE;
@css_footer_link_hover_color:#fff;
@css_tophead_background:transparent;
@css_tophead_background_repeat:no-repeat;
@css_tophead_background_picture:transparent;
@css_tophead_background_position:center top;
@css_tophead_color:#c1c1c1;
@css-tophead-link-color:#253993;
@css-tophead-link-hover-color:#253993;
@css_tophead_current_link_color:transparent;
@subfooter-background-color:#eeeff2;
@subfooter-background-repeat:repeat;
@subfooter-background-picture:transparent;
@subfooter-background-attachment:scroll;
@subfooter-background-position:center top;
@events-after-sidebars-2-background-color:transparent;
@events-after-sidebars-2-background-repeat:no-repeat;
@events-after-sidebars-2-background-image:false;
@events-after-sidebars-2-background-attachment:fixed;
@events-after-sidebars-2-background-position:center top;
@events-after-sidebars-2-background-size:auto;
@css_credits_color:#555555;
@footer-background-color:fade( #eeeff2,100% );
@footer-background-opacity:1;
@footer-background-repeat:no-repeat;
@footer-background-picture:transparent;
@footer-background-position:center bottom;
@footer-background-attachment:scroll;
@css_header_sidebars_title_color:#000;
@body-background-color:#eeeff2;
@body-background-repeat:repeat;
@body-background-image:"https://crafft.agent-number.com/wp-content/themes/auto-repair/wpv_theme/assets/images/patterns/15.png";
@body-background-position:center top;
@body-background-attachment:fixed;
@header-background-color:fade( #eeeff2,100% );
@header-background-opacity:1;
@header-background-repeat:no-repeat;
@header-background-picture:transparent;
@header-background-position:center top;
@header-background-attachment:fixed;
@top-nav-background-color:transparent;
@top-nav-background-opacity:1;
@top-nav-background-repeat:no-repeat;
@top-nav-background-picture:transparent;
@top-nav-background-position:center top;
@top-nav-background-attachment:fixed;
@slider-background-color:#ffffff;
@slider-background-repeat:repeat-x;
@slider-background-picture:transparent;
@slider-background-position:center top;
@slider-background-attachment:scroll;
@main-background:#ffffff;
@main-background-opacity:1;
@main-background-repeat:no-repeat;
@main-background-picture:transparent;
@main-background-position:center top;
@main-background-attachment:fixed;
@css_hide_fnav_background_repeat:no-repeat;
@css_hide_fnav_background_picture:transparent;
@css_hive_fnav_background_position:center center;
@css_button_color:#eeeeee;
@css_button_hover_color:#eeeeee;
@left-sidebar-width:25%;
@right-sidebar-width:25%;
@sidebar-margin-top:false;
@content-width:940px;
@custom_css:false;
@custom_js:false;
@image_small_width:50px;
@image_small_height:50px;
@image_medium_width:640px;
@image_medium_height:150px;
@image_large_width:400px;
@image_large_height:400px;
@video_width:877px;
@video_height:640px;
@feedback-link:false;
@show-fb:false;
@fb-link:false;
@show-twitter:false;
@twitter-link:false;
@show-youtube:false;
@youtube-link:false;
@show-flickr:false;
@flickr-link:false;
@show-phone-top:false;
@header-text-main:false;
@custom-header-logo:"https://crafft.agent-number.com/wp-content/uploads/2022/06/service-center.png";
@splash-screen-logo:false;
@css_logo_margin_bottom:false;
@css_logo_margin_top:10;
@css_menu_color:#afd2ea;
@css_menu_background:#F6F6F6;
@css_menu_hover_color:#253993;
@css_menu_hover_background:#3f3f3f;
@css_submenu_color:#4A4F55;
@css_submenu_background:#000000;
@css_submenu_hover_color:#253993;
@css_submenu_hover_background:#ffffff;
@css_postformat_opacity_n:0.2;
@css_postformat_opacity_h:0.5;
@header-height:75px;
@stage-height:189px;
@header-slider-height:382px;
@favicon_url:"https://construction.vamtam.com/wp-content/uploads/2014/12/favicon.png";
@meta_posted_in:false;
@meta_posted_on:false;
@meta_comment_count:false;
@last-active-skin:false;
@fixed-header:false;
@share-post-twitter:false;
@share-post-facebook:false;
@share-page-twitter:false;
@share-page-facebook:false;
@share-portfolio-twitter:false;
@share-portfolio-facebook:false;
@share-lightbox-twitter:false;
@share-lightbox-facebook:false;
@header-sidebars-7-width:false;
@header-sidebars-7-last:false;
@header-sidebars-8-width:false;
@header-sidebars-8-last:false;
@header-sidebars-9-width:false;
@header-sidebars-9-last:false;
@header-sidebars-10-width:false;
@header-sidebars-10-last:false;
@header-sidebars-11-width:false;
@header-sidebars-11-last:false;
@header-sidebars-12-width:false;
@header-sidebars-12-last:false;
@footer-sidebars-8-width:false;
@footer-sidebars-8-last:false;
@footer-sidebars-9-width:false;
@footer-sidebars-9-last:false;
@footer-sidebars-10-width:false;
@footer-sidebars-10-last:false;
@footer-sidebars-11-width:false;
@footer-sidebars-11-last:false;
@footer-sidebars-12-width:false;
@footer-sidebars-12-last:false;
@show_flickr:false;
@show_youtube:false;
@show_twitter:false;
@fbb-link:false;
@show_fb:false;
@show_rss_button:false;
@title_background_color:transparent;
@credits:false;
@analytics_key:false;
@custom-sidebars:false;
@header-slider-pauseonhover:false;
@feedback-type:false;
@has-page-header:false;
@single-featured-image-position:false;
@page_title_background_color:transparent;
@page_title_background_image:"http://makalu.vamtam.com/wp-content/uploads/2012/02/interior-design-black-living-room-on-white-up.jpg";
@page_title_background_repeat:no-repeat;
@disable-lazy-load:false;
@css_body_background:#ffffff;
@css_body_background_picture:transparent;
@css_body_background_repeat:no-repeat;
@css_body_background_attachment:fixed;
@css_body_background_position:center bottom;
@show-feedback:false;
@content-background:#ffffff;
@linkedin-link:false;
@default-header-slider:false;
@css_header_background:transparent;
@css_header_background_opacity:0.15;
@css_header_background_picture:transparent;
@css_header_background_repeat:repeat;
@css_header_background_position:left top;
@css_slider_background:transparent;
@css_slider_background_picture:transparent;
@css_slider_background_repeat:no-repeat;
@css_slider_background_position:center center;
@css_main_content_background:#ffffff;
@css_main_content_opacity:0.95;
@css_main_content_background_picture:transparent;
@css_main_content_background_repeat:no-repeat;
@css_main_content_background_position:center center;
@css_footer_background:#050505;
@css_footer_opacity:0.9;
@css_footer_background_picture:transparent;
@css_footer_background_repeat:repeat-x;
@css_footer_background_attachment:fixed;
@css_footer_background_position:center center;
@css_credits_background:transparent;
@css_credits_background_picture:transparent;
@css_credits_background_repeat:no-repeat;
@css_credits_background_position:center top;
@css_footer_color:#bfbfbf;
@css_footer_sidebars_title_color:#bdbdbd;
@css_footer_font_size:11px;
@enable-feedback-sidebar:1;
@css_content_background:#ffffff;
@css_content_opacity:0.5;
@css_content_background_picture:transparent;
@css_content_background_repeat:no-repeat;
@css_content_background_position:left center;
@hide-post-author:1;
@show_linkedin:false;
@header-background-image:false;
@slider-background-image:"http://makalu.demo.ltf8.com/wp-content/uploads/2012/11/slider-bg.png";
@title-background-image:false;
@title-background-color:transparent;
@title-background-position:center top;
@title-background-attachment:fixed;
@title-background-repeat:no-repeat;
@events-listing-title-background-image:false;
@events-listing-title-background-color:#4f4f4f;
@events-listing-title-background-position:center top;
@events-listing-title-background-attachment:fixed;
@events-listing-title-background-repeat:no-repeat;
@events-listing-title-background-size:auto;
@mobile-top-bar-resolution:959;
@main-background-image:false;
@main-background-color:fade( #eeeff2,100% );
@footer-background-image:false;
@subfooter-background-image:false;
@content-background-attachment:fixed;
@pagination-type:false;
@accent-color:#4E89A5;
@accent-color-7:#EDEDED;
@accent-color-8:transparent;
@accent-override-1:#17f700;
@accent-override-2:#00938b;
@accent-override-3:#05008f;
@accent-override-4:#690070;
@accent-override-5:#832500;
@accent-override-6:false;
@accent-override-7:false;
@accent-override-8:false;
@additional-font-1-color:#898989;
@additional-font-1-face:"Lato";
@additional-font-1-lheight:36px;
@additional-font-1-size:30px;
@additional-font-1-weight:"bold";
@additional-font-2-color:#F8E71C;
@additional-font-2-face:"Lato";
@additional-font-2-lheight:56px;
@additional-font-2-size:50px;
@additional-font-2-weight:"bold";
@body-background:cover;
@body-background-opacity:false;
@body-background-size:auto;
@body-helper-classic:false;
@content-background-color:#ff0000;
@content-background-image:false;
@content-background-opacity-attachment:scroll;
@content-background-opacity-color:transparent;
@content-background-opacity-image:false;
@content-background-opacity-position:left center;
@content-background-opacity-repeat:no-repeat;
@content-background-position:center bottom;
@content-background-repeat:repeat;
@crop-featured-image:1;
@css-cache-timestamp:1767272878;
@css_accordion_background_bottom:transparent;
@css_accordion_background_top:#78ff64;
@css_accordion_border_color:transparent;
@css_accordion_color:#898989;
@css_accordion_pane_opacity:1;
@css_button_radius:false;
@css_footer_link_border_color:#e7e7e7;
@css_footer_link_hover_border_color:#f2612c;
@css_header_link_border_color:#999999;
@css_header_link_hover_border_color:#00c758;
@css_input_text_background:#fcfcfc;
@css_input_text_color:#999999;
@css_input_text_focus_background:#fafafa;
@css_input_text_focus_color:#444444;
@css_link_border_color:#FF6F18;
@css_link_hover_border_color:#FF6F18;
@css_link_underline:false;
@css_tab_active_background_bottom:#f8f8f8;
@css_tab_active_background_top:#d5d5d5;
@css_tab_active_color:#ececec;
@css_tab_background:#ececec;
@css_tab_border_color:transparent;
@css_tab_color:#777777;
@css_toggle_content_background:#5bff04;
@css_toggle_content_color:#9d9d9d;
@css_toggle_title_background:#24ff32;
@css_toggle_title_color:#3f4955;
@custom-header-logo2x:"https://construction.vamtam.com/wp-content/uploads/2014/01/Logo@2x.png";
@enable-breadcrumbs:false;
@enable-fmap:false;
@enable_box_layout:1;
@envato-api-key:false;
@envato-license-key:false;
@envato-username:false;
@external-fonts:false;
@fmap-address:false;
@fmap-background-attachment:scroll;
@fmap-background-color:transparent;
@fmap-background-image:"http://david-goliath.demo.ltf8.com/wp-content/uploads/2013/07/map_bottom.jpg";
@fmap-background-opacity:false;
@fmap-background-position:left center;
@fmap-background-repeat:no-repeat;
@fmap-background-size:auto;
@fmap-color:#eeeff2;
@fmap-controls:false;
@fmap-html:false;
@fmap-invert-lightness:false;
@fmap-invert_lightness:false;
@fmap-latitude:false;
@fmap-longitude:false;
@fmap-maptype:false;
@fmap-scrollwheel:false;
@footer-background-size:auto;
@footer-divider-image:false;
@footer-helper-classic:false;
@footer-phone:false;
@footer-phone-color:transparent;
@footer-phone-olor:#eeeff2;
@footer-sidebars-1-empty:false;
@footer-sidebars-2-empty:false;
@footer-sidebars-3-empty:false;
@footer-sidebars-4-empty:false;
@footer-sidebars-5-empty:false;
@footer-sidebars-6-empty:false;
@force-menu-background:transparent;
@full-width-slider:1;
@header-background-size:auto;
@header-helper-classic:false;
@header-sidebars-1-empty:false;
@header-sidebars-2-empty:false;
@header-sidebars-3-empty:false;
@header-sidebars-4-empty:false;
@header-sidebars-5-empty:false;
@header-sidebars-6-empty:false;
@header-slider-button-thumbnails:false;
@header-slider-captionqueue:1;
@header-slider-function-height:-1px;
@helper-color:#dcf9ff;
@helper-color-2:#ff98f3;
@helper-color-3:#ffc238;
@htmlslide-thumbnail:"http://makalu.vamtam.com/wp-content/uploads/2012/07/logo.png";
@is-responsive:false;
@left_sidebar_width:150px;
@main-background-size:auto;
@menu-widget-active-background-color:#e9e9e9;
@menu-widget-background-color:#f7f7f7;
@menu-widget-color:#cfcfcf;
@page-header-height:125px;
@portfolio-all-items:"https://auto-repair.vamtam.com/portfolio-layouts/masonry-style/";
@portfolio-crop-featured-image:1;
@portfolio-fullimage-height:500px;
@portfolio-slider-resizing:false;
@post-all-items:"https://auto-repair.vamtam.com/blog/blog-layout-1/";
@right_sidebar_width:299px;
@secondary-background-attachment:false;
@secondary-background-color:transparent;
@secondary-background-image:false;
@secondary-background-position:false;
@secondary-background-repeat:false;
@share-lightbox-googleplus:false;
@share-lightbox-pinterest:false;
@share-page-googleplus:false;
@share-page-pinterest:false;
@share-portfolio-googleplus:false;
@share-portfolio-pinterest:false;
@share-post-googleplus:false;
@share-post-pinterest:false;
@show-left-column:false;
@show-related-portfolios:false;
@slider-background-opacity:false;
@slider-background-size:auto;
@slider-helper-classic:false;
@slider-title:false;
@sub-header:false;
@subfooter-background:auto;
@subfooter-background-opacity:false;
@subfooter-background-size:auto;
@theme_installed_version:23;
@title-background:cover;
@title-background-opacity:false;
@title-background-size:cover;
@use-load-more:1;
@header-slider-nomobile:false;
@additional-font-3-color:#a9b9d6;
@additional-font-3-face:"Arial";
@additional-font-3-lheight:10px;
@additional-font-3-size:10px;
@additional-font-3-weight:300;
@lawyers-attorneys_vamtam_theme_activated:1;
@fmap-text-close:false;
@fmap-text-open:false;
@layerslider_activated:1;
@main-menu-hover-background:transparent;
@main-menu-sticky-color:#ffffff;
@middle-header-content:false;
@page-images-crop:false;
@portfolio-loop-images-crop:false;
@post-loop-images-crop:false;
@post-small-images-crop:false;
@share-lightbox-gplus:false;
@share-page-gplus:false;
@share-portfolio-gplus:false;
@share-post-gplus:false;
@share-product-facebook:false;
@share-product-googleplus:false;
@share-product-gplus:false;
@share-product-pinterest:false;
@share-product-twitter:false;
@show-post-author:false;
@show-related-posts:false;
@single-portfolio-images-crop:false;
@single-post-images-crop:false;
@site-max-width:1400px;
@sticky-header:false;
@sub-header-background-color:#E8E8E8;
@sub-header-background-image:false;
@sub-header-background-repeat:repeat-x;
@sub-header-background-size:auto;
@portfolio-slug:false;
@google-fonts-subsets:false;
@auto-repair_vamtam_theme_activated:1;
@construction_vamtam_theme_activated:1;
@css_tophead_link_color:#EA5178;
@css_tophead_link_hover_color:#898989;
@css-tophead-text-color:#898989;
@custom-font-families:false;
@custom-header-logo-transparent:false;
@david-goliath_vamtam_theme_activated:1;
@do-biz_vamtam_theme_activated:1;
@envato-license-key-old:false;
@events-after-details-content:false;
@events-after-sidebars-2-background-opacity:false;
@events-after-sidebars-2-content:false;
@fitness-wellness_vamtam_theme_activated:1;
@footer-sidebars-7-empty:false;
@footer-sidebars-8-empty:false;
@header-logo-type:false;
@header-name-left-bottom:false;
@header-name-left-top:false;
@header-name-right-bottom:false;
@header-name-right-top:false;
@header-sidebars-7-empty:false;
@header-sidebars-8-empty:false;
@header-text-right:false;
@health-center_vamtam_theme_activated:1;
@honeymoon_vamtam_theme_activated:1;
@last-theme-version:1;
@main-menu-layout:false;
@mobile-search-in-header:false;
@mobile-top-bar:false;
@page-title-background-attachment:scroll;
@page-title-background-color:#ffffff;
@page-title-background-image:false;
@page-title-background-repeat:no-repeat;
@page-title-background-size:auto;
@phone-num-top:false;
@previous-portfolio-slug:false;
@sermons_category_children:false;
@share-tribe-facebook:false;
@share-tribe-googleplus:false;
@share-tribe-pinterest:false;
@share-tribe-twitter:false;
@subfooter-center:false;
@subfooter-left:false;
@subfooter-right:false;
@system-status-opt-out:false;
@theme-loop-images-wth:1.3;
@theme-single-images-wth:1.3;
@theme-update-notice-dismissed:1;
@top-bar-social:false;
@top-bar-social-dribbble:false;
@top-bar-social-fb:false;
@top-bar-social-flickr:false;
@top-bar-social-gplus:false;
@top-bar-social-instagram:false;
@top-bar-social-lead:false;
@top-bar-social-linkedin:false;
@top-bar-social-pinterest:false;
@top-bar-social-twitter:false;
@top-bar-social-vimeo:false;
@top-bar-social-youtube:false;
@top-bar-text:false;
@top-nav-background-image:false;
@top-nav-background-size:auto;
@custom-js:false;
@gmap_api_key:false;
@theme-images-dir:"https://crafft.agent-number.com/wp-content/themes/construction/wpv_theme/assets/images/";
