.tt_event_hours {
	margin: 0 -15px;

	li {
		border-left-color: @accent-color-1;
		margin-left: 15px;
		margin-right: 15px;

		.csscalc & {
			width: -webkit-calc(~"33.33333% - 30px");
			width: calc(~"33.33333% - 30px");

			.border-box();
		}

		&.event_hours_right {
			margin-right: 15px;
		}
	}
}

.timetable .row_gray {
	background: @accent-color-7;
}