.shortcode-tooltip {
    position: relative;
    border-bottom: 1px dotted;

	.tooltip {
		display: none;
		position: absolute;
		left: 50%;
		bottom: 35px;
		background: #fff;
		color: #000;
		padding: 10px;
		min-width: 200px;
		z-index: 5000;
		overflow: visible;
		text-indent: 0;
		border-radius: 2px;
		box-shadow: 0 1px 3px rgba(0, 0, 0, 0.5);

		&:before {
			content: "";
			position: absolute;
			top: 100%;
			left: 50%;
			width: 0;
			height: 0;
			border-top: 10px solid rgba(0, 0, 0, 0.5);
			border-left: 10px inset transparent;
			border-right: 10px inset transparent;
			margin: 1px auto auto -5px;
		}

		&:after {
			content: "";
			position: absolute;
			top: 100%;
			left: 50%;
			width: 0;
			height: 0;
			border-top: 10px solid #FFF;
			border-left: 10px inset transparent;
			border-right: 10px inset transparent;
			margin: 0 auto auto -5px;
		}

		.no-boxshadow & {
			border: 1px solid #ddd;

			&:before,
			&:after {
				display: none;
			}
		}

		.tooltip-arrow {
			display: none;
		}
	}
}